@@ -23,16 +23,24 @@
 
 #include <kconfig.h>
 #include <klocale.h>
-#include <kstaticdeleter.h>
 
 #include "kabprefs.h"
 
-KABPrefs *KABPrefs::mInstance = 0;
-static KStaticDeleter<KABPrefs> staticDeleter;
+class KABPrefsHelper {
+  public:
+    KABPrefsHelper() : q( 0 ) {}
+    ~KABPrefsHelper() { delete q; }
+    KABPrefs *q;
+};
+
+K_GLOBAL_STATIC( KABPrefsHelper, s_globalKABPrefs )
 
 KABPrefs::KABPrefs()
   : KABPrefsBase()
 {
+  Q_ASSERT(!s_globalKABPrefs->q);
+  s_globalKABPrefs->q = this;
+
   KConfigSkeleton::setCurrentGroup( "General" );
 
   QStringList defaultMap;
@@ -47,12 +55,12 @@ KABPrefs::~KABPrefs()
 
 KABPrefs *KABPrefs::instance()
 {
-  if ( !mInstance ) {
-    staticDeleter.setObject( mInstance, new KABPrefs() );
-    mInstance->readConfig();
+  if (!s_globalKABPrefs->q) {
+    new KABPrefs;
+    s_globalKABPrefs->q->readConfig();
   }
 
-  return mInstance;
+  return s_globalKABPrefs->q;
 }
 
 void KABPrefs::setCategoryDefaults()
@@ -64,8 +72,8 @@ void KABPrefs::setCategoryDefaults()
 
 void KABPrefs::usrReadConfig()
 {
-  config()->setGroup( "General" );
-  mCustomCategories = config()->readListEntry( "Custom Categories" );
+  KConfigGroup group( config(), "General" );
+  mCustomCategories = group.readEntry( "Custom Categories" , QStringList() );
   if ( mCustomCategories.isEmpty() )
     setCategoryDefaults();
 
@@ -75,8 +83,8 @@ void KABPrefs::usrReadConfig()
 
 void KABPrefs::usrWriteConfig()
 {
-  config()->setGroup( "General" );
-  config()->writeEntry( "Custom Categories", mCustomCategories );
+  KConfigGroup group( config(), "General" );
+  group.writeEntry( "Custom Categories", mCustomCategories );
 
   KPimPrefs::usrWriteConfig();
 }
