@@ -21,11 +21,16 @@
     without including the source code for Qt in the source distribution.
 */
 
-#include <qlayout.h>
-#include <qpushbutton.h>
-#include <qtimer.h>
+#include <QPushButton>
+#include <QToolButton>
+#include <QTimer>
+#include <QGridLayout>
+#include <QHeaderView>
+#include <qlabel.h>
+#include <qtooltip.h>
 
 #include <kabc/resource.h>
+#include <kabc/resourceabc.h>
 #include <kdialog.h>
 #include <kglobal.h>
 #include <kiconloader.h>
@@ -35,9 +40,7 @@
 #include <kresources/configdialog.h>
 
 #include "core.h"
-
 #include "resourceselection.h"
-#include <libkdepim/resourceabc.h>
 
 class AddressBookWrapper : public KABC::AddressBook
 {
@@ -50,72 +53,77 @@ class AddressBookWrapper : public KABC::AddressBook
     }
 };
 
-class ResourceItem : public QCheckListItem
+class KABCResourceItem : public QTreeWidgetItem
 {
   public:
-    ResourceItem( KListView *parent, KABC::Resource *resource )
-      : QCheckListItem( parent, resource->resourceName(), CheckBox ),
-        mResource( resource ), mChecked( false ),
+    KABCResourceItem( QTreeWidget *parent, KABC::Resource *resource )
+      : QTreeWidgetItem( parent, QStringList( resource->resourceName() ) ),
+        mResource( resource ),
         mIsSubresource( false ), mSubItemsCreated( false ),
         mResourceIdentifier()
     {
-      setOn( resource->isActive() );
-      setPixmap( 0, KGlobal::iconLoader()->loadIcon( "contents", KIcon::Small ) );
-      mChecked = isOn();
+      setFlags( flags() | Qt::ItemIsUserCheckable );
+      setCheckState( 0, resource->isActive() ? Qt::Checked : Qt::Unchecked );
+      setIcon( 0, KIcon( "x-office-address-book" ) );
     }
 
-    ResourceItem( KPIM::ResourceABC *resourceABC, ResourceItem* parent,
+    KABCResourceItem( KABC::ResourceABC *resourceABC, KABCResourceItem* parent,
                   const QString& resourceIdent )
-      : QCheckListItem( parent, resourceABC->subresourceLabel( resourceIdent ), CheckBox ),
-        mResource( resourceABC ), mChecked( false ),
+      : QTreeWidgetItem( parent, QStringList( resourceABC->subresourceLabel( resourceIdent ) ) ),
+        mResource( resourceABC ),
         mIsSubresource( true ), mSubItemsCreated( false ),
         mResourceIdentifier( resourceIdent )
     {
-      KPIM::ResourceABC* res = dynamic_cast<KPIM::ResourceABC *>( mResource );
-      setOn( res->subresourceActive( mResourceIdentifier ) );
-      setPixmap( 0, KGlobal::iconLoader()->loadIcon( "contents", KIcon::Small ) );
-      mChecked = isOn();
+      setFlags( flags() | Qt::ItemIsUserCheckable );
+      KABC::ResourceABC* res = static_cast<KABC::ResourceABC *>( mResource );
+      setCheckState( 0, res->subresourceActive( mResourceIdentifier ) ? Qt::Checked : Qt::Unchecked );
+      setIcon( 0, KIcon( "x-office-address-book" ) );
+
+      treeWidget()->setRootIsDecorated( true );
+    }
+
+    ~KABCResourceItem()
+    {
+        qDebug( ) << "Deleting Item";
     }
 
     void createSubresourceItems();
-
-    void setChecked( bool state ) { mChecked = state; }
-    bool checked() const { return mChecked; }
     KABC::Resource *resource() const { return mResource; }
     QString resourceIdentifier() const { return mResourceIdentifier; }
     bool isSubResource() const { return mIsSubresource; }
 
-    virtual void stateChange( bool active );
-
   private:
     KABC::Resource * const mResource;
-    bool mChecked;
     const bool mIsSubresource;
     bool mSubItemsCreated;
     const QString mResourceIdentifier;
 };
 
 // Comes from korganizer/resourceview.cpp
-void ResourceItem::createSubresourceItems()
+void KABCResourceItem::createSubresourceItems()
 {
-  KPIM::ResourceABC* res = dynamic_cast<KPIM::ResourceABC *>( mResource );
-  QStringList subresources;
-  if ( res )
-    subresources = res->subresources();
-  if ( !subresources.isEmpty() ) {
-    setOpen( true );
-    setExpandable( true );
-    // This resource has subresources
-    QStringList::ConstIterator it;
-    for ( it = subresources.begin(); it != subresources.end(); ++it ) {
-      (void)new ResourceItem( res, this, *it );
+  if ( !mIsSubresource && !mSubItemsCreated ) {
+    KABC::ResourceABC* res = dynamic_cast<KABC::ResourceABC *>( mResource );
+    QStringList subresources;
+    if ( res )
+      subresources = res->subresources();
+    if ( !subresources.isEmpty() ) {
+      setExpanded( true );
+
+      // This resource has subresources
+      QStringList::ConstIterator it;
+      for ( it = subresources.begin(); it != subresources.end(); ++it ) {
+        (void)new KABCResourceItem( res, this, *it );
+      }
     }
+    mSubItemsCreated = true;
+
+    setExpanded( childCount() > 0 );
   }
-  mSubItemsCreated = true;
 }
 
 // TODO: connect this to some signalResourceModified
-// void ResourceItem::setGuiState()
+// void KABCResourceItem::setGuiState()
 // {
 //   if ( mIsSubresource )
 //     setOn( mResource->subresourceActive( mResourceIdentifier ) );
@@ -123,21 +131,10 @@ void ResourceItem::createSubresourceItems()
 //     setOn( mResource->isActive() );
 // }
 
-void ResourceItem::stateChange( bool active )
-{
-  //kdDebug(5720) << k_funcinfo << this << " " << text( 0 ) << " active=" << active << endl;
-  if ( active && !mIsSubresource ) {
-    if ( !mSubItemsCreated )
-      createSubresourceItems();
-  }
-
-  setOpen( active && childCount() > 0 );
-}
-
 ////
 
-ResourceSelection::ResourceSelection( KAB::Core *core, QWidget *parent, const char *name )
-  : KAB::ExtensionWidget( core, parent, name ), mManager( 0 )
+ResourceSelection::ResourceSelection( KAB::Core *core, QWidget *parent )
+  : KAB::ExtensionWidget( core, parent ), mManager( 0 )
 {
   initGUI();
 
@@ -148,8 +145,8 @@ ResourceSelection::ResourceSelection( KAB::Core *core, QWidget *parent, const ch
   connect( mEditButton, SIGNAL( clicked() ), SLOT( edit() ) );
   connect( mRemoveButton, SIGNAL( clicked() ), SLOT( remove() ) );
 
-  connect( mListView, SIGNAL( clicked( QListViewItem* ) ),
-           SLOT( currentChanged( QListViewItem* ) ) );
+  connect( mListView, SIGNAL( itemClicked( QTreeWidgetItem *, int ) ),
+           SLOT( currentChanged( QTreeWidgetItem * ) ) );
 
   QTimer::singleShot( 0, this, SLOT( updateView() ) );
 }
@@ -180,18 +177,18 @@ void ResourceSelection::add()
   if ( !ok )
     return;
 
-  QString type = types[ descs.findIndex( desc ) ];
+  QString type = types[ descs.indexOf( desc ) ];
 
   // Create new resource
   KABC::Resource *resource = mManager->createResource( type );
   if ( !resource ) {
-    KMessageBox::error( this, i18n("<qt>Unable to create an address book of type <b>%1</b>.</qt>")
-                              .arg( type ) );
+    KMessageBox::error( this, i18n("<qt>Unable to create an address book of type <b>%1</b>.</qt>",
+                                type ) );
     return;
   }
 
-  resource->setResourceName( i18n( "%1 address book" ).arg( type ) );
-  resource->setAddressBook(core()->addressBook());
+  resource->setResourceName( i18n( "%1 address book", type ) );
+  resource->setAddressBook( core()->addressBook() );
 
   KRES::ConfigDialog dlg( this, QString( "contact" ), resource );
 
@@ -209,7 +206,7 @@ void ResourceSelection::add()
 
 void ResourceSelection::edit()
 {
-  ResourceItem *item = selectedItem();
+  KABCResourceItem *item = selectedItem();
   if ( !item )
     return;
 
@@ -226,14 +223,14 @@ void ResourceSelection::edit()
 
 void ResourceSelection::remove()
 {
-  ResourceItem *item = selectedItem();
+  KABCResourceItem *item = selectedItem();
   if ( !item )
     return;
 
   int result = KMessageBox::warningContinueCancel( this,
-        i18n( "<qt>Do you really want to remove the address book <b>%1</b>?</qt>" )
-        .arg( item->resource()->resourceName() ), "",
-        KGuiItem( i18n( "&Remove" ), "editdelete" ) );
+        i18n( "<qt>Do you really want to remove the address book <b>%1</b>?</qt>" ,
+          item->resource()->resourceName() ), "",
+        KGuiItem( i18n( "&Remove" ), "edit-delete" ) );
   if ( result == KMessageBox::Cancel )
     return;
 
@@ -245,9 +242,9 @@ void ResourceSelection::remove()
   updateView();
 }
 
-void ResourceSelection::currentChanged( QListViewItem *item )
+void ResourceSelection::currentChanged( QTreeWidgetItem *item )
 {
-  ResourceItem *resItem = static_cast<ResourceItem*>( item );
+  KABCResourceItem *resItem = static_cast<KABCResourceItem*>( item );
   bool state = (resItem && !resItem->isSubResource() );
 
   mEditButton->setEnabled( state );
@@ -258,33 +255,32 @@ void ResourceSelection::currentChanged( QListViewItem *item )
 
   KABC::Resource *resource = resItem->resource();
 
-  if ( resItem->checked() != resItem->isOn() ) {
-    resItem->setChecked( resItem->isOn() );
-    if ( resItem->isSubResource() ) {
-      KPIM::ResourceABC *res = dynamic_cast<KPIM::ResourceABC *>( resource );
-      res->setSubresourceActive( resItem->resourceIdentifier(), resItem->isOn() );
-      mManager->change( resource );
+  resItem->createSubresourceItems();
+
+  if ( resItem->isSubResource() ) {
+    KABC::ResourceABC *res = static_cast<KABC::ResourceABC *>( resource );
+    res->setSubresourceActive( resItem->resourceIdentifier(), resItem->checkState( 0 ) == Qt::Checked );
+    mManager->change( resource );
+  } else {
+    resource->setActive( resItem->checkState( 0 ) == Qt::Checked );
+    mManager->change( resource );
+
+    if ( resItem->checkState( 0 ) == Qt::Checked ) {
+      if ( !resource->addressBook() )
+        resource->setAddressBook( core()->addressBook() );
+
+      if ( !resource->isOpen() )
+        resource->open();
+
+      resource->asyncLoad();
     } else {
-      resource->setActive( resItem->isOn() );
-      mManager->change( resource );
-
-      if ( resItem->checked() ) {
-        if ( !resource->addressBook() )
-          resource->setAddressBook( core()->addressBook() );
-
-        if ( !resource->isOpen() )
-          resource->open();
-
-        resource->asyncLoad();
-      } else {
-        resource->close();
-      }
+      resource->close();
     }
-
-    mLastResource = resource->identifier();
-    core()->addressBook()->emitAddressBookChanged();
-    //updateView();
   }
+
+  mLastResource = resource->identifier();
+  core()->addressBook()->emitAddressBookChanged();
+  //updateView();
 }
 
 void ResourceSelection::updateView()
@@ -297,33 +293,33 @@ void ResourceSelection::updateView()
   KRES::Manager<KABC::Resource>::Iterator it;
   for ( it = mManager->begin(); it != mManager->end(); ++it ) {
 
-    new ResourceItem( mListView, *it );
-    KPIM::ResourceABC* resource = dynamic_cast<KPIM::ResourceABC *>( *it );
+    KABCResourceItem *item = new KABCResourceItem( mListView, *it );
+    KABC::ResourceABC* resource = dynamic_cast<KABC::ResourceABC *>( *it );
     if ( resource ) {
       disconnect( resource, 0, this, 0 );
-      connect( resource, SIGNAL( signalSubresourceAdded( KPIM::ResourceABC *,
+      connect( resource, SIGNAL( signalSubresourceAdded( KABC::ResourceABC *,
                                                          const QString &, const QString & ) ),
-               SLOT( slotSubresourceAdded( KPIM::ResourceABC *,
+               SLOT( slotSubresourceAdded( KABC::ResourceABC *,
                                            const QString &, const QString & ) ) );
 
-      connect( resource, SIGNAL( signalSubresourceRemoved( KPIM::ResourceABC *,
+      connect( resource, SIGNAL( signalSubresourceRemoved( KABC::ResourceABC *,
                                                            const QString &, const QString & ) ),
-               SLOT( slotSubresourceRemoved( KPIM::ResourceABC *,
+               SLOT( slotSubresourceRemoved( KABC::ResourceABC *,
                                              const QString &, const QString & ) ) );
-      //connect( resource, SIGNAL( resourceSaved( KPIM::ResourceABC * ) ),
-      //         SLOT( closeResource( KPIM::ResourceABC * ) ) );
+      //connect( resource, SIGNAL( resourceSaved( KABC::ResourceABC * ) ),
+      //         SLOT( closeResource( KABC::ResourceABC * ) ) );
+      item->createSubresourceItems();
     }
   }
 
-  QListViewItemIterator itemIt( mListView );
-  while ( itemIt.current() ) {
-    ResourceItem *item = static_cast<ResourceItem*>( itemIt.current() );
+  QTreeWidgetItemIterator iterator( mListView );
+  while ( *iterator ) {
+    KABCResourceItem *item = static_cast< KABCResourceItem * >( *iterator );
     if ( item->resource()->identifier() == mLastResource ) {
-      mListView->setSelected( item, true );
-      mListView->ensureItemVisible( item );
+      item->setSelected( true );
       break;
     }
-    ++itemIt;
+    ++iterator;
   }
 
   core()->addressBook()->emitAddressBookChanged();
@@ -331,62 +327,79 @@ void ResourceSelection::updateView()
 
 
 // Add a new entry
-void ResourceSelection::slotSubresourceAdded( KPIM::ResourceABC *resource,
+void ResourceSelection::slotSubresourceAdded( KABC::ResourceABC *resource,
                                               const QString& /*type*/,
                                               const QString& subResource )
 {
-  kdDebug(5720) << k_funcinfo << resource->resourceName() << " " << subResource << endl;
-  QListViewItem *i = mListView->findItem( resource->resourceName(), 0 );
-  if ( !i )
+  kDebug(5720) << resource->resourceName() << subResource;
+
+  QList< QTreeWidgetItem * > foundItems =
+      mListView->findItems( resource->resourceName(), Qt::MatchExactly );
+
+  if ( foundItems.size() == 0 )
     // Not found
     return;
 
-  ResourceItem *item = static_cast<ResourceItem *>( i );
-  (void)new ResourceItem( resource, item, subResource );
+  KABCResourceItem *item = static_cast<KABCResourceItem *>( foundItems[0] );
+  (void)new KABCResourceItem( resource, item, subResource );
 }
 
 // Remove an entry
-void ResourceSelection::slotSubresourceRemoved( KPIM::ResourceABC* resource,
+void ResourceSelection::slotSubresourceRemoved( KABC::ResourceABC* resource,
                                                 const QString& /*type*/,
                                                 const QString& subResource )
 {
-  kdDebug(5720) << k_funcinfo << resource->resourceName() << " " << subResource << endl;
+  kDebug(5720) << resource->resourceName() << subResource;
   // TODO
   //delete findItemByIdentifier( resource );
   //emitResourcesChanged();
 }
 
-ResourceItem* ResourceSelection::selectedItem() const
+KABCResourceItem* ResourceSelection::selectedItem() const
 {
-  return static_cast<ResourceItem*>( mListView->selectedItem() );
+  return static_cast<KABCResourceItem*>( mListView->currentItem() );
 }
 
 void ResourceSelection::initGUI()
 {
-  QGridLayout *layout = new QGridLayout( this, 2, 3, 2, 5 );
+  QBoxLayout *topLayout = new QVBoxLayout( this );
+  topLayout->setSpacing( KDialog::spacingHint() );
+  QBoxLayout *buttonLayout = new QHBoxLayout();
+  buttonLayout->setSpacing( KDialog::spacingHint() );
+  topLayout->addLayout( buttonLayout );
 
-  mListView = new KListView( this );
-  mListView->addColumn( i18n( "Address Books" ) );
-  mListView->setFullWidth( true );
-  layout->addMultiCellWidget( mListView, 0, 0, 0, 2 );
+  QLabel *abLabel = new QLabel( i18n( "Address Books" ), this );
+  buttonLayout->addWidget( abLabel );
+  buttonLayout->addStretch( 1 );
 
-  mAddButton = new QPushButton( i18n( "Add..." ), this );
-  mEditButton = new QPushButton( i18n( "Edit..." ), this );
+  mAddButton = new QToolButton( this );
+  mAddButton->setIcon( KIcon( "list-add" ) );
+  mAddButton->setToolTip( i18n( "Add addressbook" ) );
+  buttonLayout->addWidget( mAddButton );
+  mEditButton = new QToolButton( this );
+  mEditButton->setIcon( KIcon( "document-properties" ) );
   mEditButton->setEnabled( false );
-  mRemoveButton = new QPushButton( i18n( "Remove" ), this );
+  mEditButton->setToolTip( i18n( "Edit addressbook settings" ) );
+  buttonLayout->addWidget( mEditButton );
+  mRemoveButton = new QToolButton( this );
+  mRemoveButton->setIcon( KIcon( "edit-delete" ) );
   mRemoveButton->setEnabled( false );
+  mRemoveButton->setToolTip( i18n( "Remove addressbook" ) );
+  buttonLayout->addWidget( mRemoveButton );
 
-  layout->addWidget( mAddButton, 1, 0 );
-  layout->addWidget( mEditButton, 1, 1 );
-  layout->addWidget( mRemoveButton, 1, 2 );
+  mListView = new QTreeWidget( this );
+  mListView->setRootIsDecorated( false );
+  mListView->setHeaderLabel( i18n( "Address Books" ) );
+  mListView->header()->hide();
+  topLayout->addWidget( mListView );
 }
 
 class ResourceSelectionFactory : public KAB::ExtensionFactory
 {
   public:
-    KAB::ExtensionWidget *extension( KAB::Core *core, QWidget *parent, const char *name )
+    KAB::ExtensionWidget *extension( KAB::Core *core, QWidget *parent )
     {
-      return new ResourceSelection( core, parent, name );
+      return new ResourceSelection( core, parent );
     }
 
     QString identifier() const
@@ -395,11 +408,6 @@ class ResourceSelectionFactory : public KAB::ExtensionFactory
     }
 };
 
-extern "C" {
-  void *init_libkaddrbk_resourceselection()
-  {
-    return ( new ResourceSelectionFactory );
-  }
-}
+K_EXPORT_PLUGIN(ResourceSelectionFactory)
 
 #include "resourceselection.moc"
