@@ -21,27 +21,26 @@
     without including the source code for Qt in the source distribution.
 */
 
-#include <qlayout.h>
+//Added by qt3to4:
+#include <QVBoxLayout>
 
 #include <kaboutdata.h>
 #include <kdebug.h>
 #include <klocale.h>
-
+#include <kcomponentdata.h>
 #include "kabconfigwidget.h"
 
 #include "kcmkabconfig.h"
 
-#include <kdepimmacros.h>
+#include <kdemacros.h>
+#include <kgenericfactory.h>
 
-extern "C"
-{
-  KDE_EXPORT KCModule *create_kabconfig( QWidget *parent, const char * ) {
-    return new KCMKabConfig( parent, "kcmkabconfig" );
-  }
-}
+K_PLUGIN_FACTORY(KCMKabConfigFactory, registerPlugin<KCMKabConfig>();)
+K_EXPORT_PLUGIN(KCMKabConfigFactory( "kcmkabconfig" ))
 
-KCMKabConfig::KCMKabConfig( QWidget *parent, const char *name )
-  : KCModule( parent, name )
+
+KCMKabConfig::KCMKabConfig( QWidget *parent, const QVariantList & )
+  : KCModule( KCMKabConfigFactory::componentData(), parent )
 {
   QVBoxLayout *layout = new QVBoxLayout( this );
   mConfigWidget = new KABConfigWidget( this, "mConfigWidget" );
@@ -51,12 +50,12 @@ KCMKabConfig::KCMKabConfig( QWidget *parent, const char *name )
 
   load();
 
-  KAboutData *about = new KAboutData( I18N_NOOP( "kcmkabconfig" ),
-                                      I18N_NOOP( "KAddressBook Configure Dialog" ),
-                                      0, 0, KAboutData::License_GPL,
-                                      I18N_NOOP( "(c), 2003 - 2004 Tobias Koenig" ) );
+  KAboutData *about = new KAboutData( I18N_NOOP( "kcmkabconfig" ), 0,
+                                      ki18n( "KAddressBook Configure Dialog" ),
+                                      0, KLocalizedString(), KAboutData::License_GPL,
+                                      ki18n( "(c), 2003 - 2004 Tobias Koenig" ) );
 
-  about->addAuthor( "Tobias Koenig", 0, "tokoe@kde.org" );
+  about->addAuthor( ki18n("Tobias Koenig"), KLocalizedString(), "tokoe@kde.org" );
   setAboutData( about );
 }
 
