@@ -27,16 +27,20 @@
 #include <kcombobox.h>
 #include <klocale.h>
 
-#include <qbuttongroup.h>
-#include <qcombobox.h>
-#include <qheader.h>
-#include <qlabel.h>
-#include <qlayout.h>
-#include <qlistview.h>
-#include <qpushbutton.h>
-#include <qradiobutton.h>
-#include <qstringlist.h>
-#include <qwhatsthis.h>
+#include <QComboBox>
+#include <QGroupBox>
+#include <QLabel>
+#include <QPushButton>
+#include <QRadioButton>
+#include <QStringList>
+
+//Added by qt3to4:
+#include <QVBoxLayout>
+#include <QGridLayout>
+#include <ktoolinvocation.h>
+#include <kglobal.h>
+
+#include <libkdepim/categoryselectdialog.h>
 
 #include "core.h"
 #include "kabprefs.h"
@@ -44,46 +48,48 @@
 #include "xxportselectdialog.h"
 
 XXPortSelectDialog::XXPortSelectDialog( KAB::Core *core, bool sort,
-                                        QWidget* parent, const char* name )
-    : KDialogBase( Plain, i18n( "Choose Which Contacts to Export" ), Help | Ok | Cancel,
-                   Ok, parent, name, true, true ), mCore( core ),
+                                        QWidget* parent )
+    : KDialog( parent ), mCore( core ),
       mUseSorting( sort )
 {
+  setCaption( i18n( "Choose Which Contacts to Export" ) );
+  setButtons( Help | Ok | Cancel );
+  setDefaultButton( Ok );
+  setModal( true );
+  showButtonSeparator( true );
+
   initGUI();
 
   connect( mFiltersCombo, SIGNAL( activated( int ) ),
            SLOT( filterChanged( int ) ) );
-  connect( mCategoriesView, SIGNAL( clicked( QListViewItem* ) ),
-           SLOT( categoryClicked( QListViewItem* ) ) );
 
   // setup filters
-  mFilters = Filter::restore( kapp->config(), "Filter" );
+  mFilters = Filter::restore( KGlobal::config().data(), "Filter" );
   Filter::List::ConstIterator filterIt;
   QStringList filters;
   for ( filterIt = mFilters.begin(); filterIt != mFilters.end(); ++filterIt )
     filters.append( (*filterIt).name() );
 
-  mFiltersCombo->insertStringList( filters );
+  mFiltersCombo->addItems( filters );
   mUseFilters->setEnabled( filters.count() > 0 );
 
   // setup categories
-  const QStringList categories =  KABPrefs::instance()->customCategories();
-  QStringList::ConstIterator it;
-  for ( it = categories.begin(); it != categories.end(); ++it )
-    new QCheckListItem( mCategoriesView, *it, QCheckListItem::CheckBox );
+  const QStringList categories = KABPrefs::instance()->customCategories();
+  mCategoriesView->setCategories( categories );
   mUseCategories->setEnabled( categories.count() > 0 );
 
   int count = mCore->selectedUIDs().count();
   mUseSelection->setEnabled( count != 0 );
   mUseSelection->setChecked( count  > 0 );
 
-  mSortTypeCombo->insertItem( i18n( "Ascending" ) );
-  mSortTypeCombo->insertItem( i18n( "Descending" ) );
+  mSortTypeCombo->addItem( i18n( "Ascending" ) );
+  mSortTypeCombo->addItem( i18n( "Descending" ) );
 
   mFields = mCore->addressBook()->fields( KABC::Field::All );
   KABC::Field::List::ConstIterator fieldIt;
   for ( fieldIt = mFields.begin(); fieldIt != mFields.end(); ++fieldIt )
-    mFieldCombo->insertItem( (*fieldIt)->label() );
+    mFieldCombo->addItem( (*fieldIt)->label() );
+  connect(this,SIGNAL(helpClicked()),this,SLOT(slotHelp()));
 }
 
 KABC::AddresseeList XXPortSelectDialog::contacts()
@@ -132,8 +138,8 @@ KABC::AddresseeList XXPortSelectDialog::contacts()
   }
 
   if ( mUseSorting ) {
-    list.setReverseSorting( mSortTypeCombo->currentItem() == 1 );
-    uint pos = mFieldCombo->currentItem();
+    list.setReverseSorting( mSortTypeCombo->currentIndex() == 1 );
+    int pos = mFieldCombo->currentIndex();
     if ( pos < mFields.count() )
       list.sortByField( mFields[ pos ] );
   }
@@ -143,16 +149,8 @@ KABC::AddresseeList XXPortSelectDialog::contacts()
 
 QStringList XXPortSelectDialog::categories() const
 {
-  QStringList list;
-
-  QListViewItemIterator it( mCategoriesView );
-  for ( ; it.current(); ++it ) {
-    QCheckListItem* qcli = static_cast<QCheckListItem*>(it.current());
-    if ( qcli->isOn() )
-      list.append( it.current()->text( 0 ) );
-  }
-
-  return list;
+  QString lst;
+  return mCategoriesView->selectedCategories( lst );
 }
 
 void XXPortSelectDialog::filterChanged( int )
@@ -160,75 +158,75 @@ void XXPortSelectDialog::filterChanged( int )
   mUseFilters->setChecked( true );
 }
 
-void XXPortSelectDialog::categoryClicked( QListViewItem *i )
+void XXPortSelectDialog::categoryClicked()
 {
-  if ( !i )
-    return;
-
-  QCheckListItem *qcli = static_cast<QCheckListItem*>( i );
-  if ( qcli->isOn() )
-    mUseCategories->setChecked( true );
+  mUseCategories->setChecked( true );
 }
 
 void XXPortSelectDialog::slotHelp()
 {
-  kapp->invokeHelp( "import-and-export" );
+  KToolInvocation::invokeHelp( "import-and-export" );
 }
 
 void XXPortSelectDialog::initGUI()
 {
-  QFrame *page = plainPage();
+  QWidget *page = new QWidget( this );
+  setMainWidget( page );
 
-  QVBoxLayout *topLayout = new QVBoxLayout( page, KDialog::marginHint(),
-                                            KDialog::spacingHint() );
+  QVBoxLayout *topLayout = new QVBoxLayout( page );
+  topLayout->setSpacing( KDialog::spacingHint() );
+  topLayout->setMargin( 0 );
 
   QLabel *label = new QLabel( i18n( "Which contacts do you want to export?" ), page );
   topLayout->addWidget( label );
 
-  mButtonGroup = new QButtonGroup( i18n( "Selection" ), page );
-  mButtonGroup->setColumnLayout( 0, Qt::Vertical );
-  mButtonGroup->layout()->setSpacing( KDialog::spacingHint() );
-  mButtonGroup->layout()->setMargin( KDialog::marginHint() );
-
-  QGridLayout *groupLayout = new QGridLayout( mButtonGroup->layout() );
+  mButtonGroup = new QGroupBox( i18n( "Selection" ), page );
+  QGridLayout *groupLayout = new QGridLayout();
+  groupLayout->setSpacing( KDialog::spacingHint() );
+  groupLayout->setMargin( KDialog::marginHint() );
   groupLayout->setAlignment( Qt::AlignTop );
+  mButtonGroup->setLayout( groupLayout );
 
   mUseWholeBook = new QRadioButton( i18n( "&All contacts" ), mButtonGroup );
   mUseWholeBook->setChecked( true );
-  QWhatsThis::add( mUseWholeBook, i18n( "Export the entire address book" ) );
+  mUseWholeBook->setWhatsThis( i18n( "Export the entire address book" ) );
   groupLayout->addWidget( mUseWholeBook, 0, 0 );
-  mUseSelection = new QRadioButton( i18n("&Selected contact", "&Selected contacts (%n selected)", mCore->selectedUIDs().count() ), mButtonGroup );
-  QWhatsThis::add( mUseSelection, i18n( "Only export contacts selected in KAddressBook.\n"
+  mUseSelection = new QRadioButton( i18np( "&Selected contact", "&Selected contacts (%1 selected)", mCore->selectedUIDs().count() ), mButtonGroup );
+  mUseSelection->setWhatsThis( i18n( "Only export contacts selected in KAddressBook.\n"
                                         "This option is disabled if no contacts are selected." ) );
   groupLayout->addWidget( mUseSelection, 1, 0 );
 
   mUseFilters = new QRadioButton( i18n( "Contacts matching &filter" ), mButtonGroup );
-  QWhatsThis::add( mUseFilters, i18n( "Only export contacts matching the selected filter.\n"
+  mUseFilters->setWhatsThis( i18n( "Only export contacts matching the selected filter.\n"
                                      "This option is disabled if you have not defined any filters" ) );
   groupLayout->addWidget( mUseFilters, 2, 0 );
 
   mUseCategories = new QRadioButton( i18n( "Category &members" ), mButtonGroup );
-  QWhatsThis::add( mUseCategories, i18n( "Only export contacts who are members of a category that is checked on the list to the left.\n"
+  mUseCategories->setWhatsThis( i18n( "Only export contacts who are members of a category that is checked on the list to the left.\n"
                                        "This option is disabled if you have no categories." ) );
   groupLayout->addWidget( mUseCategories, 3, 0, Qt::AlignTop );
 
-  mFiltersCombo = new QComboBox( false, mButtonGroup );
-  QWhatsThis::add( mFiltersCombo, i18n( "Select a filter to decide which contacts to export." ) );
+  mFiltersCombo = new QComboBox( mButtonGroup );
+  mFiltersCombo->setEditable( false );
+  mFiltersCombo->setWhatsThis( i18n( "Select a filter to decide which contacts to export." ) );
   groupLayout->addWidget( mFiltersCombo, 2, 1 );
 
-  mCategoriesView = new QListView( mButtonGroup );
-  mCategoriesView->addColumn( "" );
-  mCategoriesView->header()->hide();
-  QWhatsThis::add( mCategoriesView, i18n( "Check the categories whose members you want to export." ) );
+  mCategoriesView = new KPIM::CategorySelectWidget( mButtonGroup, KABPrefs::instance() );
+  mCategoriesView->hideButton();
+  mCategoriesView->layout()->setMargin( 0 );
+  mCategoriesView->setWhatsThis( i18n( "Check the categories whose members you want to print." ) );
   groupLayout->addWidget( mCategoriesView, 3, 1 );
+  connect( mCategoriesView->listView(), 
+           SIGNAL( itemClicked( QTreeWidgetItem *, int ) ),
+           this, SLOT( categoryClicked() ) );
 
   topLayout->addWidget( mButtonGroup );
 
-  QButtonGroup *sortingGroup = new QButtonGroup( i18n( "Sorting" ), page );
-  sortingGroup->setColumnLayout( 0, Qt::Vertical );
-  QGridLayout *sortLayout = new QGridLayout( sortingGroup->layout(), 2, 2,
-                                             KDialog::spacingHint() );
+  QGroupBox *sortingGroup = new QGroupBox( i18n( "Sorting" ), page );
+  QGridLayout *sortLayout = new QGridLayout();
+  sortLayout->setSpacing( KDialog::spacingHint() );
   sortLayout->setAlignment( Qt::AlignTop );
+  sortingGroup->setLayout( sortLayout );
 
   label = new QLabel( i18n( "Criterion:" ), sortingGroup );
   sortLayout->addWidget( label, 0, 0 );
