@@ -20,12 +20,12 @@
 #ifndef GROUPCONFIGDIALOG_H
 #define GROUPCONFIGDIALOG_H
 
-#include <kdialogbase.h>
+#include <kdialog.h>
 
 class GroupConfig;
 class SyncProcess;
 
-class GroupConfigDialog : public KDialogBase
+class GroupConfigDialog : public KDialog
 {
   Q_OBJECT
 
@@ -35,6 +35,11 @@ class GroupConfigDialog : public KDialogBase
 
   protected slots:
     void slotOk();
+    void slotUser1();
+    void slotUser2();
+
+  private slots:
+    void memberSelected( bool );
 
   private:
     GroupConfig *mConfigWidget;
