@@ -19,11 +19,9 @@
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
 
 #include "kmacctimap.h"
+
 using KMail::SieveConfig;
 
 #include "kmmessage.h"
@@ -45,12 +43,14 @@ using KMail::ImapAccountBase;
 #include "progressmanager.h"
 using KPIM::ProgressItem;
 using KPIM::ProgressManager;
+
 #include <kio/scheduler.h>
 #include <kio/slave.h>
 #include <kmessagebox.h>
 #include <kdebug.h>
+#include <qtextdocument.h>
 
-#include <qstylesheet.h>
+#include <QList>
 
 #include <errno.h>
 
@@ -62,21 +62,21 @@ KMAcctImap::KMAcctImap(AccountManager* aOwner, const QString& aAccountName, uint
   mFolder = 0;
   mScheduler = 0;
   mNoopTimer.start( 60000 ); // // send a noop every minute
-  mOpenFolders.setAutoDelete(true);
   connect(kmkernel->imapFolderMgr(), SIGNAL(changed()),
       this, SLOT(slotUpdateFolderList()));
+  mErrorTimer.setSingleShot( true );
   connect(&mErrorTimer, SIGNAL(timeout()), SLOT(slotResetConnectionError()));
 
-  QString serNumUri = locateLocal( "data", "kmail/unfiltered." +
-				   QString("%1").arg(KAccount::id()) );
+  QString serNumUri = KStandardDirs::locateLocal( "data", "kmail/unfiltered." +
+                                            QString("%1").arg(KAccount::id()) );
   KConfig config( serNumUri );
-  QStringList serNums = config.readListEntry( "unfiltered" );
-  mFilterSerNumsToSave.setAutoDelete( false );
+  QStringList serNums =
+      config.group("<default>").readEntry( "unfiltered", QStringList() );
 
   for ( QStringList::ConstIterator it = serNums.begin();
 	it != serNums.end(); ++it ) {
       mFilterSerNums.append( (*it).toUInt() );
-      mFilterSerNumsToSave.insert( *it, (const int *)1 );
+      mFilterSerNumsToSave.insert( *it, 1 );
     }
 }
 
@@ -86,21 +86,17 @@ KMAcctImap::~KMAcctImap()
 {
   killAllJobs( true );
 
-  QString serNumUri = locateLocal( "data", "kmail/unfiltered." +
-				   QString("%1").arg(KAccount::id()) );
+  QString serNumUri = KStandardDirs::locateLocal( "data", "kmail/unfiltered." +
+                                            QString("%1").arg(KAccount::id()) );
   KConfig config( serNumUri );
   QStringList serNums;
-  QDictIterator<int> it( mFilterSerNumsToSave );
-  for( ; it.current(); ++it )
-      serNums.append( it.currentKey() );
-  config.writeEntry( "unfiltered", serNums );
-}
-
-
-//-----------------------------------------------------------------------------
-QString KMAcctImap::type() const
-{
-  return "imap";
+  QHashIterator<QString, int> it( mFilterSerNumsToSave );
+  while ( it.hasNext() ) {
+    it.next();
+    serNums.append( it.key() );
+  }
+  config.group("<default>").writeEntry( "unfiltered", serNums );
+  qDeleteAll( mOpenFolders );
 }
 
 //-----------------------------------------------------------------------------
@@ -136,19 +132,35 @@ bool KMAcctImap::handleError( int errorCode, const QString &errorMsg, KIO::Job*
   return ImapAccountBase::handleError( errorCode, errorMsg, job, context, abortSync );
 }
 
+void KMAcctImap::registerJob( KMail::ImapJob *job )
+{
+  if ( !job )
+    return;
+  if ( mImapJobList.contains( job ) )
+    return;
+  mImapJobList.append( job );
+}
+
+void KMAcctImap::unregisterJob( KMail::ImapJob *job )
+{
+  if ( !job )
+    return;
+  mImapJobList.removeAll( job );
+}
+
 
 //-----------------------------------------------------------------------------
 void KMAcctImap::killAllJobs( bool disconnectSlave )
 {
-  QMap<KIO::Job*, jobData>::Iterator it = mapJobData.begin();
+  QMap<KJob*, jobData>::Iterator it = mapJobData.begin();
   for ( ; it != mapJobData.end(); ++it)
   {
-    QPtrList<KMMessage> msgList = (*it).msgList;
-    QPtrList<KMMessage>::Iterator it2 = msgList.begin();
+    QList<KMMessage*> msgList = (*it).msgList;
+    QList<KMMessage*>::Iterator it2 = msgList.begin();
     for ( ; it2 != msgList.end(); ++it2 ) {
        KMMessage *msg = *it2;
        if ( msg->transferInProgress() ) {
-          kdDebug(5006) << "KMAcctImap::killAllJobs - resetting mail" << endl;
+          kDebug(5006) << "Resetting mail";
           msg->setTransferInProgress( false );
        }
     }
@@ -160,7 +172,7 @@ void KMAcctImap::killAllJobs( bool disconnectSlave )
       fld->quiet(false);
       fld->setContentState(KMFolderImap::imapNoInformation);
       fld->setSubfolderState(KMFolderImap::imapNoInformation);
-      fld->sendFolderComplete(FALSE);
+      fld->sendFolderComplete(false);
       fld->removeJobs();
     }
     if ( (*it).progressItem )
@@ -175,16 +187,12 @@ void KMAcctImap::killAllJobs( bool disconnectSlave )
   }
   // remove the jobs
   mapJobData.clear();
-  // KMAccount::deleteFolderJobs(); doesn't work here always, it deletes jobs from
-  // its own mJobList instead of our mJobList...
   KMAccount::deleteFolderJobs();
-  QPtrListIterator<ImapJob> it2( mJobList );
-  while ( it2.current() ) {
-    ImapJob *job = it2.current();
-    ++it2;
-    job->kill();
-  }
-  mJobList.clear();
+
+  while( mImapJobList.count() > 0 )
+    mImapJobList.takeFirst()->kill();
+
+  mImapJobList.clear();
   // make sure that no new-mail-check is blocked
   if (mCountRemainChecks > 0)
   {
@@ -201,11 +209,10 @@ void KMAcctImap::killAllJobs( bool disconnectSlave )
 void KMAcctImap::ignoreJobsForMessage( KMMessage* msg )
 {
   if (!msg) return;
-  QPtrListIterator<ImapJob> it( mJobList );
-  while ( it.current() )
+  QList<ImapJob*>::const_iterator it;
+  for ( it = mImapJobList.begin(); (*it) && it != mImapJobList.constEnd(); ++it )
   {
-    ImapJob *job = it.current();
-    ++it;
+    ImapJob *job = (*it);
     if ( job->msgList().first() == msg )
     {
       job->kill();
@@ -216,11 +223,10 @@ void KMAcctImap::ignoreJobsForMessage( KMMessage* msg )
 //-----------------------------------------------------------------------------
 void KMAcctImap::ignoreJobsForFolder( KMFolder* folder )
 {
-  QPtrListIterator<ImapJob> it( mJobList );
-  while ( it.current() )
+  QList<ImapJob*>::const_iterator it;
+  for ( it = mImapJobList.begin(); (*it) && it != mImapJobList.constEnd(); ++it )
   {
-    ImapJob *job = it.current();
-    ++it;
+    ImapJob *job = (*it);
     if ( !job->msgList().isEmpty() && job->msgList().first()->parent() == folder )
     {
       job->kill();
@@ -232,13 +238,13 @@ void KMAcctImap::ignoreJobsForFolder( KMFolder* folder )
 void KMAcctImap::removeSlaveJobsForFolder( KMFolder* folder )
 {
   // Make sure the folder is not referenced in any kio slave jobs
-  QMap<KIO::Job*, jobData>::Iterator it = mapJobData.begin();
+  QMap<KJob*, jobData>::Iterator it = mapJobData.begin();
   while ( it != mapJobData.end() ) {
-     QMap<KIO::Job*, jobData>::Iterator i = it;
+     QMap<KJob*, jobData>::Iterator i = it;
      it++;
      if ( (*i).parent ) {
         if ( (*i).parent == folder ) {
-           mapJobData.remove(i);
+           mapJobData.erase(i);
         }
      }
   }
@@ -248,8 +254,8 @@ void KMAcctImap::removeSlaveJobsForFolder( KMFolder* folder )
 void KMAcctImap::cancelMailCheck()
 {
   // Make list of folders to reset, like in killAllJobs
-  QValueList<KMFolderImap*> folderList;
-  QMap<KIO::Job*, jobData>::Iterator it = mapJobData.begin();
+  QList<KMFolderImap*> folderList;
+  QMap<KJob*, jobData>::Iterator it = mapJobData.begin();
   for (; it != mapJobData.end(); ++it) {
     if ( (*it).cancellable && (*it).parent ) {
       folderList << static_cast<KMFolderImap*>((*it).parent->storage());
@@ -261,19 +267,18 @@ void KMAcctImap::cancelMailCheck()
   killAllJobs( true );
   // emit folderComplete, this is important for
   // KMAccount::checkingMail() to be reset, in case we restart checking mail later.
-  for( QValueList<KMFolderImap*>::Iterator it = folderList.begin(); it != folderList.end(); ++it ) {
+  for( QList<KMFolderImap*>::Iterator it = folderList.begin(); it != folderList.end(); ++it ) {
     KMFolderImap *fld = *it;
-    fld->sendFolderComplete(FALSE);
+    fld->sendFolderComplete(false);
   }
 }
 
 //-----------------------------------------------------------------------------
 void KMAcctImap::processNewMail(bool interactive)
 {
-  kdDebug() << "processNewMail " << mCheckingSingleFolder << ",status="<<makeConnection()<<endl;
-  if (!mFolder || !mFolder->folder() || !mFolder->folder()->child() ||
-      makeConnection() == ImapAccountBase::Error)
-  {
+  kDebug(5006) <<"processNewMail" << mCheckingSingleFolder <<",status="<<makeConnection();
+  if ( !mFolder || !mFolder->folder() || !mFolder->folder()->child() ||
+       makeConnection() == ImapAccountBase::Error ) {
     // checks for mCountRemainChecks
     checkDone( false, CheckError );
     mCountRemainChecks = 0;
@@ -297,8 +302,8 @@ void KMAcctImap::processNewMail(bool interactive)
   mMailCheckProgressItem =
     ProgressManager::createProgressItem(
         "MailCheckAccount" + name(),
-        i18n("Checking account: %1" ).arg( QStyleSheet::escape( name() ) ),
-        QString::null, // status
+        i18n( "Checking account: %1", Qt::escape( name() ) ),
+        QString(), // status
         true, // can be canceled
         useSSL() || useTLS() );
 
@@ -308,7 +313,7 @@ void KMAcctImap::processNewMail(bool interactive)
             this,
             SLOT( slotMailCheckCanceled() ) );
 
-  QValueList<QGuardedPtr<KMFolder> >::Iterator it;
+  QList<QPointer<KMFolder> >::Iterator it;
   // first get the current count of unread-messages
   mCountRemainChecks = 0;
   mCountUnread = 0;
@@ -323,11 +328,9 @@ void KMAcctImap::processNewMail(bool interactive)
   }
   bool gotError = false;
   // then check for new mails
-  for (it = mMailCheckFolders.begin(); it != mMailCheckFolders.end(); ++it)
-  {
+  for ( it = mMailCheckFolders.begin(); it != mMailCheckFolders.end(); ++it ) {
     KMFolder *folder = *it;
-    if (folder && !folder->noContent())
-    {
+    if ( folder && !folder->noContent() ) {
       KMFolderImap *imapFolder = static_cast<KMFolderImap*>(folder->storage());
       if ( imapFolder->getContentState() != KMFolderImap::imapListingInProgress
         && imapFolder->getContentState() != KMFolderImap::imapDownloadInProgress )
@@ -335,26 +338,25 @@ void KMAcctImap::processNewMail(bool interactive)
         // connect the result-signals for new-mail-notification
         mCountRemainChecks++;
 
-        if (imapFolder->isSelected()) {
+        if ( imapFolder->isSelected() ) {
           connect(imapFolder, SIGNAL(folderComplete(KMFolderImap*, bool)),
               this, SLOT(postProcessNewMail(KMFolderImap*, bool)));
           imapFolder->getFolder();
         } else if ( kmkernel->filterMgr()->atLeastOneIncomingFilterAppliesTo( id() ) &&
                     imapFolder->folder()->isSystemFolder() &&
                     imapFolder->imapPath() == "/INBOX/" ) {
-          imapFolder->open("acctimap"); // will be closed in the folderSelected slot
+          // will be closed in the folderSelected slot
+          imapFolder->open( "acctimap" );
           // first get new headers before we select the folder
           imapFolder->setSelected( true );
           connect( imapFolder, SIGNAL( folderComplete( KMFolderImap*, bool ) ),
                    this, SLOT( slotFolderSelected( KMFolderImap*, bool) ) );
           imapFolder->getFolder();
-        }
-        else {
+        } else {
           connect(imapFolder, SIGNAL(numUnreadMsgsChanged(KMFolder*)),
-              this, SLOT(postProcessNewMail(KMFolder*)));
+                  this, SLOT(postProcessNewMail(KMFolder*)));
           bool ok = imapFolder->processNewMail(interactive); // this removes the local kmfolderimap if its imapPath is somehow empty, and removing it calls createFolderList, invalidating mMailCheckFolders, and causing a crash
-          if (!ok)
-          {
+          if ( !ok ) {
             // there was an error so cancel
             mCountRemainChecks--;
             gotError = true;
@@ -397,14 +399,14 @@ void KMAcctImap::postProcessNewMail( KMFolder * folder )
   if ( mMailCheckProgressItem ) {
     mMailCheckProgressItem->incCompletedItems();
     mMailCheckProgressItem->updateProgress();
-    mMailCheckProgressItem->setStatus( folder->prettyURL() + i18n(" completed") );
+    mMailCheckProgressItem->setStatus( folder->prettyUrl() + i18n(" completed") );
   }
   mCountRemainChecks--;
 
   // count the unread messages
   const QString folderId = folder->idString();
   int newInFolder = folder->countUnread();
-  if ( mUnreadBeforeCheck.find( folderId ) != mUnreadBeforeCheck.end() )
+  if ( mUnreadBeforeCheck.contains( folderId )  )
     newInFolder -= mUnreadBeforeCheck[folderId];
   if ( newInFolder > 0 ) {
     addToNewInFolder( folderId, newInFolder );
@@ -412,41 +414,40 @@ void KMAcctImap::postProcessNewMail( KMFolder * folder )
   }
 
   // Filter messages
-  QValueListIterator<Q_UINT32> filterIt = mFilterSerNums.begin();
-  QValueList<Q_UINT32> inTransit;
+  QListIterator<quint32> filterIt( mFilterSerNums );
+  QList<quint32> inTransit;
 
   if (ActionScheduler::isEnabled() ||
       kmkernel->filterMgr()->atLeastOneOnlineImapFolderTarget()) {
     KMFilterMgr::FilterSet set = KMFilterMgr::Inbound;
-    QValueList<KMFilter*> filters = kmkernel->filterMgr()->filters();
+    QList<KMFilter*> filters = kmkernel->filterMgr()->filters();
     if (!mScheduler) {
-	mScheduler = new KMail::ActionScheduler( set, filters );
-	mScheduler->setAccountId( id() );
-	connect( mScheduler, SIGNAL(filtered(Q_UINT32)), this, SLOT(slotFiltered(Q_UINT32)) );
+      mScheduler = new KMail::ActionScheduler( set, filters );
+      mScheduler->setAccountId( id() );
+      connect( mScheduler, SIGNAL(filtered(quint32)), this, SLOT(slotFiltered(quint32)) );
     } else {
-	mScheduler->setFilterList( filters );
+      mScheduler->setFilterList( filters );
     }
   }
 
-  while (filterIt != mFilterSerNums.end()) {
+  while ( filterIt.hasNext() ) {
     int idx = -1;
     KMFolder *folder = 0;
     KMMessage *msg = 0;
-    KMMsgDict::instance()->getLocation( *filterIt, &folder, &idx );
+    quint32 sernum = filterIt.next();
+    KMMsgDict::instance()->getLocation( sernum, &folder, &idx );
     // It's possible that the message has been deleted or moved into a
     // different folder, or that the serNum is stale
     if ( !folder ) {
-      mFilterSerNumsToSave.remove( QString( "%1" ).arg( *filterIt ) );
-      ++filterIt;
+      mFilterSerNumsToSave.remove( QString( "%1" ).arg( sernum ) );
       continue;
     }
 
     KMFolderImap *imapFolder = dynamic_cast<KMFolderImap*>(folder->storage());
     if (!imapFolder ||
-	!imapFolder->folder()->isSystemFolder() ||
+        !imapFolder->folder()->isSystemFolder() ||
         !(imapFolder->imapPath() == "/INBOX/") ) { // sanity checking
-      mFilterSerNumsToSave.remove( QString( "%1" ).arg( *filterIt ) );
-      ++filterIt;
+      mFilterSerNumsToSave.remove( QString( "%1" ).arg( sernum ) );
       continue;
     }
 
@@ -454,33 +455,30 @@ void KMAcctImap::postProcessNewMail( KMFolder * folder )
 
       msg = folder->getMsg( idx );
       if (!msg) { // sanity checking
-        mFilterSerNumsToSave.remove( QString( "%1" ).arg( *filterIt ) );
-        ++filterIt;
+        mFilterSerNumsToSave.remove( QString( "%1" ).arg( sernum ) );
         continue;
       }
 
       if (ActionScheduler::isEnabled() ||
-	  kmkernel->filterMgr()->atLeastOneOnlineImapFolderTarget()) {
-	mScheduler->execFilters( msg );
+          kmkernel->filterMgr()->atLeastOneOnlineImapFolderTarget()) {
+        mScheduler->execFilters( msg );
       } else {
-	if (msg->transferInProgress()) {
-	  inTransit.append( *filterIt );
-	  ++filterIt;
-	  continue;
-	}
-	msg->setTransferInProgress(true);
-	if ( !msg->isComplete() ) {
-	  FolderJob *job = folder->createJob(msg);
-	  connect(job, SIGNAL(messageRetrieved(KMMessage*)),
-		  SLOT(slotFilterMsg(KMMessage*)));
-	  job->start();
-	} else {
-	  mFilterSerNumsToSave.remove( QString( "%1" ).arg( *filterIt ) );
-	  if (slotFilterMsg(msg) == 2) break;
-	}
+        if (msg->transferInProgress()) {
+          inTransit.append( sernum );
+          continue;
+        }
+        msg->setTransferInProgress(true);
+        if ( !msg->isComplete() ) {
+          FolderJob *job = folder->createJob(msg);
+          connect(job, SIGNAL(messageRetrieved(KMMessage*)),
+            SLOT(slotFilterMsg(KMMessage*)));
+          job->start();
+        } else {
+          mFilterSerNumsToSave.remove( QString( "%1" ).arg( sernum ) );
+          if (slotFilterMsg(msg) == 2) break;
+        }
       }
     }
-    ++filterIt;
   }
   mFilterSerNums = inTransit;
 
@@ -498,7 +496,7 @@ void KMAcctImap::postProcessNewMail( KMFolder * folder )
 }
 
 //-----------------------------------------------------------------------------
-void KMAcctImap::slotFiltered(Q_UINT32 serNum)
+void KMAcctImap::slotFiltered(quint32 serNum)
 {
     mFilterSerNumsToSave.remove( QString( "%1" ).arg( serNum ) );
 }
@@ -508,17 +506,17 @@ void KMAcctImap::slotUpdateFolderList()
 {
   if ( !mFolder || !mFolder->folder() || !mFolder->folder()->child() )
   {
-    kdWarning(5006) << "KMAcctImap::slotUpdateFolderList return" << endl;
+    kWarning(5006) << "Return";
     return;
   }
   QStringList strList;
   mMailCheckFolders.clear();
   kmkernel->imapFolderMgr()->createFolderList(&strList, &mMailCheckFolders,
-    mFolder->folder()->child(), QString::null, false);
+    mFolder->folder()->child(), QString(), false);
   // the new list
-  QValueList<QGuardedPtr<KMFolder> > includedFolders;
+  QList<QPointer<KMFolder> > includedFolders;
   // check for excluded folders
-  QValueList<QGuardedPtr<KMFolder> >::Iterator it;
+  QList<QPointer<KMFolder> >::Iterator it;
   for (it = mMailCheckFolders.begin(); it != mMailCheckFolders.end(); ++it)
   {
     KMFolderImap* folder = static_cast<KMFolderImap*>(((KMFolder*)(*it))->storage());
@@ -535,7 +533,7 @@ void KMAcctImap::listDirectory()
 }
 
 //-----------------------------------------------------------------------------
-void KMAcctImap::readConfig(KConfig& config)
+void KMAcctImap::readConfig(KConfigGroup& config)
 {
   ImapAccountBase::readConfig( config );
 }
@@ -549,7 +547,7 @@ void KMAcctImap::slotMailCheckCanceled()
 }
 
 //-----------------------------------------------------------------------------
-FolderStorage* const KMAcctImap::rootFolder() const
+FolderStorage* KMAcctImap::rootFolder() const
 {
   return mFolder;
 }
@@ -558,7 +556,7 @@ ImapAccountBase::ConnectionState KMAcctImap::makeConnection()
 {
   if ( mSlaveConnectionError )
   {
-    mErrorTimer.start(100, true); // Clear error flag
+    mErrorTimer.start( 100 ); // Clear error flag
     return Error;
   }
   return ImapAccountBase::makeConnection();
@@ -567,7 +565,7 @@ ImapAccountBase::ConnectionState KMAcctImap::makeConnection()
 void KMAcctImap::slotResetConnectionError()
 {
   mSlaveConnectionError = false;
-  kdDebug(5006) << k_funcinfo << endl;
+  kDebug(5006) ;
 }
 
 void KMAcctImap::slotFolderSelected( KMFolderImap* folder, bool )
@@ -579,14 +577,14 @@ void KMAcctImap::slotFolderSelected( KMFolderImap* folder, bool )
   folder->close( "acctimap" );
 }
 
-void KMAcctImap::execFilters(Q_UINT32 serNum)
+void KMAcctImap::execFilters(quint32 serNum)
 {
   if ( !kmkernel->filterMgr()->atLeastOneFilterAppliesTo( id() ) ) return;
-  QValueListIterator<Q_UINT32> findIt = mFilterSerNums.find( serNum );
-  if ( findIt != mFilterSerNums.end() )
+  if ( mFilterSerNums.contains( serNum ) )
       return;
+
   mFilterSerNums.append( serNum );
-  mFilterSerNumsToSave.insert( QString( "%1" ).arg( serNum ), (const int *)1 );
+  mFilterSerNumsToSave.insert( QString( "%1" ).arg( serNum ), 1 );
 }
 
 int KMAcctImap::slotFilterMsg( KMMessage *msg )
@@ -596,14 +594,14 @@ int KMAcctImap::slotFilterMsg( KMMessage *msg )
     return -1;
   }
   msg->setTransferInProgress(false);
-  Q_UINT32 serNum = msg->getMsgSerNum();
+  quint32 serNum = msg->getMsgSerNum();
   if ( serNum )
     mFilterSerNumsToSave.remove( QString( "%1" ).arg( serNum ) );
 
   int filterResult = kmkernel->filterMgr()->process(msg,
-						    KMFilterMgr::Inbound,
-						    true,
-						    id() );
+                                                    KMFilterMgr::Inbound,
+                                                    true,
+                                                    id() );
   if (filterResult == 2) {
     // something went horribly wrong (out of space?)
     kmkernel->emergencyExit( i18n("Unable to process messages: " ) + QString::fromLocal8Bit(strerror(errno)));
