@@ -1,40 +1,54 @@
-// -*- mode: C++; c-file-style: "gnu" -*-
-// Header for kmreaderwin the kmail reader
-// written by Markus Wuebben <markus.wuebben@kde.org>
+/* -*- mode: C++; c-file-style: "gnu" -*-
+  This file is part of KMail, the KDE mail client.
+  Copyright (c) 1997 Markus Wuebben <markus.wuebben@kde.org>
+
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
+
+  This program is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+  GNU General Public License for more details.
+
+  You should have received a copy of the GNU General Public License along
+  with this program; if not, write to the Free Software Foundation, Inc.,
+  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+*/
 
 #ifndef KMREADERWIN_H
 #define KMREADERWIN_H
 
-#include <qwidget.h>
-#include <qtimer.h>
-#include <qstringlist.h>
+#include <QWidget>
+#include <QTimer>
+#include <QStringList>
+#include <QCloseEvent>
+#include <QEvent>
+#include <QList>
+#include <QResizeEvent>
 #include <kurl.h>
 #include <kservice.h>
-#include "kmmsgbase.h"
+#include <messagestatus.h>
+#include <kvbox.h>
+using KPIM::MessageStatus;
 #include "kmmimeparttree.h" // Needed for friend declaration.
 #include "interfaces/observer.h"
 
-class QFrame;
 class QSplitter;
-class QHBox;
-class QListViewItem;
-class QScrollBar;
+class KHBox;
+class QTreeWidgetItem;
 class QString;
-class QTabDialog;
 class QTextCodec;
 
-class DwHeaders;
-class DwMediaType;
 
 class KActionCollection;
 class KAction;
-class KActionMenu;
 class KSelectAction;
-class KRadioAction;
 class KToggleAction;
-class KConfigBase;
+class KToggleAction;
 class KHTMLPart;
-class KURL;
+class KUrl;
 
 class KMFolder;
 class KMMessage;
@@ -43,26 +57,22 @@ namespace KMail {
   namespace Interface {
     class Observable;
   }
-  class PartMetaData;
   class ObjectTreeParser;
   class AttachmentStrategy;
   class HeaderStrategy;
   class HeaderStyle;
   class HtmlWriter;
   class KHtmlPartHtmlWriter;
-  class ISubject;
   class HtmlStatusBar;
-  class FolderJob;
   class CSSHelper;
 }
 
 class partNode; // might be removed when KMime is used instead of mimelib
                 //                                      (khz, 29.11.2001)
 
-class NewByteArray; // providing operator+ on a QByteArray (khz, 21.06.2002)
-
 namespace KParts {
-  struct URLArgs;
+  struct BrowserArguments;
+  class OpenUrlArguments;
 }
 
 /**
@@ -73,20 +83,17 @@ namespace KParts {
 class KMReaderWin: public QWidget, public KMail::Interface::Observer {
   Q_OBJECT
 
-  friend void KMMimePartTree::itemClicked( QListViewItem* item );
-  friend void KMMimePartTree::itemRightClicked( QListViewItem* item, const QPoint & );
+  friend void KMMimePartTree::slotItemClicked( QTreeWidgetItem* );
+  friend void KMMimePartTree::slotContextMenuRequested( const QPoint & );
   friend void KMMimePartTree::slotSaveAs();
-  friend void KMMimePartTree::startDrag();
+  friend void KMMimePartTree::startDrag( Qt::DropActions actions );
 
   friend class KMail::ObjectTreeParser;
   friend class KMail::KHtmlPartHtmlWriter;
 
 public:
-  KMReaderWin( QWidget *parent,
-	       QWidget *mainWindow,
-	       KActionCollection *actionCollection,
-               const char *name=0,
-	       int f=0 );
+  KMReaderWin( QWidget *parent, QWidget *mainWindow,
+               KActionCollection *actionCollection, Qt::WindowFlags f = 0 );
   virtual ~KMReaderWin();
 
   /**
@@ -98,7 +105,7 @@ public:
   /** Read settings from app's config file. */
   void readConfig();
 
-  /** Write settings to app's config file. Calls sync() if withSync is TRUE. */
+  /** Write settings to app's config file. Calls sync() if withSync is true. */
   void writeConfig( bool withSync=true ) const;
 
   const KMail::HeaderStyle * headerStyle() const {
@@ -107,7 +114,7 @@ public:
   /** Set the header style and strategy. We only want them to be set
       together. */
   void setHeaderStyleAndStrategy( const KMail::HeaderStyle * style,
-				  const KMail::HeaderStrategy * strategy );
+                                  const KMail::HeaderStrategy * strategy );
 
   /** Getthe message header strategy. */
   const KMail::HeaderStrategy * headerStrategy() const {
@@ -144,7 +151,7 @@ public:
   /** Instead of settings a message to be shown sets a message part
       to be shown */
   void setMsgPart( KMMessagePart* aMsgPart, bool aHTML,
-		   const QString& aFileName, const QString& pname );
+                   const QString& aFileName, const QString& pname );
 
   void setMsgPart( partNode * node );
 
@@ -169,8 +176,8 @@ public:
   /** Re-parse the current message. */
   void update(bool force = false);
 
-  /** Print current message. */
-  virtual void printMsg(void);
+  /** Print message. */
+  virtual void printMsg(  KMMessage* aMsg );
 
   /** Return selected text */
   QString copyText();
@@ -235,26 +242,25 @@ public:
   KAction *urlOpenAction() { return mUrlOpenAction; }
   KAction *urlSaveAsAction() { return mUrlSaveAsAction; }
   KAction *addBookmarksAction() { return mAddBookmarksAction;}
-  KAction *startImChatAction() { return mStartIMChatAction; }
   // This function returns the complete data that were in this
   // message parts - *after* all encryption has been removed that
   // could be removed.
   // - This is used to store the message in decrypted form.
   void objectTreeToDecryptedMsg( partNode* node,
-                                 NewByteArray& resultingData,
+                                 QByteArray& resultingData,
                                  KMMessage& theMessage,
                                  bool weAreReplacingTheRootNode = false,
                                  int recCount = 0 );
 
   /** Returns message part from given URL or null if invalid. */
-  partNode* partNodeFromUrl(const KURL &url);
+  partNode* partNodeFromUrl(const KUrl &url);
 
   partNode * partNodeForId( int id );
 
-  KURL tempFileUrlFromPartNode( const partNode * node );
+  KUrl tempFileUrlFromPartNode( const partNode *node );
 
   /** Returns id of message part from given URL or -1 if invalid. */
-  static int msgPartFromUrl(const KURL &url);
+  static int msgPartFromUrl(const KUrl &url);
 
   void setUpdateAttachment( bool update = true ) { mAtmUpdate = update; }
 
@@ -267,15 +273,22 @@ public:
 
   void openAttachment( int id, const QString & name );
 
-  void emitUrlClicked( const KURL & url, int button ) {
+  void emitUrlClicked( const KUrl & url, int button ) {
     emit urlClicked( url, button );
   }
 
-  void emitPopupMenu( const KURL & url, const QPoint & p ) {
+  void emitPopupMenu( const KUrl & url, const QPoint & p ) {
     if ( message() )
       emit popupMenu( *message(), url, p );
   }
 
+  /**
+   * Sets the current attachment ID and the current attachment temporary filename
+   * to the given values.
+   * Call this so that slotHandleAttachment() knows which attachment to handle.
+   */
+  void prepareHandleAttachment( int id, const QString& fileName );
+
   void showAttachmentPopup( int id, const QString & name, const QPoint & p );
 
   /** Set the serial number of the message this reader window is currently
@@ -296,11 +309,7 @@ public:
   /** Show signature details. */
   void setShowSignatureDetails( bool showDetails = true ) { mShowSignatureDetails = showDetails; }
 
-  /* show or hide the list that points to the attachments */
-  bool showAttachmentQuicklist() const { return mShowAttachmentQuicklist; }
-
-  /* show or hide the list that points to the attachments */
-  void setShowAttachmentQuicklist( bool showAttachmentQuicklist = true ) { mShowAttachmentQuicklist = showAttachmentQuicklist; }
+  KMail::CSSHelper* cssHelper() const;
 
 signals:
   /** Emitted after parsing of a message to have it stored
@@ -308,10 +317,10 @@ signals:
   void replaceMsgByUnencryptedVersion();
 
   /** The user presses the right mouse button. 'url' may be 0. */
-  void popupMenu(KMMessage &msg, const KURL &url, const QPoint& mousePos);
+  void popupMenu(KMMessage &msg, const KUrl &url, const QPoint& mousePos);
 
   /** The user has clicked onto an URL that is no attachment. */
-  void urlClicked(const KURL &url, int button);
+  void urlClicked(const KUrl &url, int button);
 
   /** Pgp displays a password dialog */
   void noDrag(void);
@@ -338,7 +347,7 @@ public slots:
   void slotTextSelected(bool);
 
   /** An URL has been activate with a click. */
-  void slotUrlOpen(const KURL &url, const KParts::URLArgs &args);
+  void slotUrlOpen(const KUrl &url, const KParts::OpenUrlArguments &, const KParts::BrowserArguments &);
 
   /** The mouse has moved on or off an URL. */
   void slotUrlOn(const QString &url);
@@ -348,8 +357,6 @@ public slots:
 
   /** The user selected "Find" from the menu. */
   void slotFind();
-  /** The user selected "Find Next" from the menu. */
-  void slotFindNext();
 
   /** The user toggled the "Fixed Font" flag from the view menu. */
   void slotToggleFixedFont();
@@ -368,7 +375,7 @@ public slots:
   /** Copy URL in mUrlCurrent to clipboard. Removes "mailto:" at
       beginning of URL before copying. */
   void slotUrlCopy();
-  void slotUrlOpen( const KURL &url = KURL() );
+  void slotUrlOpen( const KUrl &url = KUrl() );
   /** Save the page to a file */
   void slotUrlSave();
   void slotAddBookmarks();
@@ -376,9 +383,6 @@ public slots:
   void slotSaveAttachments();
 
   void slotMessageArrived( KMMessage *msg );
-  /** start IM Chat with addressee */
-  void slotIMChat();
-  void contactStatusChanged( const QString &uid);
 
   void slotLevelQuote( int l );
   void slotTouchMessage();
@@ -386,13 +390,19 @@ public slots:
   void slotDeleteAttachment( partNode* node );
   void slotEditAttachment( partNode* node );
 
-  KMail::CSSHelper* cssHelper();
+  /**
+   * Does an action for the current attachment.
+   * The action is defined by the KMHandleAttachmentCommand::AttachmentAction
+   * enum.
+   * prepareHandleAttachment() needs to be called before calling this to set the
+   * correct attachment ID.
+   */
+  void slotHandleAttachment( int action );
 
 protected slots:
   void slotCycleHeaderStyles();
   void slotBriefHeaders();
   void slotFancyHeaders();
-  void slotEnterpriseHeaders();
   void slotStandardHeaders();
   void slotLongHeaders();
   void slotAllHeaders();
@@ -406,7 +416,12 @@ protected slots:
   /** Some attachment operations. */
   void slotAtmView( int id, const QString& name );
   void slotDelayedResize();
-  void slotHandleAttachment( int );
+
+  /** Print message. Called on as a response of finished() signal of mPartHtmlWriter
+      after rendering is finished.
+      In the very end it deletes the KMReaderWin window that was created 
+      for the purpose of rendering. */
+  void slotPrintMsg();
 
 protected:
   /** reimplemented in order to update the frame width in case of a changed
@@ -432,10 +447,10 @@ protected:
 
   /** Creates a nice mail header depending on the current selected
     header style. */
-  QString writeMsgHeader(KMMessage* aMsg, bool hasVCard=false, bool topLevel=false);
+  QString writeMsgHeader(KMMessage* aMsg, bool hasVCard=false);
 
   /** Writes the given message part to a temporary file and returns the
-      name of this file or QString::null if writing failed.
+      name of this file or QString() if writing failed.
   */
   QString writeMessagePartToTempFile( KMMessagePart* msgPart, int partNumber );
 
@@ -464,22 +479,19 @@ protected:
 
 private slots:
   void slotSetEncoding();
-  void injectAttachments();
 
 private:
   void adjustLayout();
   void createWidgets();
-  void createActions( KActionCollection * ac );
-  void saveSplitterSizes( KConfigBase & c ) const;
+  void createActions();
+  void saveSplitterSizes( KConfigGroup & c ) const;
 
-  KRadioAction * actionForHeaderStyle( const KMail::HeaderStyle *,
+  KToggleAction * actionForHeaderStyle( const KMail::HeaderStyle *,
                                        const KMail::HeaderStrategy * );
-  KRadioAction * actionForAttachmentStrategy( const KMail::AttachmentStrategy * );
+  KToggleAction * actionForAttachmentStrategy( const KMail::AttachmentStrategy * );
   /** Read override codec from configuration */
   void readGlobalOverrideCodec();
 
-  QString renderAttachments( partNode *node, const QColor &bgColor );
-
 private:
   bool mHtmlMail, mHtmlLoadExternal, mHtmlOverride, mHtmlLoadExtOverride;
   int mAtmCurrent;
@@ -487,7 +499,7 @@ private:
   KMMessage *mMessage;
   // widgets:
   QSplitter * mSplitter;
-  QHBox *mBox;
+  KHBox *mBox;
   KMail::HtmlStatusBar *mColorBar;
   KMMimePartTree* mMimePartTree;
   KHTMLPart *mViewer;
@@ -507,7 +519,7 @@ private:
   bool mMsgDisplay;
   bool mNoMDNsWhenEncrypted;
   unsigned long mLastSerNum;
-  KMMsgStatus mLastStatus;
+  MessageStatus mLastStatus;
 
   KMail::CSSHelper * mCSSHelper;
   bool mUseFixedFont;
@@ -518,18 +530,23 @@ private:
   QStringList mTempDirs;
   int mMimeTreeMode;
   bool mMimeTreeAtBottom;
-  QValueList<int> mSplitterSizes;
+  QList<int> mSplitterSizes;
   partNode* mRootNode;
   QString mIdOfLastViewedMessage;
   QWidget *mMainWindow;
   KActionCollection *mActionCollection;
   KAction *mMailToComposeAction, *mMailToReplyAction, *mMailToForwardAction,
       *mAddAddrBookAction, *mOpenAddrBookAction, *mCopyAction, *mCopyURLAction,
-      *mUrlOpenAction, *mUrlSaveAsAction, *mAddBookmarksAction, *mStartIMChatAction, *mSelectAllAction;
+      *mUrlOpenAction, *mUrlSaveAsAction, *mAddBookmarksAction, *mSelectAllAction,
+      *mScrollUpAction, *mScrollDownAction, *mScrollUpMoreAction, *mScrollDownMoreAction;
   KSelectAction *mSelectEncodingAction;
   KToggleAction *mToggleFixFontAction;
-  KURL mUrlClicked;
+  KUrl mUrlClicked;
   KMail::HtmlWriter * mHtmlWriter;
+  /** Used only to be able to connect and disconnect finished() signal 
+      in printMsg() and slotPrintMsg() since mHtmlWriter points only to abstract non-QObject class. */
+  QPointer<KMail::KHtmlPartHtmlWriter> mPartHtmlWriter;
+
   // an attachment should be updated
   bool mAtmUpdate;
   int mChoice;
@@ -538,7 +555,6 @@ private:
 	int mLevelQuote;
   bool mDecrytMessageOverwrite;
   bool mShowSignatureDetails;
-  bool mShowAttachmentQuicklist;
 };
 
 
