@@ -12,10 +12,6 @@
     Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, US
 */
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 #include "sieveconfig.h"
 
 #include <knuminput.h>
@@ -23,51 +19,64 @@
 #include <kdialog.h>
 #include <kconfigbase.h>
 
-#include <qlayout.h>
-#include <qcheckbox.h>
-#include <qlabel.h>
+#include <QLayout>
+#include <QCheckBox>
+#include <QLabel>
+//Added by qt3to4:
+#include <QGridLayout>
 #include <klineedit.h>
 
 
 namespace KMail {
 
-  void SieveConfig::readConfig( const KConfigBase & config ) {
-    mManagesieveSupported = config.readBoolEntry( "sieve-support", false );
-    mReuseConfig = config.readBoolEntry( "sieve-reuse-config", true );
+  void SieveConfig::readConfig( const KConfigGroup & config ) {
+    mManagesieveSupported = config.readEntry( "sieve-support", false );
+    mReuseConfig = config.readEntry( "sieve-reuse-config", true );
 
-    int port = config.readNumEntry( "sieve-port", 2000 );
+    int port = config.readEntry( "sieve-port", 2000 );
     if ( port < 1 || port > USHRT_MAX ) port = 2000;
     mPort = static_cast<unsigned short>( port );
 
     mAlternateURL = config.readEntry( "sieve-alternate-url" );
     mVacationFileName = config.readEntry( "sieve-vacation-filename", "kmail-vacation.siv" );
+    if ( mVacationFileName.isEmpty() )
+      mVacationFileName = "kmail-vacation.siv";
   }
 
-  void SieveConfig::writeConfig( KConfigBase & config ) const {
+  void SieveConfig::writeConfig( KConfigGroup & config ) const {
     config.writeEntry( "sieve-support", managesieveSupported() );
     config.writeEntry( "sieve-reuse-config", reuseConfig() );
-    config.writeEntry( "sieve-port", port() );
+    config.writeEntry( "sieve-port", (int)port() );
     config.writeEntry( "sieve-alternate-url", mAlternateURL.url() );
     config.writeEntry( "sieve-vacation-filename", mVacationFileName );
   }
 
+  QString SieveConfig::toString() const
+  {
+    QString result;
+    result += "SieveConfig: \n";
+    result += "  sieve-vacation-filename: " + mVacationFileName + "\n\n";
+    return result;
+  }
 
-  SieveConfigEditor::SieveConfigEditor( QWidget * parent, const char * name )
-    : QWidget( parent, name )
+  SieveConfigEditor::SieveConfigEditor( QWidget * parent )
+    : QWidget( parent )
   {
     // tmp. vars:
     int row = -1;
     QLabel * label;
 
-    QGridLayout * glay = new QGridLayout( this, 5, 2, 0, KDialog::spacingHint() );
+    QGridLayout * glay = new QGridLayout( this );
+    glay->setSpacing( KDialog::spacingHint() );
+    glay->setMargin( 0 );
     glay->setRowStretch( 4, 1 );
-    glay->setColStretch( 1, 1 );
+    glay->setColumnStretch( 1, 1 );
 
 
     // "Server supports sieve" checkbox:
     ++row;
     mManagesieveCheck = new QCheckBox( i18n("&Server supports Sieve"), this );
-    glay->addMultiCellWidget( mManagesieveCheck, row, row, 0, 1 );
+    glay->addWidget( mManagesieveCheck, row, 0, 1, 2 );
 
     connect( mManagesieveCheck, SIGNAL(toggled(bool)), SLOT(slotEnableWidgets()) );
 
@@ -76,15 +85,16 @@ namespace KMail {
     mSameConfigCheck = new QCheckBox( i18n("&Reuse host and login configuration"), this );
     mSameConfigCheck->setChecked( true );
     mSameConfigCheck->setEnabled( false );
-    glay->addMultiCellWidget( mSameConfigCheck, row, row, 0, 1 );
+    glay->addWidget( mSameConfigCheck, row, 0, 1, 2 );
 
     connect( mSameConfigCheck, SIGNAL(toggled(bool)), SLOT(slotEnableWidgets()) );
 
     // "Managesieve port" spinbox and label:
     ++row;
-    mPortSpin = new KIntSpinBox( 1, USHRT_MAX, 1, 2000, 10, this );
+    mPortSpin = new KIntSpinBox( 1, USHRT_MAX, 1, 2000, this );
     mPortSpin->setEnabled( false );
-    label = new QLabel( mPortSpin, i18n("Managesieve &port:"), this );
+    label = new QLabel( i18n("Managesieve &port:"), this );
+    label->setBuddy( mPortSpin );
     glay->addWidget( label, row, 0 );
     glay->addWidget( mPortSpin, row, 1 );
 
@@ -92,7 +102,9 @@ namespace KMail {
     ++row;
     mAlternateURLEdit = new KLineEdit( this );
     mAlternateURLEdit->setEnabled( false );
-    glay->addWidget( new QLabel( mAlternateURLEdit, i18n("&Alternate URL:"), this ), row, 0 );
+    label = new QLabel( i18n("&Alternate URL:"), this );
+    label->setBuddy( mAlternateURLEdit );
+    glay->addWidget( label, row, 0 );
     glay->addWidget( mAlternateURLEdit, row, 1 );
 
     // row 4 is spacer
@@ -132,26 +144,36 @@ namespace KMail {
     mPortSpin->setValue( port );
   }
 
-  KURL SieveConfigEditor::alternateURL() const {
-    KURL url ( mAlternateURLEdit->text() );
+  KUrl SieveConfigEditor::alternateURL() const {
+    KUrl url ( mAlternateURLEdit->text() );
     if ( !url.isValid() )
-      return KURL();
+      return KUrl();
 
     if ( url.hasPass() )
-      url.setPass( QString::null );
+      url.setPass( QString() );
 
     return url;
   }
 
-  void SieveConfigEditor::setAlternateURL( const KURL & url ) {
+  void SieveConfigEditor::setAlternateURL( const KUrl & url ) {
     mAlternateURLEdit->setText( url.url() );
   }
 
+
+  QString SieveConfigEditor::vacationFileName() const {
+    return mVacationFileName;
+  }
+
+  void SieveConfigEditor::setVacationFileName( const QString& name ) {
+    mVacationFileName = name;
+  }
+
   void SieveConfigEditor::setConfig( const SieveConfig & config ) {
     setManagesieveSupported( config.managesieveSupported() );
     setReuseConfig( config.reuseConfig() );
     setPort( config.port() );
     setAlternateURL( config.alternateURL() );
+    setVacationFileName( config.vacationFileName() );
   }
 
 } // namespace KMail
