@@ -1,6 +1,6 @@
 /*
     KNode, the KDE newsreader
-    Copyright (c) 1999-2005 the KNode authors.
+    Copyright (c) 1999-2006 the KNode authors.
     See file AUTHORS for details
 
     This program is free software; you can redistribute it and/or modify
@@ -15,35 +15,48 @@
 #ifndef KNCOMPOSER_H
 #define KNCOMPOSER_H
 
-#include <klistview.h>
+#include <k3listview.h>
 
-#include <kmainwindow.h>
-#include <kdialogbase.h>
-#include <keditcl.h>
-#include <qlineedit.h>
-#include <qregexp.h>
+#include <kxmlguiwindow.h>
+#include <kdialog.h>
+#include <QRegExp>
+#include <QByteArray>
+#include <QCloseEvent>
+#include <QKeyEvent>
+#include <QEvent>
+#include <QDropEvent>
+#include <QLabel>
+#include <QList>
+#include <QContextMenuEvent>
+#include <QMenu>
+#include <QDragEnterEvent>
+#include <QSplitter>
 
 #include <kdeversion.h>
-#include <keditcl.h>
-
+#include <kprocess.h>
 #include <kabc/addresslineedit.h>
-#include <knodecomposeriface.h>
 
 class QGroupBox;
 
-class KProcess;
-class KSpell;
-class KDictSpellingHighlighter;
 class KSelectAction;
 class KToggleAction;
-
 class KNLocalArticle;
 class KNAttachment;
-class SpellingFilter;
+class KComboBox;
+class QComboBox;
+namespace KPIM {
+class KMeditor;
+}
+using KPIM::KMeditor;
 
-class KNComposer : public KMainWindow , virtual public KNodeComposerIface {
+namespace KPIMUtils { class SpellingFilter; }
+using KPIMUtils::SpellingFilter;
+
+/** Message composer window. */
+class KNComposer : public KXmlGuiWindow {
 
   Q_OBJECT
+  Q_CLASSINFO( "D-Bus Interface", "org.kde.knode.composer")
 
   public:
     enum composerResult { CRsendNow, CRsendLater, CRdelAsk,
@@ -52,7 +65,9 @@ class KNComposer : public KMainWindow , virtual public KNodeComposerIface {
 
     // unwraped == original, not rewraped text
     // firstEdit==true: place the cursor at the end of the article
-    KNComposer(KNLocalArticle *a, const QString &text=QString::null, const QString &sig=QString::null, const QString &unwraped=QString::null, bool firstEdit=false, bool dislikesCopies=false, bool createCopy=false);
+    KNComposer( KNLocalArticle *a, const QString &text = QString(), const QString &sig = QString(),
+                const QString &unwraped = QString(), bool firstEdit = false,
+                bool dislikesCopies = false, bool createCopy = false );
     ~KNComposer();
     void setConfig(bool onlyFonts);
     void setMessageMode(MessageMode mode);
@@ -65,18 +80,22 @@ class KNComposer : public KMainWindow , virtual public KNodeComposerIface {
 
     void closeEvent(QCloseEvent *e);
 
+  public slots:
     //set data from the given article
-    void initData(const QString &text);
+    Q_SCRIPTABLE void initData(const QString &text);
 
-    // inserts at cursor position if clear is false, replaces content otherwise
-    // puts the file content into a box if box==true
-    // "file" is already open for reading
-    void insertFile(QFile *file, bool clear=false, bool box=false, QString boxTitle=QString::null);
+  public:
 
-    // ask for a filename, handle network urls
+    /** Inserts at cursor position if clear is false, replaces content otherwise
+     * puts the file content into a box if box==true
+     * "file" is already open for reading
+     */
+    void insertFile( QFile *file, bool clear = false, bool box = false, const QString &boxTitle = QString() );
+
+    /// ask for a filename, handle network urls
     void insertFile(bool clear=false, bool box=false);
 
-    QPopupMenu * popupMenu( const QString& name );
+    QMenu * popupMenu( const QString& name );
     int listOfResultOfCheckWord( const QStringList & lst , const QString & selectWord);
 
 //internal classes
@@ -88,13 +107,13 @@ class KNComposer : public KMainWindow , virtual public KNodeComposerIface {
 
     //GUI
     ComposerView *v_iew;
-    QPopupMenu *a_ttPopup;
+    QMenu *a_ttPopup;
 
     //Data
     composerResult r_esult;
     KNLocalArticle *a_rticle;
     QString s_ignature, u_nwraped;
-    QCString c_harset;
+    QByteArray c_harset;
     MessageMode m_ode;
     bool n_eeds8Bit,    // false: fall back to us-ascii
          v_alidated,    // hasValidData was run and found no problems, n_eeds8Bit is valid
@@ -103,25 +122,23 @@ class KNComposer : public KMainWindow , virtual public KNodeComposerIface {
     //edit
     bool e_xternalEdited;
     KProcess *e_xternalEditor;
-    KTempFile *e_ditorTempfile;
-    KSpell *s_pellChecker;
+    KTemporaryFile *e_ditorTempfile;
     SpellingFilter* mSpellingFilter;
 
     //Attachments
-    QValueList<KNAttachment*> mDeletedAttachments;
-    QPtrList<KAction> m_listAction;
+    QList<KNAttachment*> mDeletedAttachments;
+    QList<QAction*> m_listAction;
     bool a_ttChanged;
 
   //------------------------------ <Actions> -----------------------------
 
-    KAccel        *a_ccel;
-    KAction       *a_ctExternalEditor,
+    QAction       *a_ctExternalEditor,
                   *a_ctSpellCheck,
                   *a_ctRemoveAttachment,
                   *a_ctAttachmentProperties,
                   *a_ctSetCharsetKeyb;
     KToggleAction *a_ctPGPsign,
-                  *a_ctDoPost, *a_ctDoMail, *a_ctWordWrap;
+                  *a_ctDoPost, *a_ctDoMail, *a_ctWordWrap, *a_ctAutoSpellChecking;
     KSelectAction *a_ctSetCharset;
     bool spellLineEdit;
   protected slots:
@@ -140,15 +157,16 @@ class KNComposer : public KMainWindow , virtual public KNodeComposerIface {
     void slotSetCharset(const QString &s);
     void slotSetCharsetKeyboard();
     void slotToggleWordWrap();
+    void slotAutoSpellCheckingToggled();
     void slotUndoRewrap();
     void slotExternalEditor();
-    void slotSpellcheck();
 
     void slotUpdateStatusBar();
     void slotUpdateCursorPos();
     void slotConfKeys();
     void slotConfToolbar();
     void slotNewToolbarConfig();
+  void slotUpdateCheckSpellChecking(bool _b);
 
   //------------------------------ </Actions> ----------------------------
 
@@ -159,19 +177,19 @@ class KNComposer : public KMainWindow , virtual public KNodeComposerIface {
     void slotGroupsBtnClicked();
 
     // external editor
-    void slotEditorFinished(KProcess *);
+    void slotEditorFinished(int, QProcess::ExitStatus);
     void slotCancelEditor();
 
     // attachment list
-    void slotAttachmentPopup(KListView*, QListViewItem *it, const QPoint &p);
-    void slotAttachmentSelected(QListViewItem *it);
-    void slotAttachmentEdit(QListViewItem *it);
-    void slotAttachmentRemove(QListViewItem *it);
+    void slotAttachmentPopup(K3ListView*, Q3ListViewItem *it, const QPoint &p);
+    void slotAttachmentSelected(Q3ListViewItem *it);
+    void slotAttachmentEdit(Q3ListViewItem *it);
+    void slotAttachmentRemove(Q3ListViewItem *it);
 
     // spellcheck operation
-    void slotSpellStarted(KSpell *);
-    void slotSpellDone(const QString&);
-    void slotSpellFinished();
+    //void slotSpellStarted(K3Spell *);
+    //void slotSpellDone(const QString&);
+    //void slotSpellFinished();
 
     // DND handling
     virtual void slotDragEnterEvent(QDragEnterEvent *);
@@ -183,8 +201,6 @@ class KNComposer : public KMainWindow , virtual public KNodeComposerIface {
     void slotCopy();
     void slotPaste();
     void slotSelectAll();
-    void slotMisspelling(const QString &text, const QStringList &lst, unsigned int pos);
-    void slotCorrected (const QString &oldWord, const QString &newWord, unsigned int pos);
     void addRecentAddress();
 
   protected:
@@ -198,62 +214,22 @@ class KNComposer : public KMainWindow , virtual public KNodeComposerIface {
 
   private:
     bool mFirstEdit;
-
+    /**
+    * Temporary hack for bug 169411 stolen from KMail (kmmsgbase.{h,cpp})
+    * Fixes an encoding received by a KDE function and returns the proper,
+    * MIME-compilant encoding name instead.
+    */
+    QByteArray fixEncoding( const QByteArray &encoding );
 };
 
-
-
-class KNLineEditSpell;
-class KNLineEdit;
-
-class KNComposer::ComposerView  : public QSplitter {
-
-  public:
-    ComposerView(KNComposer *_composer, const char *n=0);
-    ~ComposerView();
-    void focusNextPrevEdit(const QWidget* aCur, bool aNext);
-    void setMessageMode(KNComposer::MessageMode mode);
-    void showAttachmentView();
-    void hideAttachmentView();
-    void showExternalNotification();
-    void hideExternalNotification();
-    void restartBackgroundSpellCheck();
-    QValueList<QWidget*> mEdtList;
-
-    QLabel      *l_to,
-                *l_groups,
-                *l_fup2;
-    KNLineEditSpell *s_ubject;
-
-    KNLineEdit   *g_roups;
-    KNLineEdit  *t_o;
-
-    KComboBox   *f_up2;
-    QPushButton *g_roupsBtn,
-                *t_oBtn;
-
-    Editor      *e_dit;
-    QGroupBox   *n_otification;
-    QPushButton *c_ancelEditorBtn;
-
-    QWidget         *a_ttWidget;
-    AttachmentView  *a_ttView;
-    QPushButton     *a_ttAddBtn,
-                    *a_ttRemoveBtn,
-                    *a_ttEditBtn;
-    KDictSpellingHighlighter *mSpellChecker;
-
-    bool v_iewOpen;
-};
-
-
-//internal class : handle Tabs... (expanding them in textLine(), etc.)
+#if 0
+/** Message Compser editor, handles tabs (expanding them in textLine(), etc.) */
 class KNComposer::Editor : public KEdit {
 
   Q_OBJECT
 
   public:
-    Editor(KNComposer::ComposerView *_composerView, KNComposer *_composer, QWidget *parent=0, char *name=0);
+    Editor( KNComposer::ComposerView *_composerView, KNComposer *_composer, QWidget *parent = 0 );
     ~Editor();
     QStringList processedText();
 
@@ -270,14 +246,12 @@ class KNComposer::Editor : public KEdit {
     void slotCorrectWord();
 
 protected slots:
-    void slotSpellStarted( KSpell *);
+    void slotSpellStarted( K3Spell *);
     void slotSpellDone(const QString &);
     void slotSpellFinished();
-    void slotMisspelling (const QString &, const QStringList &lst, unsigned int);
     virtual void cut();
     virtual void clear();
     virtual void del();
-    void slotAddSuggestion( const QString &, const QStringList &lst, unsigned int );
   signals:
     void sigDragEnterEvent(QDragEnterEvent *);
     void sigDropEvent(QDropEvent *);
@@ -294,32 +268,34 @@ protected slots:
 private:
     KNComposer *m_composer;
     KNComposer::ComposerView *m_composerView;
-    KSpell *spell;
+    K3Spell *spell;
     QMap<QString,QStringList> m_replacements;
     QRegExp m_bound;
 };
+#endif
 
-
-class KNComposer::AttachmentView : public KListView {
+/** Attachment view of the message composer. */
+class KNComposer::AttachmentView : public K3ListView {
 
   Q_OBJECT
 
   public:
-    AttachmentView(QWidget *parent, char *name=0);
+    AttachmentView( QWidget *parent );
     ~AttachmentView();
 
   protected:
     void keyPressEvent( QKeyEvent *e );
 
   signals:
-    void delPressed ( QListViewItem * );      // the user used Key_Delete on a list view item
+    void delPressed ( Q3ListViewItem * );      // the user used Key_Delete on a list view item
 };
 
 
-class KNComposer::AttachmentViewItem : public KListViewItem {
+/** Attachment view item. */
+class KNComposer::AttachmentViewItem : public K3ListViewItem {
 
   public:
-    AttachmentViewItem(KListView *v, KNAttachment *a);
+    AttachmentViewItem(K3ListView *v, KNAttachment *a);
     ~AttachmentViewItem();
 
   KNAttachment *attachment;
@@ -327,12 +303,13 @@ class KNComposer::AttachmentViewItem : public KListViewItem {
 };
 
 
-class KNComposer::AttachmentPropertiesDlg : public KDialogBase {
+/** Attachment properties dialog. */
+class KNComposer::AttachmentPropertiesDlg : public KDialog {
 
   Q_OBJECT
 
   public:
-    AttachmentPropertiesDlg( KNAttachment *a, QWidget *p=0, const char *n=0);
+    AttachmentPropertiesDlg( KNAttachment *a, QWidget *parent = 0 );
     ~AttachmentPropertiesDlg();
 
     void apply();
@@ -351,30 +328,31 @@ class KNComposer::AttachmentPropertiesDlg : public KDialogBase {
 };
 
 //-----------------------------------------------------------------------------
+/** Line edit for addresses used in the composer. */
 class KNLineEdit : public KABC::AddressLineEdit
 {
     Q_OBJECT
     typedef KABC::AddressLineEdit KNLineEditInherited;
 public:
 
-    KNLineEdit(KNComposer::ComposerView *_composerView, bool useCompletion, QWidget *parent = 0,
-               const char *name = 0);
+    KNLineEdit( KNComposer::ComposerView *_composerView, bool useCompletion, QWidget *parent = 0 );
 protected:
     // Inherited. Always called by the parent when this widget is created.
     virtual void loadAddresses();
     void keyPressEvent(QKeyEvent *e);
-    virtual QPopupMenu *createPopupMenu();
+    virtual void contextMenuEvent( QContextMenuEvent*e );
 private slots:
     void editRecentAddresses();
 private:
     KNComposer::ComposerView *composerView;
 };
 
+/** Line edit with on-the-fly spell checking. */
 class KNLineEditSpell : public KNLineEdit
 {
     Q_OBJECT
 public:
-    KNLineEditSpell(KNComposer::ComposerView *_composerView, bool useCompletion,QWidget * parent, const char * name = 0);
+    KNLineEditSpell( KNComposer::ComposerView *_composerView, bool useCompletion, QWidget * parent );
     void highLightWord( unsigned int length, unsigned int pos );
     void spellCheckDone( const QString &s );
     void spellCheckerMisspelling( const QString &text, const QStringList &, unsigned int pos);
