@@ -103,6 +103,15 @@ SDSummaryWidget::SDSummaryWidget( Kontact::Plugin *plugin, QWidget *parent )
   mLayout->setSpacing( 3 );
   mLayout->setRowStretch( 6, 1 );
 
+  // Default settings
+  mDaysAhead = 7;
+  mShowBirthdaysFromKAB = true;
+  mShowBirthdaysFromCal = true;
+  mShowAnniversariesFromKAB = true;
+  mShowAnniversariesFromCal = true;
+  mShowHolidays = true;
+  mShowSpecialsFromCal = true;
+
   // Setup the Addressbook
   KABC::StdAddressBook *ab = KABC::StdAddressBook::self( true );
   connect( ab, SIGNAL(addressBookChanged(AddressBook*)),
@@ -111,30 +120,6 @@ SDSummaryWidget::SDSummaryWidget( Kontact::Plugin *plugin, QWidget *parent )
            this, SLOT(updateView()) );
 
   // Setup the Calendar
-  mCalendar = new KCal::CalendarResources( KPIM::KPimPrefs::timeSpec() );
-  mCalendar->readConfig();
-
-  KCal::CalendarResourceManager *manager = mCalendar->resourceManager();
-  if ( manager->isEmpty() ) {
-    KConfig _config( "korganizerrc" );
-    KConfigGroup config( &_config, "General" );
-    QString fileName = config.readPathEntry( "Active Calendar", QString() );
-
-    QString resourceName;
-    if ( fileName.isEmpty() ) {
-      fileName = KStandardDirs::locateLocal( "data", "korganizer/std.ics" );
-      resourceName = i18n( "Default KOrganizer resource" );
-    } else {
-      resourceName = i18n( "Active Calendar" );
-    }
-
-    KCal::ResourceCalendar *defaultResource = new KCal::ResourceLocal( fileName );
-
-    defaultResource->setResourceName( resourceName );
-
-    manager->add( defaultResource );
-    manager->setStandardResource( defaultResource );
-  }
   mCalendar = KOrg::StdCalendar::self();
   mCalendar->load();
 
