@@ -56,6 +56,7 @@ using namespace LibKHolidays;
 #include <q3listview.h>
 #include <q3buttongroup.h>
 #include <QLayout>
+#include <QFormLayout>
 #include <QLabel>
 #include <QSlider>
 #include <QFile>
@@ -96,14 +97,12 @@ KOPrefsDialogMain::KOPrefsDialogMain( const KComponentData &inst, QWidget *paren
     new QGroupBox( i18nc( "@title:group email settings", "Email Settings" ), personalFrame );
 
   personalLayout->addWidget( mUserEmailSettings );
-  QVBoxLayout *emailSettingsLayout = new QVBoxLayout( mUserEmailSettings );
-  KHBox *hbox1 = new KHBox( mUserEmailSettings );
-  addWidString( KOPrefs::instance()->userNameItem(), hbox1 );
-  emailSettingsLayout->addWidget( hbox1 );
+  QFormLayout *emailSettingsLayout = new QFormLayout( mUserEmailSettings );
+  KPrefsWidString *s = addWidString( KOPrefs::instance()->userNameItem(), mUserEmailSettings );
+  emailSettingsLayout->addRow ( s->label(), s->lineEdit() );
 
-  KHBox *hbox2 = new KHBox( mUserEmailSettings );
-  addWidString( KOPrefs::instance()->userEmailItem(), hbox2 );
-  emailSettingsLayout->addWidget( hbox2 );
+  s=addWidString( KOPrefs::instance()->userEmailItem(), mUserEmailSettings );
+  emailSettingsLayout->addRow ( s->label(), s->lineEdit() );
 
   KPrefsWidRadios *defaultEmailAttachMethod =
     addWidRadios( KOPrefs::instance()->defaultEmailAttachMethodItem(), personalFrame );
@@ -1258,9 +1257,9 @@ KOPrefsDialogPlugins::KOPrefsDialogPlugins( const KComponentData &inst, QWidget
   mPositioningGroupBox = new QGroupBox( i18nc( "@title:group", "Position" ), topFrame );
   mPositionMonthTop = new QCheckBox(
     i18nc( "@option:check", "Show in the month view" ), mPositioningGroupBox );
-  mPositionAgendaTop = new QCheckBox(
+  mPositionAgendaTop = new QRadioButton(
     i18nc( "@option:check", "Show at the top of the agenda views" ), mPositioningGroupBox );
-  mPositionAgendaBottom = new QCheckBox(
+  mPositionAgendaBottom = new QRadioButton(
     i18nc( "@option:check", "Show at the bottom of the agenda views" ), mPositioningGroupBox );
   QVBoxLayout *positioningLayout = new QVBoxLayout( mPositioningGroupBox );
   positioningLayout->addWidget( mPositionMonthTop );
@@ -1276,6 +1275,7 @@ KOPrefsDialogPlugins::KOPrefsDialogPlugins( const KComponentData &inst, QWidget
   connect( mPositionAgendaBottom, SIGNAL(clicked()), SLOT(positioningChanged()) );
 
   connect( mTreeWidget, SIGNAL(itemSelectionChanged()), SLOT(selectionChanged()) );
+  connect( mTreeWidget, SIGNAL(itemChanged(QTreeWidgetItem*,int)), SLOT(selectionChanged()) );
   connect( mTreeWidget, SIGNAL(itemClicked(QTreeWidgetItem*,int)), SLOT(slotWidChanged()) );
 
   load();
@@ -1393,7 +1393,7 @@ void KOPrefsDialogPlugins::positioningChanged()
     mDecorationsAtMonthViewTop.remove( decoration );
   }
 
-  if ( mPositionAgendaTop->checkState() == Qt::Checked ) {
+  if ( mPositionAgendaTop->isChecked() ) {
     if ( !mDecorationsAtAgendaViewTop.contains( decoration ) ) {
       mDecorationsAtAgendaViewTop.insert( decoration );
     }
@@ -1401,7 +1401,7 @@ void KOPrefsDialogPlugins::positioningChanged()
     mDecorationsAtAgendaViewTop.remove( decoration );
   }
 
-  if ( mPositionAgendaBottom->checkState() == Qt::Checked ) {
+  if ( mPositionAgendaBottom->isChecked() ) {
     if ( !mDecorationsAtAgendaViewBottom.contains( decoration ) ) {
       mDecorationsAtAgendaViewBottom.insert( decoration );
     }
@@ -1440,19 +1440,36 @@ void KOPrefsDialogPlugins::selectionChanged()
   }
 
   mDescription->setText( item->service()->comment() );
-  mConfigureButton->setEnabled( hasSettings );
+  if ( !hasSettings ) {
+    mConfigureButton->hide();
+  } else {
+    mConfigureButton->show();
+    mConfigureButton->setEnabled( item->checkState(0) == Qt::Checked );
+  }
 
+  bool hasPosition = false;
   if ( item->service()->hasServiceType( KOrg::CalendarDecoration::Decoration::serviceType() ) ) {
     QString decoration = item->service()->desktopEntryName();
     if ( mDecorationsAtMonthViewTop.contains( decoration ) ) {
       mPositionMonthTop->setChecked( true );
+      hasPosition = true;
     }
     if ( mDecorationsAtAgendaViewTop.contains( decoration ) ) {
       mPositionAgendaTop->setChecked( true );
+      hasPosition = true;
     }
     if ( mDecorationsAtAgendaViewBottom.contains( decoration ) ) {
       mPositionAgendaBottom->setChecked( true );
+      hasPosition = true;
     }
+
+    if ( !hasPosition ) {
+      // no position has been selected, so default to Agenda Top
+      mDecorationsAtAgendaViewTop << decoration;
+      mPositionAgendaTop->setChecked( true );
+    }
+
+    mPositioningGroupBox->setEnabled( item->checkState(0) == Qt::Checked );
     mPositioningGroupBox->show();
   }
 
