@@ -133,12 +133,14 @@ class TimePrintStringsVisitor : public IncidenceBase::Visitor
     QString mDurationCaption, mDurationString;
 
   protected:
-    bool visit( Event *event ) {
+    bool visit( Event *event )
+    {
+      KDateTime::Spec spec = KPIM::KPimPrefs::timeSpec();
       if ( event->dtStart().isValid() ) {
         mStartCaption =  i18n( "Start date: " );
         // Show date/time or only date, depending on whether it's an all-day event
         mStartString = event->allDay() ?
-                       event->dtStartDateStr( false ) : event->dtStartStr( false );
+                       event->dtStartDateStr( false, spec ) : event->dtStartStr( false, spec );
       } else {
         mStartCaption = i18n( "No start date" );
         mStartString.clear();
@@ -147,7 +149,7 @@ class TimePrintStringsVisitor : public IncidenceBase::Visitor
       if ( event->hasEndDate() ) {
         mEndCaption = i18n( "End date: " );
         mEndString = event->allDay() ?
-                     event->dtEndDateStr( false ) : event->dtEndStr( false );
+                     event->dtEndDateStr( false, spec ) : event->dtEndStr( false, spec );
       } else if ( event->hasDuration() ) {
         mEndCaption = i18n( "Duration: " );
         int mins = event->duration().asSeconds() / 60;
@@ -163,12 +165,14 @@ class TimePrintStringsVisitor : public IncidenceBase::Visitor
       }
       return true;
     }
-    bool visit( Todo *todo ) {
+    bool visit( Todo *todo )
+    {
+      KDateTime::Spec spec = KPIM::KPimPrefs::timeSpec();
       if ( todo->hasStartDate() ) {
         mStartCaption =  i18n( "Start date: " );
         // Show date/time or only date, depending on whether it's an all-day event
         mStartString = todo->allDay() ?
-                       todo->dtStartDateStr( false ) : todo->dtStartStr( false );
+                       todo->dtStartDateStr( false, spec ) : todo->dtStartStr( false, spec );
       } else {
         mStartCaption = i18n( "No start date" );
         mStartString.clear();
@@ -177,22 +181,25 @@ class TimePrintStringsVisitor : public IncidenceBase::Visitor
       if ( todo->hasDueDate() ) {
         mEndCaption = i18n( "Due date: " );
         mEndString = todo->allDay() ?
-                     todo->dtDueDateStr( false ) : todo->dtDueStr( false );
+                     todo->dtDueDateStr( false, spec ) : todo->dtDueStr( false, spec );
       } else {
         mEndCaption = i18n( "No due date" );
         mEndString.clear();
       }
       return true;
     }
-    bool visit( Journal *journal ) {
+    bool visit( Journal *journal )
+    {
+      KDateTime::Spec spec = KPIM::KPimPrefs::timeSpec();
       mStartCaption = i18n( "Start date: " );
       mStartString = journal->allDay() ?
-                     journal->dtStartDateStr( false ) : journal->dtStartStr( false );
+                     journal->dtStartDateStr( false, spec ) : journal->dtStartStr( false, spec );
       mEndCaption.clear();
       mEndString.clear();
       return true;
     }
-    bool visit( FreeBusy *fb ) {
+    bool visit( FreeBusy *fb )
+    {
       Q_UNUSED( fb );
       return true;
     }
@@ -560,7 +567,7 @@ void CalPrintDay::loadConfig()
 {
   if ( mConfig ) {
     KConfigGroup grp( mConfig, "General" );
-    QDate dt;
+    QDate dt = QDate::currentDate(); // any valid QDate will do
     QTime tm1( dayStart() );
     QDateTime startTm( dt, tm1 );
     QDateTime endTm( dt, tm1.addSecs( 12 * 60 * 60 ) );
@@ -577,8 +584,11 @@ void CalPrintDay::saveConfig()
   readSettingsWidget();
   if ( mConfig ) {
     KConfigGroup grp( mConfig, "General" );
-    grp.writeEntry( "Start time", QDateTime( QDate(), mStartTime ) );
-    grp.writeEntry( "End time", QDateTime( QDate(), mEndTime ) );
+    QDateTime dt = QDateTime::currentDateTime(); // any valid QDateTime will do
+    dt.setTime( mStartTime );
+    grp.writeEntry( "Start time", dt );
+    dt.setTime( mEndTime );
+    grp.writeEntry( "End time", dt );
     grp.writeEntry( "Include todos", mIncludeTodos );
     grp.writeEntry( "Include all events", mIncludeAllEvents );
   }
@@ -623,13 +633,10 @@ void CalPrintDay::print( QPainter &p, int width, int height )
 
     // TODO: Find a good way to determine the height of the all-day box
     QRect allDayBox( TIMELINE_WIDTH + padding(), headerBox.bottom() + padding(),
-                     0, height / 20 );
+        0, height - headerBox.bottom() - padding() );
     allDayBox.setRight( width );
-    int allDayHeight = drawAllDayBox( p, eventList, curDay, true, allDayBox );
 
     QRect dayBox( allDayBox );
-    dayBox.setTop( allDayHeight );
-    dayBox.setBottom( height );
     drawAgendaDayBox( p, eventList, curDay, mIncludeAllEvents,
                       curStartTime, curEndTime, dayBox );
 
@@ -709,7 +716,7 @@ void CalPrintWeek::loadConfig()
 {
   if ( mConfig ) {
     KConfigGroup grp( mConfig, "General" );
-    QDate dt;
+    QDate dt = QDate::currentDate(); // any valid QDate will do
     QTime tm1( dayStart() );
     QDateTime startTm( dt, tm1 );
     QDateTime endTm( dt, tm1.addSecs( 43200 ) );
@@ -725,9 +732,13 @@ void CalPrintWeek::saveConfig()
 {
   readSettingsWidget();
   if ( mConfig ) {
+
     KConfigGroup grp( mConfig, "General" );
-    grp.writeEntry( "Start time", QDateTime( QDate(), mStartTime ) );
-    grp.writeEntry( "End time", QDateTime( QDate(), mEndTime ) );
+    QDateTime dt = QDateTime::currentDateTime(); // any valid QDateTime will do
+    dt.setTime( mStartTime );
+    grp.writeEntry( "Start time", dt );
+    dt.setTime( mEndTime );
+    grp.writeEntry( "End time", dt );
     grp.writeEntry( "Include todos", mIncludeTodos );
     grp.writeEntry( "Print type", int( mWeekPrintType ) );
   }
@@ -762,7 +773,7 @@ void CalPrintWeek::print( QPainter &p, int width, int height )
   // correct begin and end to first and last day of week
   int weekdayCol = weekdayColumn( mFromDate.dayOfWeek() );
   fromWeek = mFromDate.addDays( -weekdayCol );
-  weekdayCol = weekdayColumn( mFromDate.dayOfWeek() );
+  weekdayCol = weekdayColumn( mToDate.dayOfWeek() );
   toWeek = mToDate.addDays( 6 - weekdayCol );
 
   curWeek = fromWeek.addDays( 6 );
@@ -830,6 +841,7 @@ void CalPrintWeek::print( QPainter &p, int width, int height )
       QDate endLeft( fromWeek.addDays( 3 ) );
       int hh = headerHeight();
 
+      drawSplitHeaderRight( p, fromWeek, curWeek, QDate(), width, hh );
       drawTimeTable( p, fromWeek, endLeft, mStartTime, mEndTime, weekBox );
       mPrinter->newPage();
       drawSplitHeaderRight( p, fromWeek, curWeek, QDate(), width, hh );
