@@ -21,23 +21,24 @@
 **
 ** You should have received a copy of the GNU General Public License
 ** along with this program in a file called COPYING; if not, write to
-** the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-** MA 02111-1307, USA.
+** the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+** MA 02110-1301, USA.
 */
 
 /*
 ** Bug reports and questions can be sent to kde-pim@kde.org
 */
 
-#include "plugin.h"
 #include "vcal-setup.h"
 
 class ToDoWidgetSetup : public VCalWidgetSetupBase
 {
+Q_OBJECT
 public:
-	ToDoWidgetSetup(QWidget *,const char *);
+	ToDoWidgetSetup(QWidget *, const QVariantList & = QVariantList() );
 	virtual ~ToDoWidgetSetup();
 
+	virtual VCalConduitSettings*config();
 	static ConduitConfigBase *create(QWidget *, const char *);
 } ;
 
