@@ -19,24 +19,24 @@
 */
 
 #include <klocale.h>
-#include <kmdcodec.h>
-#include <libkdepim/kpimprefs.h>
-#include <libkcal/event.h>
-#include <libkcal/journal.h>
-#include <libkcal/recurrence.h>
-#include <libkcal/kcalversion.h>
+#include <kcodecs.h>
+#include <kcal/event.h>
+#include <kcal/journal.h>
+#include <kcal/recurrence.h>
+#include <kcal/kcalversion.h>
 #include <kabc/stdaddressbook.h>
 #include <kabc/addressee.h>
 #include <kdebug.h>
 
 #include "incidenceconverter.h"
+//Added by qt3to4:
+#include <QList>
 
 #define GW_MAX_RECURRENCES 50
 
-IncidenceConverter::IncidenceConverter( struct soap* soap )
-  : GWConverter( soap )
+IncidenceConverter::IncidenceConverter( KDateTime::Spec spec, struct soap* soap )
+  : GWConverter( soap ), mTimeSpec( spec )
 {
-  mTimezone = KPimPrefs::timezone();
 }
 
 void IncidenceConverter::setFrom( const QString &name,
@@ -49,7 +49,7 @@ void IncidenceConverter::setFrom( const QString &name,
 
 KCal::Event* IncidenceConverter::convertFromAppointment( ngwt__Appointment* appointment )
 {
-  kdDebug() << "IncidenceConverter::convertFromAppointment()" << endl;
+  kDebug() <<"IncidenceConverter::convertFromAppointment()";
   if ( !appointment )
     return 0;
 
@@ -62,30 +62,31 @@ KCal::Event* IncidenceConverter::convertFromAppointment( ngwt__Appointment* appo
 
   if ( appointment->allDayEvent && (*appointment->allDayEvent) )
   {
-    event->setFloats( true );
+    event->setAllDay( true );
 
     if ( appointment->startDay != 0 )
-      event->setDtStart( stringToQDate( appointment->startDay ).addDays( 1 ) );
+      event->setDtStart( stringToKDateTime( appointment->startDay ).addDays( 1 ) );
 
     if ( appointment->endDay != 0 )
-      event->setDtEnd( stringToQDate( appointment->endDay) );
-    
-    kdDebug() << " all day event." << endl;
+      //TODO: Use KDateTime::fromString()?
+      event->setDtEnd( stringToKDateTime( appointment->endDay) );
+    kDebug() <<" all day event.";
   }
   else
   {
-    event->setFloats( false );
+    event->setAllDay( false );
 
     if ( appointment->startDate != 0 ) {
-      event->setDtStart( charToQDateTime( appointment->startDate, mTimezone ) );
+      event->setDtStart( charToKDateTime( appointment->startDate, mTimeSpec ) );
+    }
+
+    if ( appointment->endDate != 0 ) {
+      event->setDtEnd( charToKDateTime( appointment->endDate, mTimeSpec ) );
     }
-    
-    if ( appointment->endDate != 0 )
-      event->setDtEnd( charToQDateTime( appointment->endDate, mTimezone ) );
   }
 
-  kdDebug() << "start date: " << event->dtStart() << endl;
-  kdDebug() << "end date: " << event->dtEnd() << endl;
+  kDebug() <<"start date:" << event->dtStart();
+  kDebug() <<"end date:" << event->dtEnd();
 
   if ( appointment->alarm ) {
     KCal::Alarm *alarm = event->newAlarm();
@@ -108,7 +109,7 @@ KCal::Event* IncidenceConverter::convertFromAppointment( ngwt__Appointment* appo
 
 ngwt__Appointment* IncidenceConverter::convertToAppointment( KCal::Event* event )
 {
-  kdDebug() << "IncidenceConverter::convertToAppointment()" << endl;
+  kDebug() <<"IncidenceConverter::convertToAppointment()";
   if ( !event )
     return 0;
 
@@ -128,40 +129,41 @@ ngwt__Appointment* IncidenceConverter::convertToAppointment( KCal::Event* event
     return 0;
   }
 
-  if ( event->doesFloat() ) {
+  if ( event->allDay
+      () ) {
     bool *allDayEvent = (bool*)soap_malloc( soap(), 1 );
     (*allDayEvent ) = true;
     appointment->allDayEvent = allDayEvent;
 
     if ( event->dtStart().isValid() ) {
-/*      kdDebug() << " convertToAppointment() raw start date: " << event->dtStart().toString() << endl;*/
-      QDateTime start = event->dtStart();
+/*      kDebug() << " convertToAppointment() raw start date: " << event->dtStart().toString();*/
+      KDateTime start = event->dtStart();
       start.setTime( QTime( 0, 0, 0 ) );
-      appointment->startDate = qDateTimeToChar( start, mTimezone );
+      appointment->startDate = kDateTimeToChar( start, mTimeSpec );
       //appointment->startDay = qDateToString( event->dtStart().date()/*.addDays( -1 )*/ );  
-/*      kdDebug() << "   converted start date: " << appointment->startDate << endl;*/
+/*      kDebug() << "   converted start date: " << appointment->startDate;*/
     }
     else
-      kdDebug() << "   event start date not valid " << endl;
+      kDebug() << "   event start date not valid ";
     if ( event->hasEndDate() ) {
-//       kdDebug() << " convertToAppointment() raw end date: " << event->dtEnd().toString() << endl;
-      QDateTime end = event->dtEnd();
+//       kDebug() << " convertToAppointment() raw end date: " << event->dtEnd().toString();
+      KDateTime end = event->dtEnd();
       end = end.addDays( 1 );
       end.setTime( QTime( 0, 0, 0 ) );
-      appointment->endDate = qDateTimeToChar( end, mTimezone );
+      appointment->endDate = kDateTimeToChar( end, mTimeSpec );
       //appointment->endDay = qDateToString( event->dtEnd().date() );
-//       kdDebug() << "   converted end date:" << appointment->endDate << endl;
+//       kDebug() << "   converted end date:" << appointment->endDate;
     }
     else
-      kdDebug() << "   event end date not valid " << endl;
+      kDebug() << "   event end date not valid ";
   } else {
     appointment->allDayEvent = 0;
 
     if ( event->dtStart().isValid() )
-      appointment->startDate = qDateTimeToChar( event->dtStart(), mTimezone );
+      appointment->startDate = kDateTimeToChar( event->dtStart(), mTimeSpec );
 
     if ( event->hasEndDate() )
-      appointment->endDate = qDateTimeToChar( event->dtEnd(), mTimezone );
+      appointment->endDate = kDateTimeToChar( event->dtEnd(), mTimeSpec );
   }
 
   enum ngwt__AcceptLevel * al = (enum ngwt__AcceptLevel*)soap_malloc(soap(), sizeof(enum ngwt__AcceptLevel));
@@ -206,12 +208,12 @@ KCal::Todo* IncidenceConverter::convertFromTask( ngwt__Task* task )
 
   if ( task->startDate ) {
     todo->setHasStartDate( true );
-    todo->setDtStart( stringToQDateTime( task->startDate ) );
+    todo->setDtStart( stringToKDateTime( task->startDate, mTimeSpec ) );
   }
 
   if ( task->dueDate ) {
     todo->setHasDueDate( true );
-    todo->setDtDue( stringToQDateTime( task->dueDate ) );
+    todo->setDtDue( stringToKDateTime( task->dueDate, mTimeSpec ) );
   }
 
   if ( task->taskPriority ) {
@@ -249,10 +251,10 @@ ngwt__Task* IncidenceConverter::convertToTask( KCal::Todo* todo )
   }
 
   if ( todo->dtStart().isValid() )
-    task->startDate = qDateTimeToString( todo->dtStart(), mTimezone );
+    task->startDate = kDateTimeToString( todo->dtStart(), mTimeSpec );
 
   if ( todo->hasDueDate() ) {
-    task->dueDate = qDateTimeToString( todo->dtDue() );
+    task->dueDate = kDateTimeToString( todo->dtDue() );
   }
 
   // FIXME: Restore custom priorities
@@ -270,21 +272,21 @@ ngwt__Task* IncidenceConverter::convertToTask( KCal::Todo* todo )
 
 KCal::Journal* IncidenceConverter::convertFromNote( ngwt__Note* note)
 {
-  kdDebug() << "IncidenceConverter::convertFromNote()" << endl;
+  kDebug();
   if ( !note )
     return 0;
 
   KCal::Journal *journal = new KCal::Journal();
 
   if ( !convertFromCalendarItem( note, journal ) ) {
-    kdDebug() << "Couldn't convert Note to Journal!" << endl;
+    kDebug() << "Couldn't convert Note to Journal!";
     delete journal;
     return 0;
   }
 
   if ( note->startDate ) {
-    kdDebug() << "Journal start date is: " << note->startDate->c_str() << endl;
-    journal->setDtStart( stringToQDate( note->startDate ) );
+    kDebug() << "Journal start date is: " << note->startDate->c_str();
+    journal->setDtStart( stringToKDateTime( note->startDate, mTimeSpec ) );
   }
 
   return journal;
@@ -302,12 +304,12 @@ ngwt__Note* IncidenceConverter::convertToNote( KCal::Journal* journal )
     return 0;
   }
 
-  if ( journal->doesFloat() ) {
+  if ( journal->allDay() ) {
     if ( journal->dtStart().isValid() )
       note->startDate = qDateToString( journal->dtStart().date() );
   } else {
     if ( journal->dtStart().isValid() )
-      note->startDate = qDateTimeToString( journal->dtStart(), mTimezone );
+      note->startDate = kDateTimeToString( journal->dtStart(), mTimeSpec );
   }
 
   if ( !note->subject )
@@ -317,7 +319,7 @@ ngwt__Note* IncidenceConverter::convertToNote( KCal::Journal* journal )
 
 bool IncidenceConverter::convertToCalendarItem( KCal::Incidence* incidence, ngwt__CalendarItem* item )
 {
-  kdDebug() << k_funcinfo << endl;
+  kDebug() ;
   //TODO: support the new iCal standard recurrence rule
 
   // ngwt__CalendarItem
@@ -370,7 +372,7 @@ bool IncidenceConverter::convertToCalendarItem( KCal::Incidence* incidence, ngwt
     std::vector<ngwt__ContainerRef*>* container = soap_new_std__vectorTemplateOfPointerTongwt__ContainerRef( soap(), -1 );
     ngwt__ContainerRef* containerRef = soap_new_ngwt__ContainerRef( soap(), -1 );
     containerRef->deleted = 0;
-    containerRef->__item = incidence->customProperty( "GWRESOURCE", "CONTAINER" ).utf8();
+    containerRef->__item = incidence->customProperty( "GWRESOURCE", "CONTAINER" ).toUtf8().data()/*.toUtf8().data()*/;
     container->push_back( containerRef );
 
     item->container = *container;
@@ -405,12 +407,12 @@ bool IncidenceConverter::convertToCalendarItem( KCal::Incidence* incidence, ngwt
 
 // TODO: reinstate when we know that this isn't causing problems with recurrence
 //   if ( incidence->created().isValid() ) {
-//     item->created = qDateTimeToChar( incidence->created(), mTimezone );
+//     item->created = kDateTimeToChar( incidence->created(), mTimeSpec );
 //   } else
 //     item->created = 0;
 
 //   if ( incidence->lastModified().isValid() )
-//     item->modified = qDateTimeToChar( incidence->lastModified(), mTimezone );
+//     item->modified = kDateTimeToChar( incidence->lastModified(), mTimeSpec );
 
   setItemDescription( incidence, item );
 
@@ -471,11 +473,10 @@ void IncidenceConverter::setAttendees( KCal::Incidence *incidence,
   for( it = attendees.begin(); it != attendees.end(); ++it ) {
     if ( !to.isEmpty() )
       to += QString::fromLatin1( ";  %1" ).arg( (*it)->name() );
-    kdDebug() << "IncidenceConverter::setAttendees(), adding " << (*it)->fullName()
-      << endl;
+    kDebug() <<"IncidenceConverter::setAttendees(), adding" << (*it)->fullName();
     QString uuid;
-    QValueList<KABC::Addressee> addList = KABC::StdAddressBook::self()->findByEmail( (*it)->email() );
-    if ( !addList.first().isEmpty() )
+    QList<KABC::Addressee> addList = KABC::StdAddressBook::self()->findByEmail( (*it)->email() );
+    if ( !addList.isEmpty() && !addList.first().isEmpty() )
       uuid = addList.first().custom( "GWRESOURCE", "UUID" ); //uuid may be mandatory for the recipients list to be stored on the server...
     item->distribution->recipients->recipient.push_back( createRecipient( (*it)->name(), (*it)->email(), uuid ) );
   }
@@ -493,13 +494,13 @@ ngwt__Recipient *IncidenceConverter::createRecipient( const QString &name,
   if ( !uuid.isEmpty() ) recipient->uuid = qStringToString( uuid );
   else recipient->uuid = 0;
   if ( !name.isEmpty() ) {
-    kdDebug() << "- recipient name: " << name << endl;
+    kDebug() <<"- recipient name:" << name;
     recipient->displayName = qStringToString( name );
   } else {
     recipient->displayName = 0;
   }
   if ( !email.isEmpty() ) {
-    kdDebug() << "- recipient email: " << email << endl;
+    kDebug() <<"- recipient email:" << email;
     recipient->email = qStringToString( email );
   } else {
     recipient->email = 0;
@@ -519,15 +520,16 @@ bool IncidenceConverter::convertFromCalendarItem( ngwt__CalendarItem* item,
   if ( item->subject && !item->subject->empty() )
     incidence->setSummary( stringToQString( item->subject ) );
 
-  kdDebug() << "SUMMARY: " << incidence->summary() << endl;
+  kDebug() <<"SUMMARY:" << incidence->summary();
 
   if ( item->created ) {
-    kdDebug() << "item created at " << item->created << endl;
-    incidence->setCreated( charToQDateTime( item->created, mTimezone ) );
+    kDebug() << "item created at " << item->created;
+    incidence->setCreated( charToKDateTime( item->created, mTimeSpec ) );
   }
+
   if ( item->modified != 0 ) {
-    kdDebug() << "item modified at " << item->created << endl;
-    incidence->setLastModified( charToQDateTime( item->modified, mTimezone ) );
+    kDebug() << "item modified at " << item->modified;
+    incidence->setLastModified( charToKDateTime( item->modified, mTimeSpec ) );
   }
 
   getItemDescription( item, incidence );
@@ -570,7 +572,7 @@ void IncidenceConverter::getItemDescription( ngwt__CalendarItem *item, KCal::Inc
       if ( stringToQString( (*it)->contentType ) == "text/plain" ) {
         QString description = QString::fromUtf8( (char*)data.__ptr, data.__size );
         incidence->setDescription( description );
-        kdDebug() << "Incidence description decodes to: " << description << endl;
+        kDebug() <<"Incidence description decodes to:" << description;
         return;
       }
     }
@@ -589,8 +591,10 @@ void IncidenceConverter::setItemDescription( KCal::Incidence *incidence,
 
     xsd__base64Binary data;
     data.__ptr =
-      (unsigned char*)qStringToChar( incidence->description().utf8() );
-    data.__size = incidence->description().utf8().length();
+      (unsigned char*)qStringToChar( incidence->description().toUtf8().data() );
+    data.__size = incidence->description().toUtf8().length();
+    data.id = data.type = data.option = 0;
+    data.soap = 0;
 
     part->id = 0;
     part->__item = data;
@@ -610,32 +614,35 @@ void IncidenceConverter::setItemDescription( KCal::Incidence *incidence,
 
 void IncidenceConverter::getAttendees( ngwt__CalendarItem *item, KCal::Incidence *incidence )
 {
-//   kdDebug() << "IncidenceConverter::getAttendees()" << ( item->subject ? item->subject->c_str() : "no subject" )
-//     << endl;
-
+  kDebug() << ( item->subject ? item->subject->c_str() : "no subject" );
+ 
   if ( item->distribution && item->distribution->from ) {
-/*    kdDebug() << "-- from" << endl;*/
+    kDebug() << "-- from";
     KCal::Person organizer( stringToQString( item->distribution->from->displayName ),
                             stringToQString( item->distribution->from->email ) );
     incidence->setOrganizer( organizer );
   }
 
   if ( item->distribution && item->distribution->recipients ) {
-/*    kdDebug() << "-- recipients" << endl;*/
+    kDebug() << "-- recipients";
     std::vector<ngwt__Recipient*> recipients = item->distribution->recipients->recipient;
     std::vector<ngwt__Recipient*>::const_iterator it;
 
     for ( it = recipients.begin(); it != recipients.end(); ++it ) {
-/*      kdDebug() << "---- recipient " << endl;
- */   ngwt__Recipient *recipient = *it;
+      ngwt__Recipient *recipient = *it;
+      kDebug() << "---- recipient " << recipient->email->c_str();
       KCal::Attendee *attendee = new KCal::Attendee(
         stringToQString( recipient->displayName ),
         stringToQString( recipient->email ) );
 
       // set our status
-      if ( *(recipient->email) == *(qStringToString( mFromEmail )) )
+      if ( emailsMatch( stringToQString(recipient->email), mFromEmail ) )
         if ( item->status->accepted )
           attendee->setStatus( ( *item->status->accepted ) ? KCal::Attendee::Accepted : KCal::Attendee::NeedsAction );
+        else
+          kDebug() << "---- found ourselves, but not accepted";
+      else
+        kDebug() << "---- '" <<  "' != '" << (qStringToString( mFromEmail ))->c_str() << "'";
 
       incidence->addAttendee( attendee );
     }
@@ -644,11 +651,11 @@ void IncidenceConverter::getAttendees( ngwt__CalendarItem *item, KCal::Incidence
 
 void IncidenceConverter::setRecurrence( KCal::Incidence * incidence, ngwt__CalendarItem * item )
 {
-  kdDebug() << k_funcinfo << endl;
+  kDebug() ;
   ngwt__Frequency * freq = 0;
   const KCal::Recurrence * recur = incidence->recurrence();
 
-  if ( incidence->doesRecur() )
+  if ( incidence->recurs() )
   {
     item->rrule = soap_new_ngwt__RecurrenceRule( soap(), -1 );
     item->rrule->frequency = 0; //
@@ -671,11 +678,7 @@ void IncidenceConverter::setRecurrence( KCal::Incidence * incidence, ngwt__Calen
       item->rrule->count = (long unsigned int *)soap_malloc( soap(), sizeof( long unsigned int * ) );
       *item->rrule->count = recur->duration();
     }
-#if LIBKCAL_IS_VERSION( 1, 3, 0 )
     else if ( recur->endDateTime().isValid() )
-#else
-		else if ( recur->endDate().isValid() )
-#endif
       item->rrule->until = qDateToString( recur->endDate() );
     else // GROUPWISE doesn't accept infinite recurrence so end after GW_MAX_RECURRENCES recurrences
     {
@@ -685,44 +688,32 @@ void IncidenceConverter::setRecurrence( KCal::Incidence * incidence, ngwt__Calen
 
     // recurrence date - try setting it using the recurrence start date - didn't help
 /*    std::string startDate;
-    startDate.append( recur->recurStart().date().toString( Qt::ISODate ).utf8() );
+    startDate.append( recur->recurStart().date().toString( Qt::ISODate ).toUtf8().data() );
     item->rdate = soap_new_ngwt__RecurrenceDateType( soap(), -1 );
     item->rdate->date.push_back( startDate );*/
     // exceptions list - try sending empty list even if no exceptions
-#if LIBKCAL_IS_VERSION( 1, 3, 0 )
     KCal::DateList exceptions = recur->exDates();
-#else
-		KCal::DateList exceptions = incidence->exDates();
-#endif
     if ( !exceptions.isEmpty() )
     {
       item->exdate = soap_new_ngwt__RecurrenceDateType( soap(), -1 );
       for ( KCal::DateList::ConstIterator it = exceptions.begin(); it != exceptions.end(); ++it )
       {
         std::string startDate;
-        startDate.append( (*it).toString( Qt::ISODate ).utf8() );
+        startDate.append( (*it).toString( Qt::ISODate ).toUtf8().data() );
         item->exdate->date.push_back( startDate );
       }
     }
   }
 
-#if LIBKCAL_IS_VERSION( 1, 3, 0 )
   if ( incidence->recurrenceType() == KCal::Recurrence::rDaily )
-#else
-  if ( incidence->doesRecur() == KCal::Recurrence::rDaily )
-#endif
   {
-    kdDebug() << "incidence recurs daily" << endl;
+    kDebug() <<"incidence recurs daily";
     *freq = Daily;
     item->rrule->frequency = freq;
   }
-#if LIBKCAL_IS_VERSION( 1, 3, 0 )
   else if ( incidence->recurrenceType() == KCal::Recurrence::rWeekly )
-#else
-  else if ( incidence->doesRecur() == KCal::Recurrence::rWeekly )
-#endif
   {
-    kdDebug() << "incidence recurs weekly" << endl;
+    kDebug() <<"incidence recurs weekly";
 #if 1 //trying out byDay recurrence
     *freq = Weekly;
     item->rrule->frequency = freq;
@@ -766,50 +757,32 @@ void IncidenceConverter::setRecurrence( KCal::Incidence * incidence, ngwt__Calen
     item->rrule->byDay = weeklyDays;
 #endif
   }
-#if LIBKCAL_IS_VERSION( 1, 3, 0 )
-   else if ( incidence->recurrenceType() == KCal::Recurrence::rMonthlyDay )
-#else
-   else if ( incidence->doesRecur() == KCal::Recurrence::rMonthlyDay )
-#endif
+  else if ( incidence->recurrenceType() == KCal::Recurrence::rMonthlyDay )
   {
-    kdDebug() << "incidence recurs monthly" << endl;
+    kDebug() <<"incidence recurs monthly";
     ;
     *freq = Monthly;
     item->rrule->frequency = freq;
 
     // TODO: translate '3rd wednesday of month' etc into rdates
   }
-#if LIBKCAL_IS_VERSION( 1, 3, 0 )
   else if ( incidence->recurrenceType() == KCal::Recurrence::rYearlyDay )
-#else
-  else if ( incidence->doesRecur() == KCal::Recurrence::rYearlyDay )
-#endif
   {
-    kdDebug() << "incidence recurs yearly on day #" << endl;
+    kDebug() <<"incidence recurs yearly on day #";
     *freq = Yearly;
     item->rrule->frequency = freq;
     // TODO: translate '1st sunday in may'
     ngwt__DayOfYearList * daysOfYear = soap_new_ngwt__DayOfYearList( soap(), -1 );
-#if LIBKCAL_IS_VERSION( 1, 3, 0 )
-    QValueList<int> rmd;
+    QList<int> rmd;
     rmd = recur->yearMonths();
     daysOfYear->day.push_back( rmd.first() );
-#else
-    QPtrList<int> rmd;
-    rmd = recur->yearNums();
-    daysOfYear->day.push_back( *rmd.first() );
-#endif
 
     item->rrule->byYearDay = daysOfYear;
     // no need to do MonthList recurrence as these will appear as separate instances when fetched from GW
   }
-#if LIBKCAL_IS_VERSION( 1, 3, 0 )
   else if ( incidence->recurrenceType() == KCal::Recurrence::rYearlyMonth )
-#else
-  else if ( incidence->doesRecur() == KCal::Recurrence::rYearlyMonth )
-#endif
   {
-    kdDebug() << "incidence recurs yearly on monthday" << endl;
+    kDebug() <<"incidence recurs yearly on monthday";
     *freq = Yearly;
     item->rrule->frequency = freq;
   }
