@@ -1,6 +1,6 @@
 /*
     This file is part of libkabc and/or kaddressbook.
-    Copyright (c) 2004 Klarlvdalens Datakonsult AB
+    Copyright (c) 2004 Klarälvdalens Datakonsult AB
         <info@klaralvdalens-datakonsult.se>
 
     This library is free software; you can redistribute it and/or
@@ -15,8 +15,8 @@
 
     You should have received a copy of the GNU Library General Public License
     along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-    Boston, MA 02111-1307, USA.
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 
     In addition, as a special exception, the copyright holders give
     permission to link the code of this program with any edition of
@@ -34,9 +34,11 @@
 #include "resourcekolab.h"
 
 #include <kabc/addressee.h>
+#include <kabc/stdaddressbook.h>
+#include <libkdepim/distributionlist.h>
 #include <kio/netaccess.h>
 #include <kdebug.h>
-#include <qfile.h>
+#include <QFile>
 #include <float.h>
 
 using namespace Kolab;
@@ -54,7 +56,7 @@ Contact::Contact( const KABC::Addressee* addr )
 }
 
 // loading (xml->addressee)
-Contact::Contact( const QString& xml, KABC::ResourceKolab* resource, const QString& subResource, Q_UINT32 sernum )
+Contact::Contact( const QString& xml, KABC::ResourceKolab* resource, const QString& subResource, quint32 sernum )
   : mHasGeo( false )
 {
   load( xml );
@@ -325,12 +327,12 @@ void Contact::addPhoneNumber( const PhoneNumber& number )
   mPhoneNumbers.append( number );
 }
 
-QValueList<Contact::PhoneNumber>& Contact::phoneNumbers()
+QList<Contact::PhoneNumber>& Contact::phoneNumbers()
 {
   return mPhoneNumbers;
 }
 
-const QValueList<Contact::PhoneNumber>& Contact::phoneNumbers() const
+const QList<Contact::PhoneNumber>& Contact::phoneNumbers() const
 {
   return mPhoneNumbers;
 }
@@ -340,12 +342,12 @@ void Contact::addEmail( const Email& email )
   mEmails.append( email );
 }
 
-QValueList<Contact::Email>& Contact::emails()
+QList<Contact::Email>& Contact::emails()
 {
   return mEmails;
 }
 
-const QValueList<Contact::Email>& Contact::emails() const
+const QList<Contact::Email>& Contact::emails() const
 {
   return mEmails;
 }
@@ -355,12 +357,12 @@ void Contact::addAddress( const Contact::Address& address )
   mAddresses.append( address );
 }
 
-QValueList<Contact::Address>& Contact::addresses()
+QList<Contact::Address>& Contact::addresses()
 {
   return mAddresses;
 }
 
-const QValueList<Contact::Address>& Contact::addresses() const
+const QList<Contact::Address>& Contact::addresses() const
 {
   return mAddresses;
 }
@@ -400,9 +402,9 @@ bool Contact::loadNameAttribute( QDomElement& element )
         setSuffix( e.text() );
       else
         // TODO: Unhandled tag - save for later storage
-        kdDebug() << "Warning: Unhandled tag " << e.tagName() << endl;
+        kDebug() <<"Warning: Unhandled tag" << e.tagName();
     } else
-      kdDebug() << "Node is not a comment or an element???" << endl;
+      kDebug() <<"Node is not a comment or an element???";
   }
 
   return true;
@@ -438,9 +440,9 @@ bool Contact::loadPhoneAttribute( QDomElement& element )
         number.number = e.text();
       else
         // TODO: Unhandled tag - save for later storage
-        kdDebug() << "Warning: Unhandled tag " << e.tagName() << endl;
+        kDebug() <<"Warning: Unhandled tag" << e.tagName();
     } else
-      kdDebug() << "Node is not a comment or an element???" << endl;
+      kDebug() <<"Node is not a comment or an element???";
   }
 
   addPhoneNumber( number );
@@ -449,7 +451,7 @@ bool Contact::loadPhoneAttribute( QDomElement& element )
 
 void Contact::savePhoneAttributes( QDomElement& element ) const
 {
-  QValueList<PhoneNumber>::ConstIterator it = mPhoneNumbers.begin();
+  QList<PhoneNumber>::ConstIterator it = mPhoneNumbers.begin();
   for ( ; it != mPhoneNumbers.end(); ++it ) {
     QDomElement e = element.ownerDocument().createElement( "phone" );
     element.appendChild( e );
@@ -461,7 +463,7 @@ void Contact::savePhoneAttributes( QDomElement& element ) const
 
 void Contact::saveEmailAttributes( QDomElement& element ) const
 {
-  QValueList<Email>::ConstIterator it = mEmails.begin();
+  QList<Email>::ConstIterator it = mEmails.begin();
   for ( ; it != mEmails.end(); ++it )
     saveEmailAttribute( element, *it );
 }
@@ -477,7 +479,7 @@ void Contact::loadCustomAttributes( QDomElement& element )
 
 void Contact::saveCustomAttributes( QDomElement& element ) const
 {
-  QValueList<Custom>::ConstIterator it = mCustomList.begin();
+  QList<Custom>::ConstIterator it = mCustomList.begin();
   for ( ; it != mCustomList.end(); ++it ) {
     Q_ASSERT( !(*it).name.isEmpty() );
     if ( (*it).app == s_unhandledTagAppName ) {
@@ -506,8 +508,12 @@ bool Contact::loadAddressAttribute( QDomElement& element )
 
       if ( tagName == "type" )
         address.type = e.text();
+      else if ( tagName == "x-kde-type" )
+        address.kdeAddressType = e.text().toInt();
       else if ( tagName == "street" )
         address.street = e.text();
+      else if ( tagName == "pobox" )
+        address.pobox = e.text();
       else if ( tagName == "locality" )
         address.locality = e.text();
       else if ( tagName == "region" )
@@ -518,9 +524,9 @@ bool Contact::loadAddressAttribute( QDomElement& element )
         address.country = e.text();
       else
         // TODO: Unhandled tag - save for later storage
-        kdDebug() << "Warning: Unhandled tag " << e.tagName() << endl;
+        kDebug() <<"Warning: Unhandled tag" << e.tagName();
     } else
-      kdDebug() << "Node is not a comment or an element???" << endl;
+      kDebug() <<"Node is not a comment or an element???";
   }
 
   addAddress( address );
@@ -529,104 +535,231 @@ bool Contact::loadAddressAttribute( QDomElement& element )
 
 void Contact::saveAddressAttributes( QDomElement& element ) const
 {
-  QValueList<Address>::ConstIterator it = mAddresses.begin();
+  QList<Address>::ConstIterator it = mAddresses.begin();
   for ( ; it != mAddresses.end(); ++it ) {
     QDomElement e = element.ownerDocument().createElement( "address" );
     element.appendChild( e );
     const Address& a = *it;
     writeString( e, "type", a.type );
-    writeString( e, "street", a.street );
+    writeString( e, "x-kde-type", QString::number( a.kdeAddressType ) );
+    if ( !a.street.isEmpty() )
+      writeString( e, "street", a.street );
+    if ( !a.pobox.isEmpty() )
+      writeString( e, "pobox", a.pobox );
+    if ( !a.locality.isEmpty() )
     writeString( e, "locality", a.locality );
-    writeString( e, "region", a.region );
-    writeString( e, "postal-code", a.postalCode );
-    writeString( e, "country", a.country );
+    if ( !a.region.isEmpty() )
+      writeString( e, "region", a.region );
+    if ( !a.postalCode.isEmpty() )
+      writeString( e, "postal-code", a.postalCode );
+    if ( !a.country.isEmpty() )
+      writeString( e, "country", a.country );
+  }
+}
+
+
+void Kolab::Contact::loadDistrListMember( const QDomElement& element )
+{
+  Member member;
+  for ( QDomNode n = element.firstChild(); !n.isNull(); n = n.nextSibling() ) {
+    if ( n.isComment() )
+      continue;
+    if ( n.isElement() ) {
+      QDomElement e = n.toElement();
+      QString tagName = e.tagName();
+      if ( tagName == "display-name" )
+        member.displayName = e.text();
+      else if ( tagName == "smtp-address" )
+        member.email = e.text();
+    }
+  }
+  mDistrListMembers.append( member );
+}
+
+void Contact::saveDistrListMembers( QDomElement& element ) const
+{
+  QList<Member>::ConstIterator it = mDistrListMembers.begin();
+  for( ; it != mDistrListMembers.end(); ++it ) {
+    QDomElement e = element.ownerDocument().createElement( "member" );
+    element.appendChild( e );
+    const Member& m = *it;
+    writeString( e, "display-name", m.displayName );
+    writeString( e, "smtp-address", m.email );
   }
 }
 
 bool Contact::loadAttribute( QDomElement& element )
 {
-  QString tagName = element.tagName();
-
-  if ( tagName == "name" )
-    return loadNameAttribute( element );
-  else if ( tagName == "role" )
-    setRole( element.text() );
-  else if ( tagName == "free-busy-url" )
-    setFreeBusyUrl( element.text() );
-  else if ( tagName == "organization" )
-    setOrganization( element.text() );
-  else if ( tagName == "web-page" )
-    setWebPage( element.text() );
-  else if ( tagName == "im-address" )
-    setIMAddress( element.text() );
-  else if ( tagName == "department" )
-    setDepartment( element.text() );
-  else if ( tagName == "office-location" )
-    setOfficeLocation( element.text() );
-  else if ( tagName == "profession" )
-    setProfession( element.text() );
-  else if ( tagName == "job-title" )
-    // see saveAttributes: <job-title> is mapped to the Role field
-    setRole( element.text() );
-  else if ( tagName == "manager-name" )
-    setManagerName( element.text() );
-  else if ( tagName == "assistant" )
-    setAssistant( element.text() );
-  else if ( tagName == "nick-name" )
-    setNickName( element.text() );
-  else if ( tagName == "spouse-name" )
-    setSpouseName( element.text() );
-  else if ( tagName == "birthday" ) {
-    if ( !element.text().isEmpty() )
-      setBirthday( stringToDate( element.text() ) );
-  }
-  else if ( tagName == "anniversary" ) {
-    if ( !element.text().isEmpty() )
-      setAnniversary( stringToDate( element.text() ) );
-  }
-  else if ( tagName == "picture" ) {
-    mPictureAttachmentName = element.text();
-  }
-  else if ( tagName == "x-logo" ) {
-    mLogoAttachmentName = element.text();
-  }
-  else if ( tagName == "x-sound" ) {
-    mSoundAttachmentName = element.text();
-  }
-  else if ( tagName == "children" )
-    setChildren( element.text() );
-  else if ( tagName == "gender" )
-    setGender( element.text() );
-  else if ( tagName == "language" )
-    setLanguage( element.text() );
-  else if ( tagName == "phone" )
-    return loadPhoneAttribute( element );
-  else if ( tagName == "email" ) {
-    Email email;
-    if ( loadEmailAttribute( element, email ) ) {
-      addEmail( email );
+  const QString tagName = element.tagName();
+  switch ( tagName[0].toLatin1() ) {
+  case 'a':
+    if ( tagName == "address" )
+      return loadAddressAttribute( element );
+    if ( tagName == "assistant" ) {
+      setAssistant( element.text() );
       return true;
-    } else
-      return false;
-  } else if ( tagName == "address" )
-    return loadAddressAttribute( element );
-  else if ( tagName == "preferred-address" )
-    setPreferredAddress( element.text() );
-  else if ( tagName == "latitude" ) {
-    setLatitude( element.text().toFloat() );
-    mHasGeo = true;
+    }
+    if ( tagName == "anniversary" ) {
+      if ( !element.text().isEmpty() )
+        setAnniversary( stringToDate( element.text() ) );
+      return true;
+    }
+    break;
+  case 'b':
+    if ( tagName == "birthday" ) {
+      if ( !element.text().isEmpty() )
+        setBirthday( stringToDate( element.text() ) );
+      return true;
+    }
+    break;
+  case 'c':
+    if ( tagName == "children" ) {
+      setChildren( element.text() );
+      return true;
+    }
+    break;
+  case 'd':
+    if ( tagName == "department" ) {
+      setDepartment( element.text() );
+      return true;
+    }
+    if ( mIsDistributionList && tagName == "display-name" ) {
+      setFullName( element.text() );
+      return true;
+    }
+    break;
+  case 'e':
+    if ( tagName == "email" ) {
+      Email email;
+      if ( loadEmailAttribute( element, email ) ) {
+        addEmail( email );
+        return true;
+      } else
+        return false;
+    }
+    break;
+  case 'f':
+    if ( tagName == "free-busy-url" ) {
+      setFreeBusyUrl( element.text() );
+      return true;
+    }
+    break;
+  case 'g':
+    if ( tagName == "gender" ) {
+      setGender( element.text() );
+      return true;
+    }
+    break;
+  case 'i':
+    if ( tagName == "im-address" ) {
+      setIMAddress( element.text() );
+      return true;
+    }
+    break;
+  case 'j':
+    if ( tagName == "job-title" ) {
+      // see saveAttributes: <job-title> is mapped to the Role field
+      setRole( element.text() );
+      return true;
+    }
+    break;
+  case 'l':
+    if ( tagName == "language" ) {
+      setLanguage( element.text() );
+      return true;
+    }
+    if ( tagName == "latitude" ) {
+      setLatitude( element.text().toFloat() );
+      mHasGeo = true;
+      return true;
+    }
+    if ( tagName == "longitude" ) {
+      setLongitude( element.text().toFloat() );
+      mHasGeo = true;
+    }
+    break;
+  case 'm':
+    if ( tagName == "manager-name" ) {
+      setManagerName( element.text() );
+      return true;
+    }
+    if ( mIsDistributionList && tagName == "member" ) {
+      loadDistrListMember( element );
+      return true;
+    }
+    break;
+  case 'n':
+    if ( tagName == "name" )
+      return loadNameAttribute( element );
+    if ( tagName == "nick-name" ) {
+      setNickName( element.text() );
+      return true;
+    }
+    break;
+  case 'o':
+    if ( tagName == "organization" ) {
+      setOrganization( element.text() );
+      return true;
+    }
+    if ( tagName == "office-location" ) {
+      setOfficeLocation( element.text() );
+      return true;
+    }
+    break;
+  case 'p':
+    if ( tagName == "profession" ) {
+      setProfession( element.text() );
+      return true;
+    }
+    if ( tagName == "picture" ) {
+      mPictureAttachmentName = element.text();
+      return true;
+    }
+    if ( tagName == "phone" ) {
+      return loadPhoneAttribute( element );
+      return true;
+    }
+    if ( tagName == "preferred-address" ) {
+      setPreferredAddress( element.text() );
+      return true;
+    }
+    break;
+  case 'r':
+    if ( tagName == "role" ) {
+      setRole( element.text() );
+      return true;
+    }
+    break;
+  case 's':
+    if ( tagName == "spouse-name" ) {
+      setSpouseName( element.text() );
+      return true;
+    }
+    break;
+  case 'x':
+    if ( tagName == "x-logo" ) {
+      mLogoAttachmentName = element.text();
+      return true;
+    }
+    if ( tagName == "x-sound" ) {
+      mSoundAttachmentName = element.text();
+      return true;
+    }
+    if ( tagName == "x-custom" ) {
+      loadCustomAttributes( element );
+      return true;
+    }
+    break;
+  case 'w':
+    if ( tagName == "web-page" ) {
+      setWebPage( element.text() );
+      return true;
+    }
+    break;
+  default:
+    break;
   }
-  else if ( tagName == "longitude" ) {
-    setLongitude( element.text().toFloat() );
-    mHasGeo = true;
-  }
-  else if ( tagName == "x-custom" )
-    loadCustomAttributes( element );
-  else
-    return KolabBase::loadAttribute( element );
-
-  // We handled this
-  return true;
+  return KolabBase::loadAttribute( element );
 }
 
 bool Contact::saveAttributes( QDomElement& element ) const
@@ -634,41 +767,46 @@ bool Contact::saveAttributes( QDomElement& element ) const
   // Save the base class elements
   KolabBase::saveAttributes( element );
 
-  saveNameAttribute( element );
-  writeString( element, "free-busy-url", freeBusyUrl() );
-  writeString( element, "organization", organization() );
-  writeString( element, "web-page", webPage() );
-  writeString( element, "im-address", imAddress() );
-  writeString( element, "department", department() );
-  writeString( element, "office-location", officeLocation() );
-  writeString( element, "profession", profession() );
-  // <role> is gone; jobTitle() is not shown in the addresseeeditor,
-  // so let's bind <job-title> to role()
-  //writeString( element, "role", role() );
-  //writeString( element, "job-title", jobTitle() );
-  writeString( element, "job-title", role() );
-  writeString( element, "manager-name", managerName() );
-  writeString( element, "assistant", assistant() );
-  writeString( element, "nick-name", nickName() );
-  writeString( element, "spouse-name", spouseName() );
-  writeString( element, "birthday", dateToString( birthday() ) );
-  writeString( element, "anniversary", dateToString( anniversary() ) );
-  if ( !picture().isNull() )
-    writeString( element, "picture", mPictureAttachmentName );
-  if ( !logo().isNull() )
-    writeString( element, "x-logo", mLogoAttachmentName );
-  if ( !sound().isNull() )
-    writeString( element, "x-sound", mSoundAttachmentName );
-  writeString( element, "children", children() );
-  writeString( element, "gender", gender() );
-  writeString( element, "language", language() );
-  savePhoneAttributes( element );
-  saveEmailAttributes( element );
-  saveAddressAttributes( element );
-  writeString( element, "preferred-address", preferredAddress() );
-  if ( mHasGeo ) {
-    writeString( element, "latitude", QString::number( latitude(), 'g', DBL_DIG ) );
-    writeString( element, "longitude", QString::number( longitude(), 'g', DBL_DIG ) );
+  if ( mIsDistributionList ) {
+    writeString( element, "display-name", fullName() );
+    saveDistrListMembers( element );
+  } else {
+    saveNameAttribute( element );
+    writeString( element, "free-busy-url", freeBusyUrl() );
+    writeString( element, "organization", organization() );
+    writeString( element, "web-page", webPage() );
+    writeString( element, "im-address", imAddress() );
+    writeString( element, "department", department() );
+    writeString( element, "office-location", officeLocation() );
+    writeString( element, "profession", profession() );
+    // <role> is gone; jobTitle() is not shown in the addresseeeditor,
+    // so let's bind <job-title> to role()
+    //writeString( element, "role", role() );
+    //writeString( element, "job-title", jobTitle() );
+    writeString( element, "job-title", role() );
+    writeString( element, "manager-name", managerName() );
+    writeString( element, "assistant", assistant() );
+    writeString( element, "nick-name", nickName() );
+    writeString( element, "spouse-name", spouseName() );
+    writeString( element, "birthday", dateToString( birthday() ) );
+    writeString( element, "anniversary", dateToString( anniversary() ) );
+    if ( !picture().isNull() )
+      writeString( element, "picture", mPictureAttachmentName );
+    if ( !logo().isNull() )
+      writeString( element, "x-logo", mLogoAttachmentName );
+    if ( !sound().isNull() )
+      writeString( element, "x-sound", mSoundAttachmentName );
+    writeString( element, "children", children() );
+    writeString( element, "gender", gender() );
+    writeString( element, "language", language() );
+    savePhoneAttributes( element );
+    saveEmailAttributes( element );
+    saveAddressAttributes( element );
+    writeString( element, "preferred-address", preferredAddress() );
+    if ( mHasGeo ) {
+      writeString( element, "latitude", QString::number( latitude(), 'g', DBL_DIG ) );
+      writeString( element, "longitude", QString::number( longitude(), 'g', DBL_DIG ) );
+    }
   }
   saveCustomAttributes( element );
 
@@ -679,12 +817,14 @@ bool Contact::loadXML( const QDomDocument& document )
 {
   QDomElement top = document.documentElement();
 
-  if ( top.tagName() != "contact" ) {
-    qWarning( "XML error: Top tag was %s instead of the expected contact",
-              top.tagName().ascii() );
+  mIsDistributionList = top.tagName() == "distribution-list";
+  if ( top.tagName() != "contact" && !mIsDistributionList ) {
+    qWarning( "XML error: Top tag was %s instead of the expected contact or distribution-list",
+              top.tagName().toAscii().data() );
     return false;
   }
 
+
   for ( QDomNode n = top.firstChild(); !n.isNull(); n = n.nextSibling() ) {
     if ( n.isComment() )
       continue;
@@ -692,7 +832,7 @@ bool Contact::loadXML( const QDomDocument& document )
       QDomElement e = n.toElement();
       if ( !loadAttribute( e ) ) {
         // Unhandled tag - save for later storage
-        //kdDebug() << "Saving unhandled tag " << e.tagName() << endl;
+        //kDebug() <<"Saving unhandled tag" << e.tagName();
         Custom c;
         c.app = s_unhandledTagAppName;
         c.name = e.tagName();
@@ -700,7 +840,7 @@ bool Contact::loadXML( const QDomDocument& document )
         mCustomList.append( c );
       }
     } else
-      kdDebug() << "Node is not a comment or an element???" << endl;
+      kDebug() <<"Node is not a comment or an element???";
   }
 
   return true;
@@ -709,7 +849,8 @@ bool Contact::loadXML( const QDomDocument& document )
 QString Contact::saveXML() const
 {
   QDomDocument document = domTree();
-  QDomElement element = document.createElement( "contact" );
+  QDomElement element = document.createElement(
+    mIsDistributionList ? "distribution-list" : "contact" );
   element.setAttribute( "version", "1.0" );
   saveAttributes( element );
   document.appendChild( element );
@@ -735,7 +876,7 @@ static int addressTypeFromString( const QString& type )
   return KABC::Address::Dom | KABC::Address::Intl | KABC::Address::Postal | KABC::Address::Parcel;
 }
 
-static QStringList phoneTypeToString( int /*KABC::PhoneNumber::Types*/ type )
+static QStringList phoneTypeToString( KABC::PhoneNumber::Type type )
 {
   // KABC has a bitfield, i.e. the same phone number can be used for work and home
   // and fax and cellphone etc. etc.
@@ -750,12 +891,28 @@ static QStringList phoneTypeToString( int /*KABC::PhoneNumber::Types*/ type )
     type = type & ~KABC::PhoneNumber::Work;
   }
 
+  // To support both "home1" and "home2", map Home+Pref to home1
+  if ( ( type & KABC::PhoneNumber::Home ) && ( type & KABC::PhoneNumber::Pref ) )
+  {
+      types << "home1";
+      type = type & ~KABC::PhoneNumber::Home;
+      type = type & ~KABC::PhoneNumber::Pref;
+  }
+  // To support both "business1" and "business2", map Work+Pref to business1
+  if ( ( type & KABC::PhoneNumber::Work ) && ( type & KABC::PhoneNumber::Pref ) )
+  {
+      types << "business1";
+      type = type & ~KABC::PhoneNumber::Work;
+      type = type & ~KABC::PhoneNumber::Pref;
+  }
+
+
   if ( type & KABC::PhoneNumber::Home )
-    types << "home1";
-  if ( type & KABC::PhoneNumber::Msg ) // messaging
-    types << "home2"; // #
+    types << "home2";
+  if ( type & KABC::PhoneNumber::Msg ) // Msg==messaging
+    types << "company";
   if ( type & KABC::PhoneNumber::Work )
-    types << "business1";
+    types << "business2";
   if ( type & KABC::PhoneNumber::Pref )
     types << "primary";
   if ( type & KABC::PhoneNumber::Voice )
@@ -776,23 +933,25 @@ static QStringList phoneTypeToString( int /*KABC::PhoneNumber::Types*/ type )
     types << "assistant"; // ## Assistant is e.g. secretary
   if ( type & KABC::PhoneNumber::Pager )
     types << "pager";
-  // "company" and "business2" are not generated...
   return types;
 }
 
-static int /*KABC::PhoneNumber::Types*/ phoneTypeFromString( const QString& type )
+static KABC::PhoneNumber::Type phoneTypeFromString( const QString& type )
 {
   if ( type == "homefax" )
     return KABC::PhoneNumber::Home | KABC::PhoneNumber::Fax;
   if ( type == "businessfax" )
     return KABC::PhoneNumber::Work | KABC::PhoneNumber::Fax;
-
-  if ( type == "home1" )
-    return KABC::PhoneNumber::Home;
-  if ( type == "home2" )
-    return KABC::PhoneNumber::Msg;
   if ( type == "business1" )
+    return KABC::PhoneNumber::Work | KABC::PhoneNumber::Pref;
+  if ( type == "business2" )
     return KABC::PhoneNumber::Work;
+  if ( type == "home1" )
+    return KABC::PhoneNumber::Home | KABC::PhoneNumber::Pref;
+  if ( type == "home2" )
+    return KABC::PhoneNumber::Home;
+  if ( type == "company" )
+    return KABC::PhoneNumber::Msg;
   if ( type == "primary" )
     return KABC::PhoneNumber::Pref;
   if ( type == "callback" )
@@ -813,22 +972,18 @@ static int /*KABC::PhoneNumber::Types*/ phoneTypeFromString( const QString& type
     return KABC::PhoneNumber::Pcs;
   if ( type == "pager" )
     return KABC::PhoneNumber::Pager;
-  if ( type == "company" )
-    return KABC::PhoneNumber::Work; // # duplicated
-  if ( type == "business2" )
-    return KABC::PhoneNumber::Work; // # duplicated
   return KABC::PhoneNumber::Home; // whatever
 }
 
 static const char* s_knownCustomFields[] = {
   "X-IMAddress",
-  "X-Department",
   "X-Office",
   "X-Profession",
   "X-ManagersName",
   "X-AssistantsName",
   "X-SpousesName",
   "X-Anniversary",
+  "DistributionList",
   0
 };
 
@@ -837,6 +992,23 @@ void Contact::setFields( const KABC::Addressee* addressee )
 {
   KolabBase::setFields( addressee );
 
+  mIsDistributionList = KPIM::DistributionList::isDistributionList( *addressee );
+  if ( mIsDistributionList ) {
+    // Hopefully all resources are available during saving, so we can look up
+    // in the addressbook to get name+email from the UID.
+    KPIM::DistributionList distrList( *addressee );
+    const KPIM::DistributionList::Entry::List entries = distrList.entries( KABC::StdAddressBook::self() );
+    KPIM::DistributionList::Entry::List::ConstIterator it = entries.begin();
+    for ( ; it != entries.end() ; ++it ) {
+      Member m;
+      m.displayName = (*it).addressee.formattedName();
+      m.email = (*it).email;
+      if ( m.email.isEmpty() )
+        m.email = (*it).addressee.preferredEmail();
+      mDistrListMembers.append( m );
+    }
+  }
+
   setGivenName( addressee->givenName() );
   setMiddleNames( addressee->additionalName() );
   setLastName( addressee->familyName() );
@@ -846,7 +1018,7 @@ void Contact::setFields( const KABC::Addressee* addressee )
   setOrganization( addressee->organization() );
   setWebPage( addressee->url().url() );
   setIMAddress( addressee->custom( "KADDRESSBOOK", "X-IMAddress" ) );
-  setDepartment( addressee->custom( "KADDRESSBOOK", "X-Department" ) );
+  setDepartment( addressee->department() );
   setOfficeLocation( addressee->custom( "KADDRESSBOOK", "X-Office" ) );
   setProfession( addressee->custom( "KADDRESSBOOK", "X-Profession" ) );
   setRole( addressee->role() );
@@ -856,8 +1028,10 @@ void Contact::setFields( const KABC::Addressee* addressee )
   setNickName( addressee->nickName() );
   setSpouseName( addressee->custom( "KADDRESSBOOK", "X-SpousesName" ) );
   if ( !addressee->birthday().isNull() )
-  	setBirthday( addressee->birthday().date() );
-  setAnniversary( stringToDate( addressee->custom( "KADDRESSBOOK", "X-Anniversary" ) ) );
+    setBirthday( addressee->birthday().date() );
+  const QString& anniversary = addressee->custom( "KADDRESSBOOK", "X-Anniversary" );
+  if ( !anniversary.isEmpty() )
+    setAnniversary( stringToDate( anniversary  ) );
 
   const QStringList emails = addressee->emails();
   // Conversion problem here:
@@ -875,16 +1049,18 @@ void Contact::setFields( const KABC::Addressee* addressee )
   const KABC::Address::List addresses = addressee->addresses();
   for ( KABC::Address::List::ConstIterator it = addresses.begin() ; it != addresses.end(); ++it ) {
     Address address;
-    address.type = addressTypeToString( (*it).type() );
+    address.kdeAddressType = (*it).type();
+    address.type = addressTypeToString( address.kdeAddressType );
     address.street = (*it).street();
+    address.pobox = (*it).postOfficeBox();
     address.locality = (*it).locality();
     address.region = (*it).region();
     address.postalCode = (*it).postalCode();
     address.country = (*it).country();
-    // ## TODO not in the XML format: post-office-box and extended address info.
+    // ## TODO not in the XML format: extended address info.
     // ## KDE-specific tags? Or hiding those fields? Or adding a warning?
     addAddress( address );
-    if ( (*it).type() & KABC::Address::Pref ) {
+    if ( address.kdeAddressType & KABC::Address::Pref ) {
       preferredAddress = address.type; // home, business or other
     }
   }
@@ -932,17 +1108,17 @@ void Contact::setFields( const KABC::Addressee* addressee )
   for( QStringList::Iterator it = customs.begin(); it != customs.end(); ++it ) {
     // KABC::Addressee doesn't offer a real way to iterate over customs, other than splitting strings ourselves
     // The format is "app-name:value".
-    int pos = (*it).find( '-' );
+    int pos = (*it).indexOf( '-' );
     if ( pos == -1 ) continue;
     QString app = (*it).left( pos );
     if ( app == "KOLAB" ) continue;
     QString name = (*it).mid( pos + 1 );
-    pos = name.find( ':' );
+    pos = name.indexOf( ':' );
     if ( pos == -1 ) continue;
     QString value = name.mid( pos + 1 );
     name = name.left( pos );
     if ( !knownCustoms.contains( name ) ) {
-      //kdDebug() << k_funcinfo << "app=" << app << " name=" << name << " value=" << value << endl;
+      //kDebug() <<"app=" << app <<" name=" << name <<" value=" << value;
       Custom c;
       if ( app != "KADDRESSBOOK" ) // that's the default
         c.app = app;
@@ -957,9 +1133,8 @@ void Contact::setFields( const KABC::Addressee* addressee )
   // So it doesn't matter much if we don't have them in the XML.
   // mailer, timezone, productId, sortString, agent, rfc2426 name()
 
-  // TODO: Things KAddressBook can't handle:
+  // Things KAddressBook can't handle, so they are saved as unhandled tags:
   // initials, children, gender, language
-  // Well, so that's part of the "unhandled" tag thing.
 
   // TODO: Free/Busy URL. This is done rather awkward in KAddressBook -
   // it stores it in a local file through a korganizer file :-(
@@ -971,16 +1146,33 @@ void Contact::saveTo( KABC::Addressee* addressee )
   // TODO: This needs the same set of TODOs as the setFields method
   KolabBase::saveTo( addressee );
 
+  if ( mIsDistributionList ) {
+    KPIM::DistributionList distrList( *addressee );
+    distrList.setName( fullName() );
+    QList<Member>::ConstIterator mit = mDistrListMembers.begin();
+    for ( ; mit != mDistrListMembers.end(); ++mit ) {
+      QString displayName = (*mit).displayName;
+      // fixup the display name DistributionList::assumes neither ',' nor ';' is present
+      displayName.replace( ',', ' ' );
+      displayName.replace( ';', ' ' );
+      distrList.insertEntry( displayName, (*mit).email );
+    }
+    addressee->insertCustom( "KADDRESSBOOK", "DistributionList", distrList.custom( "KADDRESSBOOK", "DistributionList" ) );
+    Q_ASSERT( KPIM::DistributionList::isDistributionList( *addressee ) );
+  }
+
   addressee->setGivenName( givenName() );
   addressee->setAdditionalName( middleNames() );
   addressee->setFamilyName( lastName() );
   addressee->setFormattedName( fullName() );
+  if ( mIsDistributionList )
+    addressee->setName( fullName() );
   addressee->setPrefix( prefix() );
   addressee->setSuffix( suffix() );
   addressee->setOrganization( organization() );
   addressee->setUrl( webPage() );
   addressee->insertCustom( "KADDRESSBOOK", "X-IMAddress", imAddress() );
-  addressee->insertCustom( "KADDRESSBOOK", "X-Department", department() );
+  addressee->setDepartment( department() );
   addressee->insertCustom( "KADDRESSBOOK", "X-Office", officeLocation() );
   addressee->insertCustom( "KADDRESSBOOK", "X-Profession", profession() );
   addressee->setRole( role() );
@@ -1016,19 +1208,23 @@ void Contact::saveTo( KABC::Addressee* addressee )
     addressee->setGeo( KABC::Geo( mLatitude, mLongitude ) );
 
   QStringList emailAddresses;
-  for ( QValueList<Email>::ConstIterator it = mEmails.begin(); it != mEmails.end(); ++it ) {
+  for ( QList<Email>::ConstIterator it = mEmails.begin(); it != mEmails.end(); ++it ) {
     // we can't do anything with (*it).displayName
     emailAddresses.append( (*it).smtpAddress );
   }
   addressee->setEmails( emailAddresses );
 
-  for ( QValueList<Address>::ConstIterator it = mAddresses.begin(); it != mAddresses.end(); ++it ) {
+  for ( QList<Address>::ConstIterator it = mAddresses.begin(); it != mAddresses.end(); ++it ) {
     KABC::Address address;
-    int type = addressTypeFromString( (*it).type );
-    if ( (*it).type == mPreferredAddress )
-      type |= KABC::Address::Pref;
-    address.setType( type );
+    int type = (*it).kdeAddressType;
+    if ( type == -1 ) { // no kde-specific type available
+      type = addressTypeFromString( (*it).type );
+      if ( (*it).type == mPreferredAddress )
+        type |= KABC::Address::Pref;
+    }
+    address.setType( static_cast<KABC::Address::Type>(type) );
     address.setStreet( (*it).street );
+    address.setPostOfficeBox( (*it).pobox );
     address.setLocality( (*it).locality );
     address.setRegion( (*it).region );
     address.setPostalCode( (*it).postalCode );
@@ -1036,24 +1232,24 @@ void Contact::saveTo( KABC::Addressee* addressee )
     addressee->insertAddress( address );
   }
 
-  for ( QValueList<PhoneNumber>::ConstIterator it = mPhoneNumbers.begin(); it != mPhoneNumbers.end(); ++it ) {
+  for ( QList<PhoneNumber>::ConstIterator it = mPhoneNumbers.begin(); it != mPhoneNumbers.end(); ++it ) {
     KABC::PhoneNumber number;
     number.setType( phoneTypeFromString( (*it).type ) );
     number.setNumber( (*it).number );
     addressee->insertPhoneNumber( number );
   }
 
-  for( QValueList<Custom>::ConstIterator it = mCustomList.begin(); it != mCustomList.end(); ++it ) {
+  for( QList<Custom>::ConstIterator it = mCustomList.begin(); it != mCustomList.end(); ++it ) {
     QString app = (*it).app.isEmpty() ? QString::fromLatin1( "KADDRESSBOOK" ) : (*it).app;
     addressee->insertCustom( app, (*it).name, (*it).value );
   }
-  //kdDebug(5006) << addressee->customs() << endl;
+  //kDebug(5006) << addressee->customs();
 }
 
-QImage Contact::loadPictureFromKMail( const QString& attachmentName, KABC::ResourceKolab* resource, const QString& subResource, Q_UINT32 sernum )
+QImage Contact::loadPictureFromKMail( const QString& attachmentName, KABC::ResourceKolab* resource, const QString& subResource, quint32 sernum )
 {
   QImage img;
-  KURL url;
+  KUrl url;
   if ( resource->kmailGetAttachment( url, subResource, sernum, attachmentName ) && !url.isEmpty() ) {
     const QString path = url.path();
     img.load( path );
@@ -1076,13 +1272,13 @@ QImage Contact::loadPictureFromAddressee( const KABC::Picture& picture )
   return img;
 }
 
-QByteArray Kolab::Contact::loadDataFromKMail( const QString& attachmentName, KABC::ResourceKolab* resource, const QString& subResource, Q_UINT32 sernum )
+QByteArray Kolab::Contact::loadDataFromKMail( const QString& attachmentName, KABC::ResourceKolab* resource, const QString& subResource, quint32 sernum )
 {
   QByteArray data;
-  KURL url;
+  KUrl url;
   if ( resource->kmailGetAttachment( url, subResource, sernum, attachmentName ) && !url.isEmpty() ) {
     QFile f( url.path() );
-    if ( f.open( IO_ReadOnly ) ) {
+    if ( f.open( QIODevice::ReadOnly ) ) {
       data = f.readAll();
       f.close();
     }
@@ -1098,7 +1294,7 @@ QByteArray Kolab::Contact::loadSoundFromAddressee( const KABC::Sound& sound )
     QString tmpFile;
     if ( KIO::NetAccess::download( sound.url(), tmpFile, 0 /*no widget known*/ ) ) {
       QFile f( tmpFile );
-      if ( f.open( IO_ReadOnly ) ) {
+      if ( f.open( QIODevice::ReadOnly ) ) {
         data = f.readAll();
         f.close();
       }
