@@ -21,6 +21,8 @@
 #include "webdavhandler.h"
 #include "sloxbase.h"
 
+#include "config-slox.h"
+
 #ifdef HAVE_VALUES_H
 #include <values.h>
 #else
@@ -29,17 +31,17 @@
 #endif
 #endif
 
-#include <config.h>
+#include <climits>
 #include <stdlib.h>
 
-#include <libkcal/incidence.h>
+#include <kcal/incidence.h>
 
 #include <libkdepim/kpimprefs.h>
 
 #include <kdebug.h>
 #include <kconfig.h>
 
-#include <qfile.h>
+#include <QFile>
 
 SloxItem::SloxItem()
   : status( Invalid )
@@ -51,10 +53,10 @@ WebdavHandler::WebdavHandler()
 {
   KConfig cfg( "sloxrc" );
 
-  cfg.setGroup( "General" );
-  mLogFile = cfg.readEntry( "LogFile" );
+  const KConfigGroup cg( &cfg, "General" );
+  mLogFile = cg.readEntry( "LogFile" );
 
-  kdDebug() << "LOG FILE: " << mLogFile << endl;
+  kDebug() <<"LOG FILE:" << mLogFile;
 }
 
 void WebdavHandler::setUserId( const QString &id )
@@ -72,24 +74,24 @@ void WebdavHandler::log( const QString &text )
 {
   if ( mLogFile.isEmpty() ) return;
 
-  QString filename = mLogFile + "-" + QString::number( mLogCount );
+  QString filename = mLogFile + '-' + QString::number( mLogCount );
   QFile file( filename );
-  if ( !file.open( IO_WriteOnly ) ) {
-    kdWarning() << "Unable to open log file '" << filename << "'" << endl;
+  if ( !file.open( QIODevice::WriteOnly ) ) {
+    kWarning() <<"Unable to open log file '" << filename <<"'";
     return;
   }
 
-  QCString textUtf8 = text.utf8();
-  file.writeBlock( textUtf8.data(), textUtf8.size() - 1 );
+  QByteArray textUtf8 = text.toUtf8();
+  file.write( textUtf8.data(), textUtf8.size() - 1 );
 
   if ( ++mLogCount > 5 ) mLogCount = 0;
 }
 
-QValueList<SloxItem> WebdavHandler::getSloxItems( SloxBase *res, const QDomDocument &doc )
+QList<SloxItem> WebdavHandler::getSloxItems( SloxBase *res, const QDomDocument &doc )
 {
-  kdDebug() << "getSloxItems" << endl;
+  kDebug() <<"getSloxItems";
 
-  QValueList<SloxItem> items;
+  QList<SloxItem> items;
 
   QDomElement docElement = doc.documentElement();
 
@@ -102,20 +104,20 @@ QValueList<SloxItem> WebdavHandler::getSloxItems( SloxBase *res, const QDomDocum
 
       QDomNode propstat = responseElement.namedItem( "propstat" );
       if ( propstat.isNull() ) {
-        kdError() << "Unable to find propstat tag." << endl;
+        kError() <<"Unable to find propstat tag.";
         continue;
       }
 
       QDomNode prop = propstat.namedItem( "prop" );
       if ( prop.isNull() ) {
-        kdError() << "Unable to find WebDAV property" << endl;
+        kError() <<"Unable to find WebDAV property";
         continue;
       }
       item.domNode = prop;
 
       QDomNode sloxIdNode = prop.namedItem( res->fieldName( SloxBase::ObjectId ) );
       if ( sloxIdNode.isNull() ) {
-        kdError() << "Unable to find SLOX id." << endl;
+        kError() <<"Unable to find SLOX id.";
         continue;
       }
       QDomElement sloxIdElement = sloxIdNode.toElement();
@@ -141,14 +143,14 @@ QValueList<SloxItem> WebdavHandler::getSloxItems( SloxBase *res, const QDomDocum
 
       QDomNode status = propstat.namedItem( "status" );
       if ( status.isNull() ) {
-        kdError() << "Unable to find WebDAV status" << endl;
+        kError() <<"Unable to find WebDAV status";
         continue;
       }
       item.response = status.toElement().text();
 
       QDomNode desc = propstat.namedItem( "responsedescription" );
       if ( desc.isNull() ) {
-        kdError() << "Unable to find WebDAV responsedescription" << endl;
+        kError() <<"Unable to find WebDAV responsedescription";
         continue;
       }
       item.responseDescription = desc.toElement().text();
@@ -167,30 +169,33 @@ QString WebdavHandler::qDateTimeToSlox( const QDateTime &dt )
   return QString::number( ticks ) + "000";
 }
 
-QString WebdavHandler::qDateTimeToSlox( const QDateTime &dt,
-                                        const QString &timeZoneId )
+QString WebdavHandler::kDateTimeToSlox( const KDateTime &dt )
 {
-  QDateTime utc = KPimPrefs::localTimeToUtc( dt, timeZoneId );
-
-  // secsTo and toTime_t etc also perform a timezone conversion using the system timezone,
-  // but we want to use the calendar timezone, so we have to convert ourself and spoof the tz to UTC before
-  // converting to ticks to prevent this
-  QCString origTz = getenv("TZ");
-  setenv( "TZ", "UTC", 1 );
-  uint ticks = utc.toTime_t();
-  if ( origTz.isNull() )
-    unsetenv( "TZ" );
-  else
-    setenv( "TZ", origTz, 1 );
+  uint ticks = dt.toTime_t();
 
   return QString::number( ticks ) + "000";
 }
 
+KDateTime WebdavHandler::sloxToKDateTime( const QString &str )
+{
+  QString s = str.mid( 0, str.length() - 3 );
+  qlonglong ticks = s.toLongLong();
+
+  KDateTime dt;
+  dt.setTime_t( ticks );
+  return dt;
+}
+
+KDateTime WebdavHandler::sloxToKDateTime( const QString &str, const KDateTime::Spec &timeSpec )
+{
+  return sloxToKDateTime( str ).toTimeSpec( timeSpec );
+}
+
 QDateTime WebdavHandler::sloxToQDateTime( const QString &str )
 {
   QString s = str.mid( 0, str.length() - 3 );
 
-  bool preEpoch = s.startsWith("-");
+  bool preEpoch = s.startsWith('-');
   if (preEpoch)
      s = s.mid(1);
 
@@ -199,7 +204,8 @@ QDateTime WebdavHandler::sloxToQDateTime( const QString &str )
   QDateTime dt;
 
   if (preEpoch) {
-    dt.setTime_t( 0, Qt::UTC );
+    dt.setTime_t( 0 );
+    dt.setTimeSpec( Qt::UTC );
     if (ticks > INT_MAX) {
       dt = dt.addSecs(-INT_MAX);
       ticks -= INT_MAX;
@@ -208,18 +214,13 @@ QDateTime WebdavHandler::sloxToQDateTime( const QString &str )
   }
   else
   {
-    dt.setTime_t( ticks, Qt::UTC );
+    dt.setTime_t( ticks );
+    dt.setTimeSpec( Qt::UTC );
   }
 
   return dt;
 }
 
-QDateTime WebdavHandler::sloxToQDateTime( const QString &str,
-                                          const QString &timeZoneId )
-{
-  return KPimPrefs::utcToLocalTime( sloxToQDateTime(str), timeZoneId );
-}
-
 QDomElement WebdavHandler::addElement( QDomDocument &doc, QDomNode &node,
                                        const QString &tag )
 {
@@ -256,10 +257,10 @@ QDomElement WebdavHandler::addSloxElement( SloxBase *res,
 
 void WebdavHandler::parseSloxAttribute( const QDomElement &e )
 {
-//  kdDebug() << "parseSloxAttribute" << endl;
+//  kDebug() <<"parseSloxAttribute";
 
   QString tag = e.tagName();
-  QString text = QString::fromUtf8( e.text().latin1() );
+  QString text = QString::fromUtf8( e.text().toLatin1() );
   if ( text.isEmpty() ) return;
 
   if ( tag == "owner" ) {
