@@ -1,5 +1,5 @@
 /* kldapclient.cpp - LDAP access
- *      Copyright (C) 2002 Klarlvdalens Datakonsult AB
+ *      Copyright (C) 2002 Klarälvdalens Datakonsult AB
  *
  *      Author: Steffen Hansen <hansen@kde.org>
  *
@@ -20,66 +20,36 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
  */
 
-
-
-#include <qfile.h>
-#include <qimage.h>
-#include <qlabel.h>
-#include <qpixmap.h>
-#include <qtextstream.h>
-#include <qurl.h>
-
-#include <kabc/ldapurl.h>
-#include <kabc/ldif.h>
-#include <kapplication.h>
-#include <kconfig.h>
-#include <kdebug.h>
-#include <kdirwatch.h>
-#include <kmdcodec.h>
-#include <kprotocolinfo.h>
-#include <kstandarddirs.h>
-#include <kstaticdeleter.h>
-
 #include "ldapclient.h"
 
+#include <kldap/ldapurl.h>
+#include <kldap/ldif.h>
+
+#include <KCodecs>
+#include <KConfig>
+#include <KConfigGroup>
+#include <KDebug>
+#include <KDirWatch>
+#include <KProtocolInfo>
+#include <KStandardDirs>
+#include <K3StaticDeleter>
+
+#include <QFile>
+#include <QImage>
+#include <QLabel>
+#include <QPixmap>
+#include <QTextStream>
+
 using namespace KPIM;
 
 KConfig *KPIM::LdapSearch::s_config = 0L;
-static KStaticDeleter<KConfig> configDeleter;
-
-QString LdapObject::toString() const
-{
-  QString result = QString::fromLatin1( "\ndn: %1\n" ).arg( dn );
-  for ( LdapAttrMap::ConstIterator it = attrs.begin(); it != attrs.end(); ++it ) {
-    QString attr = it.key();
-    for ( LdapAttrValue::ConstIterator it2 = (*it).begin(); it2 != (*it).end(); ++it2 ) {
-      result += QString::fromUtf8( KABC::LDIF::assembleLine( attr, *it2, 76 ) ) + "\n";
-    }
-  }
-
-  return result;
-}
-
-void LdapObject::clear()
-{
-  dn = QString::null;
-  objectClass = QString::null;
-  attrs.clear();
-}
-
-void LdapObject::assign( const LdapObject& that )
-{
-  if ( &that != this ) {
-    dn = that.dn;
-    attrs = that.attrs;
-    client = that.client;
-  }
-}
+static K3StaticDeleter<KConfig> configDeleter;
 
 LdapClient::LdapClient( int clientNumber, QObject* parent, const char* name )
-  : QObject( parent, name ), mJob( 0 ), mActive( false ), mReportObjectClass( false )
+  : QObject( parent ), mJob( 0 ), mActive( false )
 {
 //  d = new LdapClientPrivate;
+  setObjectName(name);
   mClientNumber = clientNumber;
   mCompletionWeight = 50 - mClientNumber;
 }
@@ -93,55 +63,29 @@ LdapClient::~LdapClient()
 void LdapClient::setAttrs( const QStringList& attrs )
 {
   mAttrs = attrs;
-  for ( QStringList::Iterator it = mAttrs.begin(); it != mAttrs.end(); ++it )
-    if( (*it).lower() == "objectclass" ){
-      mReportObjectClass = true;
-      return;
-    }
-  mAttrs << "objectClass"; // via objectClass we detect distribution lists
-  mReportObjectClass = false;
 }
 
 void LdapClient::startQuery( const QString& filter )
 {
   cancelQuery();
-  KABC::LDAPUrl url;
+  KLDAP::LdapUrl url;
+
+  url = mServer.url();
 
-  url.setProtocol( ( mServer.security() == LdapServer::SSL ) ? "ldaps" : "ldap" );
-  if ( mServer.auth() != LdapServer::Anonymous ) {
-    url.setUser( mServer.user() );
-    url.setPass( mServer.pwdBindDN() );
-  }
-  url.setHost( mServer.host() );
-  url.setPort( mServer.port() );
-  url.setExtension( "x-ver", QString::number( mServer.version() ) );
-  url.setDn( mServer.baseDN() );
-  url.setDn( mServer.baseDN() );
-  if ( mServer.security() == LdapServer::TLS ) url.setExtension( "x-tls","" );
-  if ( mServer.auth() == LdapServer::SASL ) {
-    url.setExtension( "x-sasl","" );
-    if ( !mServer.bindDN().isEmpty() ) url.setExtension( "x-bindname", mServer.bindDN() );
-    if ( !mServer.mech().isEmpty() ) url.setExtension( "x-mech", mServer.mech() );
-  }
-  if ( mServer.timeLimit() != 0 ) url.setExtension( "x-timelimit", 
-    QString::number( mServer.timeLimit() ) );
-  if ( mServer.sizeLimit() != 0 ) url.setExtension( "x-sizelimit", 
-    QString::number( mServer.sizeLimit() ) );
-  
   url.setAttributes( mAttrs );
-  url.setScope( mScope == "one" ? KABC::LDAPUrl::One : KABC::LDAPUrl::Sub );
-  url.setFilter( "("+filter+")" );
+  url.setScope( mScope == "one" ? KLDAP::LdapUrl::One : KLDAP::LdapUrl::Sub );
+  url.setFilter( '('+filter+')' );
 
-  kdDebug(5300) << "LdapClient: Doing query: " << url.prettyURL() << endl;
+  kDebug(5300) <<"LdapClient: Doing query:" << url.prettyUrl();
 
   startParseLDIF();
   mActive = true;
-  mJob = KIO::get( url, false, false );
+  mJob = KIO::get( url, KIO::NoReload, KIO::HideProgressInfo );
   connect( mJob, SIGNAL( data( KIO::Job*, const QByteArray& ) ),
            this, SLOT( slotData( KIO::Job*, const QByteArray& ) ) );
-  connect( mJob, SIGNAL( infoMessage( KIO::Job*, const QString& ) ),
-           this, SLOT( slotInfoMessage( KIO::Job*, const QString& ) ) );
-  connect( mJob, SIGNAL( result( KIO::Job* ) ),
+  connect( mJob, SIGNAL( infoMessage( KJob*, const QString&, const QString& ) ),
+           this, SLOT( slotInfoMessage( KJob*, const QString&, const QString& ) ) );
+  connect( mJob, SIGNAL( result( KJob* ) ),
            this, SLOT( slotDone() ) );
 }
 
@@ -160,9 +104,9 @@ void LdapClient::slotData( KIO::Job*, const QByteArray& data )
   parseLDIF( data );
 }
 
-void LdapClient::slotInfoMessage( KIO::Job*, const QString & )
+void LdapClient::slotInfoMessage( KJob*, const QString &, const QString& )
 {
-  //qDebug("Job said \"%s\"", info.latin1());
+  //qDebug("Job said \"%s\"", info.toLatin1());
 }
 
 void LdapClient::slotDone()
@@ -170,8 +114,8 @@ void LdapClient::slotDone()
   endParseLDIF();
   mActive = false;
 #if 0
-  for ( QValueList<LdapObject>::Iterator it = mObjects.begin(); it != mObjects.end(); ++it ) {
-    qDebug( (*it).toString().latin1() );
+  for ( Q3ValueList<LdapObject>::Iterator it = mObjects.begin(); it != mObjects.end(); ++it ) {
+    qDebug( (*it).toString().toLatin1() );
   }
 #endif
   int err = mJob->error();
@@ -193,19 +137,38 @@ void LdapClient::endParseLDIF()
 
 void LdapClient::finishCurrentObject()
 {
-  mCurrentObject.dn = mLdif.dn();
-  const QString sClass( mCurrentObject.objectClass.lower() );
-  if( sClass == "groupofnames" || sClass == "kolabgroupofnames" ){
-    LdapAttrMap::ConstIterator it = mCurrentObject.attrs.find("mail");
-    if( it == mCurrentObject.attrs.end() ){
+  mCurrentObject.setDn( mLdif.dn() );
+  KLDAP::LdapAttrValue objectclasses;
+  for ( KLDAP::LdapAttrMap::ConstIterator it = mCurrentObject.attributes().begin();
+    it != mCurrentObject.attributes().end(); ++it ) {
+
+    if ( it.key().toLower() == "objectclass" ) {
+      objectclasses = it.value();
+      break;
+    }
+  }
+
+  bool groupofnames = false;
+  for ( KLDAP::LdapAttrValue::ConstIterator it = objectclasses.begin();
+    it != objectclasses.end(); ++it ) {
+
+    QByteArray sClass = (*it).toLower();
+    if ( sClass == "groupofnames" || sClass == "kolabgroupofnames" ) {
+      groupofnames = true;
+    }
+  }
+
+  if( groupofnames ){
+    KLDAP::LdapAttrMap::ConstIterator it = mCurrentObject.attributes().find("mail");
+    if( it == mCurrentObject.attributes().end() ){
       // No explicit mail address found so far?
       // Fine, then we use the address stored in the DN.
       QString sMail;
-      QStringList lMail = QStringList::split(",dc=", mCurrentObject.dn);
+      QStringList lMail = mCurrentObject.dn().toString().split(",dc=", QString::SkipEmptyParts);
       const int n = lMail.count();
       if( n ){
-        if( lMail.first().lower().startsWith("cn=") ){
-          sMail = lMail.first().simplifyWhiteSpace().mid(3);
+        if( lMail.first().toLower().startsWith("cn=") ){
+          sMail = lMail.first().simplified().mid(3);
           if( 1 < n )
             sMail.append('@');
           for( int i=1; i<n; ++i){
@@ -213,50 +176,43 @@ void LdapClient::finishCurrentObject()
             if( i < n-1 )
               sMail.append('.');
           }
-          mCurrentObject.attrs["mail"].append( sMail.utf8() );
+          mCurrentObject.addValue("mail", sMail.toUtf8() );
         }
       }
     }
   }
-  mCurrentObject.client = this;
-  emit result( mCurrentObject );
+  emit result( *this, mCurrentObject );
   mCurrentObject.clear();
 }
 
 void LdapClient::parseLDIF( const QByteArray& data )
 {
-  //kdDebug(5300) << "LdapClient::parseLDIF( " << QCString(data.data(), data.size()+1) << " )" << endl;
+  //kDebug(5300) <<"LdapClient::parseLDIF(" << QCString(data.data(), data.size()+1) <<" )";
   if ( data.size() ) {
-    mLdif.setLDIF( data );
+    mLdif.setLdif( data );
   } else {
-    mLdif.endLDIF();
+    mLdif.endLdif();
   }
-
-  KABC::LDIF::ParseVal ret;
+  KLDAP::Ldif::ParseValue ret;
   QString name;
   do {
     ret = mLdif.nextItem();
     switch ( ret ) {
-      case KABC::LDIF::Item: 
+      case KLDAP::Ldif::Item:
         {
           name = mLdif.attr();
-          // Must make a copy! QByteArray is explicitely shared
-          QByteArray value = mLdif.val().copy();
-          bool bIsObjectClass = name.lower() == "objectclass";
-          if( bIsObjectClass )
-            mCurrentObject.objectClass = QString::fromUtf8( value, value.size() );
-          if( mReportObjectClass || !bIsObjectClass )
-            mCurrentObject.attrs[ name ].append( value );
-          //kdDebug(5300) << "LdapClient::parseLDIF(): name=" << name << " value=" << QCString(value.data(), value.size()+1) << endl;
+          QByteArray value = mLdif.value();
+          mCurrentObject.addValue( name, value );
+          //kDebug(5300) <<"LdapClient::parseLDIF(): name=" << name <<" value=" << QCString(value.data(), value.size()+1);
         }
         break;
-     case KABC::LDIF::EndEntry:
+     case KLDAP::Ldif::EndEntry:
         finishCurrentObject();
         break;
       default:
         break;
     }
-  } while ( ret != KABC::LDIF::MoreData );
+  } while ( ret != KLDAP::Ldif::MoreData );
 }
 
 int LdapClient::clientNumber() const
@@ -274,63 +230,96 @@ void LdapClient::setCompletionWeight( int weight )
   mCompletionWeight = weight;
 }
 
-void LdapSearch::readConfig( LdapServer &server, KConfig *config, int j, bool active )
+void LdapSearch::readConfig( KLDAP::LdapServer &server, const KConfigGroup &config, int j, bool active )
 {
   QString prefix;
   if ( active ) prefix = "Selected";
-  QString host =  config->readEntry( prefix + QString( "Host%1" ).arg( j ), "" ).stripWhiteSpace();
+  QString host =  config.readEntry( prefix + QString( "Host%1" ).arg( j ), QString() ).trimmed();
   if ( !host.isEmpty() )
     server.setHost( host );
 
-  int port = config->readNumEntry( prefix + QString( "Port%1" ).arg( j ), 389 );
+  int port = config.readEntry( prefix + QString( "Port%1" ).arg( j ), 389 );
   server.setPort( port );
 
-  QString base = config->readEntry( prefix + QString( "Base%1" ).arg( j ), "" ).stripWhiteSpace();
+  QString base = config.readEntry( prefix + QString( "Base%1" ).arg( j ), QString() ).trimmed();
   if ( !base.isEmpty() )
-    server.setBaseDN( base );
+    server.setBaseDn( KLDAP::LdapDN( base ) );
 
-  QString user = config->readEntry( prefix + QString( "User%1" ).arg( j ) ).stripWhiteSpace();
+  QString user = config.readEntry( prefix + QString( "User%1" ).arg( j ), QString() ).trimmed();
   if ( !user.isEmpty() )
     server.setUser( user );
 
-  QString bindDN = config->readEntry( prefix + QString( "Bind%1" ).arg( j ) ).stripWhiteSpace();
+  QString bindDN = config.readEntry( prefix + QString( "Bind%1" ).arg( j ), QString() ).trimmed();
   if ( !bindDN.isEmpty() )
-    server.setBindDN( bindDN );
+    server.setBindDn( bindDN );
 
-  QString pwdBindDN = config->readEntry( prefix + QString( "PwdBind%1" ).arg( j ) );
+  QString pwdBindDN = config.readEntry( prefix + QString( "PwdBind%1" ).arg( j ), QString() );
   if ( !pwdBindDN.isEmpty() )
-    server.setPwdBindDN( pwdBindDN );
+    server.setPassword( pwdBindDN );
 
-  server.setTimeLimit( config->readNumEntry( prefix + QString( "TimeLimit%1" ).arg( j ) ) );
-  server.setSizeLimit( config->readNumEntry( prefix + QString( "SizeLimit%1" ).arg( j ) ) );
-  server.setVersion( config->readNumEntry( prefix + QString( "Version%1" ).arg( j ), 3 ) );
-  server.setSecurity( config->readNumEntry( prefix + QString( "Security%1" ).arg( j ) ) );
-  server.setAuth( config->readNumEntry( prefix + QString( "Auth%1" ).arg( j ) ) );
-  server.setMech( config->readEntry( prefix + QString( "Mech%1" ).arg( j ) ) );
+  server.setTimeLimit( config.readEntry( prefix + QString( "TimeLimit%1" ).arg( j ),0 ) );
+  server.setSizeLimit( config.readEntry( prefix + QString( "SizeLimit%1" ).arg( j ),0 ) );
+  server.setPageSize( config.readEntry( prefix + QString( "PageSize%1" ).arg( j ),0 ) );
+  server.setVersion( config.readEntry( prefix + QString( "Version%1" ).arg( j ), 3 ) );
+
+  QString tmp;
+  tmp = config.readEntry( prefix + QString( "Security%1" ).arg( j ), QString::fromLatin1("None") );
+  server.setSecurity( KLDAP::LdapServer::None );
+  if ( tmp == "SSL" ) server.setSecurity( KLDAP::LdapServer::SSL );
+  else if ( tmp == "TLS" ) server.setSecurity( KLDAP::LdapServer::TLS );
+
+  tmp = config.readEntry( prefix + QString( "Auth%1" ).arg( j ), QString::fromLatin1("Anonymous") );
+  server.setAuth( KLDAP::LdapServer::Anonymous );
+  if ( tmp == "Simple" ) server.setAuth( KLDAP::LdapServer::Simple );
+  else if ( tmp == "SASL" ) server.setAuth( KLDAP::LdapServer::SASL );
+
+  server.setMech( config.readEntry( prefix + QString( "Mech%1" ).arg( j ), QString() ) );
 }
 
-void LdapSearch::writeConfig( const LdapServer &server, KConfig *config, int j, bool active )
+void LdapSearch::writeConfig( const KLDAP::LdapServer &server, KConfigGroup &config, int j, bool active )
 {
   QString prefix;
   if ( active ) prefix = "Selected";
-  config->writeEntry( prefix + QString( "Host%1" ).arg( j ), server.host() );
-  config->writeEntry( prefix + QString( "Port%1" ).arg( j ), server.port() );
-  config->writeEntry( prefix + QString( "Base%1" ).arg( j ), server.baseDN() );
-  config->writeEntry( prefix + QString( "User%1" ).arg( j ), server.user() );
-  config->writeEntry( prefix + QString( "Bind%1" ).arg( j ), server.bindDN() );
-  config->writeEntry( prefix + QString( "PwdBind%1" ).arg( j ), server.pwdBindDN() );
-  config->writeEntry( prefix + QString( "TimeLimit%1" ).arg( j ), server.timeLimit() );
-  config->writeEntry( prefix + QString( "SizeLimit%1" ).arg( j ), server.sizeLimit() );
-  config->writeEntry( prefix + QString( "Version%1" ).arg( j ), server.version() );
-  config->writeEntry( prefix + QString( "Security%1" ).arg( j ), server.security() );
-  config->writeEntry( prefix + QString( "Auth%1" ).arg( j ), server.auth() );
-  config->writeEntry( prefix + QString( "Mech%1" ).arg( j ), server.mech() );
+  config.writeEntry( prefix + QString( "Host%1" ).arg( j ), server.host() );
+  config.writeEntry( prefix + QString( "Port%1" ).arg( j ), server.port() );
+  config.writeEntry( prefix + QString( "Base%1" ).arg( j ), server.baseDn().toString() );
+  config.writeEntry( prefix + QString( "User%1" ).arg( j ), server.user() );
+  config.writeEntry( prefix + QString( "Bind%1" ).arg( j ), server.bindDn() );
+  config.writeEntry( prefix + QString( "PwdBind%1" ).arg( j ), server.password() );
+  config.writeEntry( prefix + QString( "TimeLimit%1" ).arg( j ), server.timeLimit() );
+  config.writeEntry( prefix + QString( "SizeLimit%1" ).arg( j ), server.sizeLimit() );
+  config.writeEntry( prefix + QString( "PageSize%1" ).arg( j ), server.pageSize() );
+  config.writeEntry( prefix + QString( "Version%1" ).arg( j ), server.version() );
+  QString tmp;
+  switch ( server.security() ) {
+    case KLDAP::LdapServer::TLS:
+      tmp = "TLS";
+      break;
+    case KLDAP::LdapServer::SSL:
+      tmp = "SSL";
+      break;
+    default:
+      tmp = "None";
+  }
+  config.writeEntry( prefix + QString( "Security%1" ).arg( j ), tmp );
+  switch ( server.auth() ) {
+    case KLDAP::LdapServer::Simple:
+      tmp = "Simple";
+      break;
+    case KLDAP::LdapServer::SSL:
+      tmp = "SASL";
+      break;
+    default:
+      tmp = "Anonymous";
+  }
+  config.writeEntry( prefix + QString( "Auth%1" ).arg( j ), tmp );
+  config.writeEntry( prefix + QString( "Mech%1" ).arg( j ), server.mech() );
 }
 
 KConfig* LdapSearch::config()
 {
   if ( !s_config )
-    configDeleter.setObject( s_config, new KConfig( "kabldaprc", false, false ) ); // Open read-write, no kdeglobals
+    configDeleter.setObject( s_config, new KConfig("kabldaprc", KConfig::NoGlobals) ); // Open read-write, no kdeglobals
 
   return s_config;
 }
@@ -339,7 +328,7 @@ KConfig* LdapSearch::config()
 LdapSearch::LdapSearch()
     : mActiveClients( 0 ), mNoLDAPLookup( false )
 {
-  if ( !KProtocolInfo::isKnownProtocol( KURL("ldap://localhost") ) ) {
+  if ( !KProtocolInfo::isKnownProtocol( KUrl("ldap://localhost") ) ) {
     mNoLDAPLookup = true;
     return;
   }
@@ -352,26 +341,25 @@ LdapSearch::LdapSearch()
 void LdapSearch::readConfig()
 {
   cancelSearch();
-  QValueList< LdapClient* >::Iterator it;
+  QList< LdapClient* >::Iterator it;
   for ( it = mClients.begin(); it != mClients.end(); ++it )
     delete *it;
   mClients.clear();
 
   // stolen from KAddressBook
-  KConfig *config = KPIM::LdapSearch::config();
-  config->setGroup( "LDAP" );
-  int numHosts = config->readUnsignedNumEntry( "NumSelectedHosts");
+  KConfigGroup config(KPIM::LdapSearch::config(), "LDAP" );
+  int numHosts = config.readEntry( "NumSelectedHosts",0);
   if ( !numHosts ) {
     mNoLDAPLookup = true;
   } else {
     for ( int j = 0; j < numHosts; j++ ) {
       LdapClient* ldapClient = new LdapClient( j, this );
-      LdapServer server;
+      KLDAP::LdapServer server;
       readConfig( server, config, j, true );
       if ( !server.host().isEmpty() ) mNoLDAPLookup = false;
       ldapClient->setServer( server );
 
-      int completionWeight = config->readNumEntry( QString( "SelectedCompletionWeight%1" ).arg( j ), -1 );
+      int completionWeight = config.readEntry( QString( "SelectedCompletionWeight%1" ).arg( j ), -1 );
       if ( completionWeight != -1 )
         ldapClient->setCompletionWeight( completionWeight );
 
@@ -380,8 +368,8 @@ void LdapSearch::readConfig()
       attrs << "cn" << "mail" << "givenname" << "sn" << "objectClass";
       ldapClient->setAttrs( attrs );
 
-      connect( ldapClient, SIGNAL( result( const KPIM::LdapObject& ) ),
-               this, SLOT( slotLDAPResult( const KPIM::LdapObject& ) ) );
+      connect( ldapClient, SIGNAL( result( const KPIM::LdapClient&, const KLDAP::LdapObject& ) ),
+               this, SLOT( slotLDAPResult( const KPIM::LdapClient&, const KLDAP::LdapObject& ) ) );
       connect( ldapClient, SIGNAL( done() ),
                this, SLOT( slotLDAPDone() ) );
       connect( ldapClient, SIGNAL( error( const QString& ) ),
@@ -392,7 +380,7 @@ void LdapSearch::readConfig()
 
     connect( &mDataTimer, SIGNAL( timeout() ), SLOT( slotDataTimer() ) );
   }
-  mConfigFile = locateLocal( "config", "kabldaprc" );
+  mConfigFile = KStandardDirs::locateLocal( "config", "kabldaprc" );
   KDirWatch::self()->addFile( mConfigFile );
 }
 
@@ -409,11 +397,11 @@ void LdapSearch::startSearch( const QString& txt )
 
   cancelSearch();
 
-  int pos = txt.find( '\"' );
+  int pos = txt.indexOf( '\"' );
   if( pos >= 0 )
   {
     ++pos;
-    int pos2 = txt.find( '\"', pos );
+    int pos2 = txt.indexOf( '\"', pos );
     if( pos2 >= 0 )
         mSearchText = txt.mid( pos , pos2 - pos );
     else
@@ -427,20 +415,20 @@ void LdapSearch::startSearch( const QString& txt )
    * This allows both resource accounts with an email address which are not a person and
    * person entries without an email address to show up, while still not showing things
    * like structural entries in the ldap tree. */
-  QString filter = QString( "&(|(objectclass=person)(objectclass=groupOfNames)(mail=*))(|(cn=%1*)(mail=%2*)(givenName=%3*)(sn=%4*))" )
-      .arg( mSearchText ).arg( mSearchText ).arg( mSearchText ).arg( mSearchText );
+  QString filter = QString( "&(|(objectclass=person)(objectclass=groupOfNames)(mail=*))(|(cn=%1*)(mail=%2*)(mail=*@%3*)(givenName=%4*)(sn=%5*))" )
+      .arg( mSearchText ).arg( mSearchText ).arg( mSearchText ).arg( mSearchText ).arg( mSearchText );
 
-  QValueList< LdapClient* >::Iterator it;
+  QList< LdapClient* >::Iterator it;
   for ( it = mClients.begin(); it != mClients.end(); ++it ) {
     (*it)->startQuery( filter );
-    kdDebug(5300) << "LdapSearch::startSearch() " << filter << endl;
+    kDebug(5300) <<"LdapSearch::startSearch()" << filter;
     ++mActiveClients;
   }
 }
 
 void LdapSearch::cancelSearch()
 {
-  QValueList< LdapClient* >::Iterator it;
+  QList< LdapClient* >::Iterator it;
   for ( it = mClients.begin(); it != mClients.end(); ++it )
     (*it)->cancelQuery();
 
@@ -448,11 +436,18 @@ void LdapSearch::cancelSearch()
   mResults.clear();
 }
 
-void LdapSearch::slotLDAPResult( const KPIM::LdapObject& obj )
+void LdapSearch::slotLDAPResult( const LdapClient &client, const KLDAP::LdapObject& obj )
 {
-  mResults.append( obj );
+  ResultObject result;
+  result.client = &client;
+  result.object = obj;
+
+  mResults.append( result );
   if ( !mDataTimer.isActive() )
-    mDataTimer.start( 500, true );
+  {
+    mDataTimer.setSingleShot( true );
+    mDataTimer.start( 500 );
+  }
 }
 
 void LdapSearch::slotLDAPError( const QString& )
@@ -489,9 +484,9 @@ void LdapSearch::finish()
 
 void LdapSearch::makeSearchData( QStringList& ret, LdapResultList& resList )
 {
-  QString search_text_upper = mSearchText.upper();
+  QString search_text_upper = mSearchText.toUpper();
 
-  QValueList< KPIM::LdapObject >::ConstIterator it1;
+  QList< ResultObject >::ConstIterator it1;
   for ( it1 = mResults.begin(); it1 != mResults.end(); ++it1 ) {
     QString name, mail, givenname, sn;
     QStringList mails;
@@ -499,16 +494,16 @@ void LdapSearch::makeSearchData( QStringList& ret, LdapResultList& resList )
     bool wasCN = false;
     bool wasDC = false;
 
-    kdDebug(5300) << "\n\nLdapSearch::makeSearchData()\n\n" << endl;
+    kDebug(5300) <<"\n\nLdapSearch::makeSearchData()";
 
-    LdapAttrMap::ConstIterator it2;
-    for ( it2 = (*it1).attrs.begin(); it2 != (*it1).attrs.end(); ++it2 ) {
+    KLDAP::LdapAttrMap::ConstIterator it2;
+    for ( it2 = (*it1).object.attributes().begin(); it2 != (*it1).object.attributes().end(); ++it2 ) {
       QByteArray val = (*it2).first();
       int len = val.size();
       if( len > 0 && '\0' == val[len-1] )
         --len;
       const QString tmp = QString::fromUtf8( val, len );
-      kdDebug(5300) << "      key: \"" << it2.key() << "\" value: \"" << tmp << "\"" << endl;
+      kDebug(5300) <<"      key: \"" << it2.key() <<"\" value: \"" << tmp <<"\"";
       if ( it2.key() == "cn" ) {
         name = tmp;
         if( mail.isEmpty() )
@@ -534,8 +529,8 @@ void LdapSearch::makeSearchData( QStringList& ret, LdapResultList& resList )
         wasDC = true;
       } else if( it2.key() == "mail" ) {
         mail = tmp;
-        LdapAttrValue::ConstIterator it3 = it2.data().begin();
-        for ( ; it3 != it2.data().end(); ++it3 ) {
+        KLDAP::LdapAttrValue::ConstIterator it3 = it2.value().begin();
+        for ( ; it3 != it2.value().end(); ++it3 ) {
           mails.append( QString::fromUtf8( (*it3).data(), (*it3).size() ) );
         }
       } else if( it2.key() == "givenName" )
@@ -551,7 +546,7 @@ void LdapSearch::makeSearchData( QStringList& ret, LdapResultList& resList )
     if( mails.isEmpty()) {
       if ( !mail.isEmpty() ) mails.append( mail );
       if( isDistributionList ) {
-        kdDebug(5300) << "\n\nLdapSearch::makeSearchData() found a list: " << name << "\n\n" << endl;
+        kDebug(5300) <<"\n\nLdapSearch::makeSearchData() found a list:" << name;
         ret.append( name );
         // following lines commented out for bugfixing kolab issue #177:
         //
@@ -560,7 +555,7 @@ void LdapSearch::makeSearchData( QStringList& ret, LdapResultList& resList )
         // The right server is found by the SMTP server instead: Kolab users
         // must use the correct SMTP server, by definition.
         //
-        //mail = (*it1).client->base().simplifyWhiteSpace();
+        //mail = (*it1).client->base().simplified();
         //mail.replace( ",dc=", ".", false );
         //if( mail.startsWith("dc=", false) )
         //  mail.remove(0, 3);
@@ -568,14 +563,14 @@ void LdapSearch::makeSearchData( QStringList& ret, LdapResultList& resList )
         //mail.prepend( name );
         //mail = name;
       } else {
-        kdDebug(5300) << "LdapSearch::makeSearchData() found BAD ENTRY: \"" << name << "\"" << endl;
+        kDebug(5300) <<"LdapSearch::makeSearchData() found BAD ENTRY: \"" << name <<"\"";
         continue; // nothing, bad entry
       }
     } else if ( name.isEmpty() ) {
-      kdDebug(5300) << "LdapSearch::makeSearchData() mail: \"" << mail << "\"" << endl;
+      kDebug(5300) <<"LdapSearch::makeSearchData() mail: \"" << mail <<"\"";
       ret.append( mail );
     } else {
-      kdDebug(5300) << "LdapSearch::makeSearchData() name: \"" << name << "\"  mail: \"" << mail << "\"" << endl;
+      kDebug(5300) <<"LdapSearch::makeSearchData() name: \"" << name <<"\"  mail: \"" << mail <<"\"";
       ret.append( QString( "%1 <%2>" ).arg( name ).arg( mail ) );
     }
 
